@@ -7,7 +7,7 @@
  * Description : a folder view for date albums.
  *
  * SPDX-FileCopyrightText: 2005      by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2009-2010 by Johannes Wienke <languitar at semipol dot de>
  * SPDX-FileCopyrightText: 2014      by Michael G. Hansen <mike at mghansen dot de>
  *
@@ -37,17 +37,12 @@ class Q_DECL_HIDDEN DateFolderView::Private
 {
 public:
 
-    explicit Private()
-      : active      (false),
-        dateTreeView(nullptr),
-        monthview   (nullptr)
-    {
-    }
+    Private() = default;
 
-    bool          active;
+    bool          active        = false;
 
-    DateTreeView* dateTreeView;
-    MonthWidget*  monthview;
+    DateTreeView* dateTreeView  = nullptr;
+    MonthWidget*  monthview     = nullptr;
 };
 
 DateFolderView::DateFolderView(QWidget* const parent, DateAlbumModel* const dateAlbumModel)
@@ -209,3 +204,5 @@ AlbumPointer<DAlbum> DateFolderView::currentAlbum() const
 }
 
 } // namespace Digikam
+
+#include "moc_datefolderview.cpp"
