@@ -6,21 +6,12 @@
  * Date        : 1997-04-21
  * Description : A date selection widget.
  *
- * Copyright (C) 2011-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 1997      by Tim D. Gilman <tdgilman at best dot org>
- * Copyright (C) 1998-2001 by Mirko Boehm <mirko at kde dot org>
- * Copyright (C) 2007      by John Layt <john at layt dot net>
+ * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 1997      by Tim D. Gilman <tdgilman at best dot org>
+ * SPDX-FileCopyrightText: 1998-2001 by Mirko Boehm <mirko at kde dot org>
+ * SPDX-FileCopyrightText: 2007      by John Layt <john at layt dot net>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -29,7 +20,6 @@
 // Qt includes
 
 #include <QFontDatabase>
-#include <QApplication>
 
 // KDE includes
 
@@ -77,7 +67,6 @@ QValidator::State DatePickerValidator::validate(QString& text, int&) const
 DatePickerYearSelector::DatePickerYearSelector(const QDate& currentDate, QWidget* const parent)
     : QLineEdit(parent),
       val      (new QIntValidator(this)),
-      result   (0),
       oldDate  (currentDate)
 {
     setFont(QFontDatabase::systemFont(QFontDatabase::GeneralFont));
@@ -115,7 +104,8 @@ void DatePickerYearSelector::yearEnteredSlot()
     if (QDate(newYear, oldDate.month(), oldDate.day()).isValid())
     {
         result = newYear;
-        emit closeMe(1);
+
+        Q_EMIT closeMe(1);
     }
     else
     {
@@ -136,21 +126,7 @@ void DatePickerYearSelector::setYear(int year)
 // ------------------------------------------------------------------------------
 
 DDatePicker::Private::Private(DDatePicker* const qq)
-    : q                 (qq),
-      closeButton       (nullptr),
-      selectWeek        (nullptr),
-      todayButton       (nullptr),
-      navigationLayout  (nullptr),
-      yearForward       (nullptr),
-      yearBackward      (nullptr),
-      monthForward      (nullptr),
-      monthBackward     (nullptr),
-      selectMonth       (nullptr),
-      selectYear        (nullptr),
-      line              (nullptr),
-      val               (nullptr),
-      table             (nullptr),
-      fontsize          (0)
+    : q(qq)
 {
 }
 
@@ -233,3 +209,5 @@ QDate DDatePicker::Private::validDateInYearMonth(int year, int month)
 }
 
 } // namespace Digikam
+
+#include "moc_ddatepicker_p.cpp"
