@@ -8,7 +8,7 @@
  *
  * SPDX-FileCopyrightText: 2004      by Bram Schoenmakers <bramschoenmakers at kde dot nl>
  * SPDX-FileCopyrightText: 2006      by Mikolaj Machowski <mikmach at wp dot pl>
- * SPDX-FileCopyrightText: 2011-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -18,7 +18,6 @@
 
 // Qt includes
 
-#include <QDateTime>
 #include <QWidgetAction>
 
 // KDE includes
@@ -62,8 +61,8 @@ protected:
 
 private:
 
-    DDatePicker* m_datePicker;
-    QWidget*     m_originalParent;
+    DDatePicker* m_datePicker       = nullptr;
+    QWidget*     m_originalParent   = nullptr;
 };
 
 // ---------------------------------------------------------------------------------------
@@ -72,12 +71,9 @@ class Q_DECL_HIDDEN DDatePickerPopup::Private
 {
 public:
 
-    explicit Private()
-      : datePicker(nullptr)
-    {
-    }
+    Private() = default;
 
-    DDatePicker* datePicker;
+    DDatePicker* datePicker = nullptr;
     Items        items;
 };
 
@@ -174,6 +170,7 @@ int DDatePickerPopup::items() const
 void DDatePickerPopup::slotDateChanged(const QDate& date)
 {
     Q_EMIT dateChanged(date);
+
     hide();
 }
 
@@ -227,6 +224,7 @@ void DDatePickerPopup::slotPrevFriday()
 void DDatePickerPopup::slotPrevMonday()
 {
     QDate date = QDate::currentDate();
+
     Q_EMIT dateChanged(date.addDays(1 - date.dayOfWeek()));
 }
 
@@ -243,3 +241,5 @@ void DDatePickerPopup::slotPrevMonth()
 } // namespace Digikam
 
 #include "ddatepickerpopup.moc"
+
+#include "moc_ddatepickerpopup.cpp"
