@@ -6,7 +6,7 @@
  * Date        : 1997-04-21
  * Description : Date selection table.
  *
- * SPDX-FileCopyrightText: 2011-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 1997      by Tim D. Gilman <tdgilman at best dot org>
  * SPDX-FileCopyrightText: 1998-2001 by Mirko Boehm <mirko at kde dot org>
  * SPDX-FileCopyrightText: 2007      by John Layt <john at layt dot net>
@@ -502,6 +502,7 @@ void DDateTable::keyPressEvent(QKeyEvent *e)
         case Qt::Key_Enter:
         {
             Q_EMIT tableClicked();
+
             break;
         }
 
@@ -705,6 +706,7 @@ void DDateTable::mousePressEvent(QMouseEvent *e)
     {
         QMenu* const menu = new QMenu();
         menu->addSection(locale().toString(d->date));
+
         Q_EMIT aboutToShowContextMenu(menu, clickedDate);
 
 #if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
@@ -769,7 +771,7 @@ QSize DDateTable::sizeHint() const
     }
     else
     {
-        //qCDebug(DIGIKAM_GENERAL_LOG) << "DDateTable::sizeHint: obscure failure - " << QT_ENDL;
+        //qCDebug(DIGIKAM_GENERAL_LOG) << "DDateTable::sizeHint: obscure failure - " << Qt::endl;
 
         return QSize(-1, -1);
     }
@@ -817,3 +819,5 @@ void DDateTable::unsetCustomDatePainting(const QDate& date)
 }
 
 } // namespace Digikam
+
+#include "moc_ddatetable.cpp"
