@@ -15,8 +15,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DDATE_TABLE_H
-#define DIGIKAM_DDATE_TABLE_H
+#pragma once
 
 // Qt includes
 
@@ -174,7 +173,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 
     friend class Private;
 
@@ -182,5 +181,3 @@ private:
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_DDATE_TABLE_H
