@@ -6,7 +6,7 @@
  * Date        : 1997-04-21
  * Description : Date selection table.
  *
- * SPDX-FileCopyrightText: 2011-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 1997      by Tim D. Gilman <tdgilman at best dot org>
  * SPDX-FileCopyrightText: 1998-2001 by Mirko Boehm <mirko at kde dot org>
  * SPDX-FileCopyrightText: 2007      by John Layt <john at layt dot net>
@@ -19,7 +19,6 @@
 
 // C++ includes
 
-#include <cmath>
 
 // Qt includes
 
@@ -36,24 +35,12 @@ namespace Digikam
 {
 
 DDateTable::Private::Private(DDateTable* const qq)
-    : QObject               (qq),
-      q                     (qq),
-      weekDayFirstOfMonth   (0),
-      numDaysThisMonth      (0),
-      numWeekRows           (0),
-      numDayColumns         (0),
-      fontsize              (0),
-      popupMenuEnabled      (false),
-      useCustomColors       (false),
-      hoveredPos            (-1)
+    : QObject(qq),
+      q      (qq)
 {
     setDate(QDate::currentDate());
 }
 
-DDateTable::Private::~Private()
-{
-}
-
 void DDateTable::Private::nextMonth()
 {
     // setDate does validity checking for us
@@ -106,3 +93,5 @@ void DDateTable::Private::setDate(const QDate& dt)
 }
 
 } // namespace Digikam
+
+#include "moc_ddatetable_p.cpp"
