@@ -7,7 +7,7 @@
  * Description : a widget to edit time stamp.
  *
  * SPDX-FileCopyrightText: 2005      by Tom Albers <tomalbers at kde dot nl>
- * SPDX-FileCopyrightText: 2011-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -21,6 +21,7 @@
 
 // Local includes
 
+#include "digikam_globals.h"
 #include "ddateedit.h"
 
 namespace Digikam
@@ -30,14 +31,10 @@ class Q_DECL_HIDDEN DDateTimeEdit::Private
 {
 public:
 
-    explicit Private()
-      : timePopUp(nullptr),
-        datePopUp(nullptr)
-    {
-    }
+    Private() = default;
 
-    QTimeEdit* timePopUp;
-    DDateEdit* datePopUp;
+    QTimeEdit* timePopUp = nullptr;
+    DDateEdit* datePopUp = nullptr;
 };
 
 DDateTimeEdit::DDateTimeEdit(QWidget* const parent, const QString& name)
@@ -71,7 +68,9 @@ DDateTimeEdit::~DDateTimeEdit()
 
 QDateTime DDateTimeEdit::dateTime() const
 {
-    return QDateTime(d->datePopUp->date(), d->timePopUp->time());
+    QDateTime dateTime(d->datePopUp->date(), d->timePopUp->time());
+
+    return asDateTimeUTC(dateTime);
 }
 
 void DDateTimeEdit::setDateTime(const QDateTime& dateTime)
@@ -86,3 +85,5 @@ void DDateTimeEdit::slotDateTimeChanged()
 }
 
 } // namespace Digikam
+
+#include "moc_ddatetimeedit.cpp"
