@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DDATE_TIME_EDIT_H
-#define DIGIKAM_DDATE_TIME_EDIT_H
+#pragma once
 
 // Qt includes
 
@@ -77,9 +76,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_DDATE_TIME_EDIT_H
