@@ -6,7 +6,7 @@
  * Date        : 1997-04-21
  * Description : Frame with popup menu behavior.
  *
- * SPDX-FileCopyrightText: 2011-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 1997      by Tim D. Gilman <tdgilman at best dot org>
  * SPDX-FileCopyrightText: 1998-2001 by Mirko Boehm <mirko at kde dot org>
  * SPDX-FileCopyrightText: 2007      by John Layt <john at layt dot net>
@@ -15,8 +15,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DPOP_UP_FRAME_H
-#define DIGIKAM_DPOP_UP_FRAME_H
+#pragma once
 
 // Qt includes
 
@@ -39,7 +38,7 @@ public:
     /**
      * The destructor
      */
-    ~DPopupFrame() override;
+    ~DPopupFrame()                      override;
 
     /**
      * Set the main widget. You cannot set the main widget from the constructor,
@@ -54,7 +53,7 @@ public:
      * The resize event. Simply resizes the main widget to the whole
      * widgets client size.
      */
-    void resizeEvent(QResizeEvent* e) override;
+    void resizeEvent(QResizeEvent* e)   override;
 
     /**
      * Open the popup window at position pos.
@@ -80,12 +79,12 @@ protected:
     /**
      * Catch key press events.
      */
-    void keyPressEvent(QKeyEvent* e) override;
+    void keyPressEvent(QKeyEvent* e)    override;
 
     /**
      * Catch hide events.
      */
-    void hideEvent(QHideEvent* e)    override;
+    void hideEvent(QHideEvent* e)       override;
 
 public Q_SLOTS:
 
@@ -98,7 +97,7 @@ public Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 
     friend class Private;
 
@@ -106,5 +105,3 @@ private:
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_DPOP_UP_FRAME_H
