@@ -7,7 +7,7 @@
  * Description : a widget to perform month selection.
  *
  * SPDX-FileCopyrightText: 2005      by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2011      by Andi Clemens <andi dot clemens at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -46,47 +46,30 @@ public:
     {
     public:
 
-        Month()
-          : active   (false),
-            selected (false),
-            day      (0),
-            numImages(0)
-        {
-        }
+        Month() = default;
 
-        bool active;
-        bool selected;
+        bool active     = false;
+        bool selected   = false;
 
-        int  day;
-        int  numImages;
+        int  day        = 0;
+        int  numImages  = 0;
     };
 
 public:
 
-    explicit Private()
-      : active(true),
-        model (nullptr),
-        timer (nullptr),
-        year  (0),
-        month (0),
-        width (0),
-        height(0),
-        currw (0),
-        currh (0)
-    {
-    }
+    Private() = default;
 
-    bool             active;
+    bool             active = true;
 
-    ItemFilterModel* model;
-    QTimer*          timer;
+    ItemFilterModel* model  = nullptr;
+    QTimer*          timer  = nullptr;
 
-    int              year;
-    int              month;
-    int              width;
-    int              height;
-    int              currw;
-    int              currh;
+    int              year   = 0;
+    int              month  = 0;
+    int              width  = 0;
+    int              height = 0;
+    int              currw  = 0;
+    int              currh  = 0;
 
     Month            days[42];
 };
@@ -172,7 +155,10 @@ void MonthWidget::paintEvent(QPaintEvent*)
 {
     QRect cr(contentsRect());
 
-    QPixmap pix(cr.width(), cr.height());
+    qreal dpr = devicePixelRatio();
+
+    QPixmap pix(cr.width() * dpr, cr.height() * dpr);
+    pix.setDevicePixelRatio(dpr);
 
     QFont fnBold(font());
     QFont fnOrig(font());
@@ -346,7 +332,7 @@ void MonthWidget::mousePressEvent(QMouseEvent* e)
         {
             int endSelection = j*7+i;
 
-            if (endSelection > firstSelected)
+            if      (endSelection > firstSelected)
             {
                 for (int i2 = firstSelected ; i2 <= endSelection ; ++i2)
                 {
@@ -521,3 +507,5 @@ void MonthWidget::slotModelDestroyed()
 }
 
 } // namespace Digikam
+
+#include "moc_monthwidget.cpp"
