@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_MONTH_WIDGET_H
-#define DIGIKAM_MONTH_WIDGET_H
+#pragma once
 
 // Qt includes
 
@@ -72,9 +71,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_MONTH_WIDGET_H
