@@ -6,14 +6,13 @@
  * Date        : 2008-02-29
  * Description : Drag object info containers.
  *
- * SPDX-FileCopyrightText: 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DDRAG_OBJECTS_H
-#define DIGIKAM_DDRAG_OBJECTS_H
+#pragma once
 
 // Qt includes
 
@@ -163,5 +162,3 @@ private:
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_DDRAG_OBJECTS_H
