@@ -7,7 +7,7 @@
  * Description : Qt Model for ImportUI - drag and drop handling
  *
  * SPDX-FileCopyrightText: 2012      by Islam Wazery <wazery at ubuntu dot com>
- * SPDX-FileCopyrightText: 2013-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2013-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -276,7 +276,7 @@ QMimeData* ImportDragDropHandler::createMimeData(const QList<QModelIndex>& index
 
     QStringList lst;
 
-    Q_FOREACH (const CamItemInfo& info, infos)
+    for (const CamItemInfo& info : std::as_const(infos))
     {
         lst.append(info.folder + info.name);
     }
@@ -295,3 +295,5 @@ ImportItemModel* ImportDragDropHandler::model() const
 }
 
 } // namespace Digikam
+
+#include "moc_importdragdrop.cpp"
