@@ -7,14 +7,13 @@
  * Description : Qt Model for Tags - drag and drop handling
  *
  * SPDX-FileCopyrightText: 2009      by Johannes Wienke <languitar at semipol dot de>
- * SPDX-FileCopyrightText: 2013-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2013-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_TAG_DRAG_DROP_H
-#define DIGIKAM_TAG_DRAG_DROP_H
+#pragma once
 
 // Local includes
 
@@ -50,5 +49,3 @@ Q_SIGNALS:
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_TAG_DRAG_DROP_H
