@@ -7,7 +7,7 @@
  * Description : Qt model-view for items - the delegate
  *
  * SPDX-FileCopyrightText: 2002-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2002-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2002-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2009-2011 by Andi Clemens <andi dot clemens at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
@@ -15,8 +15,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DIGIKAMITEM_DELEGATE_P_H
-#define DIGIKAM_DIGIKAMITEM_DELEGATE_P_H
+#pragma once
 
 // Qt includes
 
@@ -33,10 +32,7 @@ class Q_DECL_HIDDEN DigikamItemDelegatePrivate : public ItemDelegate::ItemDelega
 {
 public:
 
-    explicit DigikamItemDelegatePrivate()
-    {
-    }
-
+    explicit DigikamItemDelegatePrivate() = default;
     ~DigikamItemDelegatePrivate() override;
 
     void init(DigikamItemDelegate* const q, ItemCategorizedView* const parent);
@@ -48,11 +44,7 @@ class Q_DECL_HIDDEN ItemFaceDelegatePrivate : public DigikamItemDelegatePrivate
 {
 public:
 
-    explicit ItemFaceDelegatePrivate()
-    {
-    }
+    explicit ItemFaceDelegatePrivate() = default;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_DIGIKAMITEM_DELEGATE_P_H
