@@ -8,7 +8,7 @@
  *
  * SPDX-FileCopyrightText: 2002-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  * SPDX-FileCopyrightText: 2009-2011 by Andi Clemens <andi dot clemens at gmail dot com>
- * SPDX-FileCopyrightText: 2002-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2002-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -68,12 +68,12 @@ void ItemDelegate::ItemDelegatePrivate::clearRects()
     groupRect            = QRect(0, 0, 0, 0);
 }
 
-ItemDelegate::ItemDelegate(QObject* const parent)
+ItemDelegate::ItemDelegate(QWidget* const parent)
     : ItemViewDelegate(*new ItemDelegatePrivate, parent)
 {
 }
 
-ItemDelegate::ItemDelegate(ItemDelegate::ItemDelegatePrivate& dd, QObject* const parent)
+ItemDelegate::ItemDelegate(ItemDelegate::ItemDelegatePrivate& dd, QWidget* const parent)
     : ItemViewDelegate(dd, parent)
 {
 }
@@ -81,8 +81,10 @@ ItemDelegate::ItemDelegate(ItemDelegate::ItemDelegatePrivate& dd, QObject* const
 ItemDelegate::~ItemDelegate()
 {
     Q_D(ItemDelegate);
+
     // crashes for a lot of people, see bug 230515. Cause unknown.
     //delete d->categoryDrawer;
+
     Q_UNUSED(d); // To please compiler about warnings.
 }
 
@@ -161,54 +163,68 @@ void ItemDelegate::setSpacing(int spacing)
 ItemCategoryDrawer* ItemDelegate::categoryDrawer() const
 {
     Q_D(const ItemDelegate);
+
     return d->categoryDrawer;
 }
 
 QRect ItemDelegate::commentsRect() const
 {
     Q_D(const ItemDelegate);
+
     return d->commentsRect;
 }
 
 QRect ItemDelegate::tagsRect() const
 {
     Q_D(const ItemDelegate);
+
     return d->tagRect;
 }
 
 QRect ItemDelegate::pixmapRect() const
 {
     Q_D(const ItemDelegate);
+
     return d->pixmapRect;
 }
 
 QRect ItemDelegate::imageInformationRect() const
 {
     Q_D(const ItemDelegate);
+
     return d->imageInformationRect;
 }
 
 QRect ItemDelegate::groupIndicatorRect() const
 {
     Q_D(const ItemDelegate);
+
     return d->groupRect;
 }
 
 QRect ItemDelegate::coordinatesIndicatorRect() const
 {
     Q_D(const ItemDelegate);
+
     return d->coordinatesRect;
 }
 
 QPixmap ItemDelegate::retrieveThumbnailPixmap(const QModelIndex& index, int thumbnailSize)
 {
     // work around constness
+
     QAbstractItemModel* const model = const_cast<QAbstractItemModel*>(index.model());
+
     // set requested thumbnail size
+
     model->setData(index, thumbnailSize, ItemModel::ThumbnailRole);
+
     // get data from model
+
     QVariant thumbData              = index.data(ItemModel::ThumbnailRole);
+
     // reset to default thumbnail size
+
     model->setData(index, QVariant(), ItemModel::ThumbnailRole);
 
     return thumbData.value<QPixmap>();
@@ -217,12 +233,14 @@ QPixmap ItemDelegate::retrieveThumbnailPixmap(const QModelIndex& index, int thum
 QPixmap ItemDelegate::thumbnailPixmap(const QModelIndex& index) const
 {
     Q_D(const ItemDelegate);
+
     return retrieveThumbnailPixmap(index, d->thumbSize.size());
 }
 
 void ItemDelegate::paint(QPainter* p, const QStyleOptionViewItem& option, const QModelIndex& index) const
 {
     Q_D(const ItemDelegate);
+
     ItemInfo info = ItemModel::retrieveItemInfo(index);
 
     if (info.isNull())
@@ -231,12 +249,14 @@ void ItemDelegate::paint(QPainter* p, const QStyleOptionViewItem& option, const
     }
 
     // state of painter must not be changed
+
     p->save();
     p->translate(option.rect.topLeft());
 
     bool isSelected = (option.state & QStyle::State_Selected);
 
     // Thumbnail
+
     QPixmap pix;
 
     if (isSelected)
@@ -266,10 +286,11 @@ void ItemDelegate::paint(QPainter* p, const QStyleOptionViewItem& option, const
         drawRating(p, index, d->ratingRect, info.rating(), isSelected);
     }
 
-    // Draw Color Label rectangle
+    // Draw Color Label line
+
     if (ApplicationSettings::instance()->getIconShowColorLabel())
     {
-        drawColorLabelRect(p, option, isSelected, info.colorLabel());
+        drawColorLabelLine(p, d->pixmapRect, info.colorLabel());
     }
 
     p->setPen(isSelected ? qApp->palette().color(QPalette::HighlightedText)
@@ -277,6 +298,7 @@ void ItemDelegate::paint(QPainter* p, const QStyleOptionViewItem& option, const
 
 /*
     // If there is ImageHistory present, paint a small icon over the thumbnail to indicate that this is derived image
+
     if (info.hasImageHistory())
     {
         p->drawPixmap(d->pixmapRect.right()-24, d->pixmapRect.bottom()-24, QIcon::fromTheme(QLatin1String("svn_switch")).pixmap(22, 22));
@@ -352,7 +374,9 @@ void ItemDelegate::paint(QPainter* p, const QStyleOptionViewItem& option, const
         QString frm  = info.format();
 
         if (frm.contains(QLatin1Char('-')))
+        {
             frm = frm.section(QLatin1Char('-'), -1);   // For RAW format annotated as "RAW-xxx" => "xxx"
+        }
 
         drawImageFormat(p, actualPixmapRect, frm, d->drawImageFormatTop);
     }
@@ -391,23 +415,29 @@ QPixmap ItemDelegate::pixmapForDrag(const QStyleOptionViewItem& option, const QL
         icon = thumbnailPixmap(indexes.first());
     }
 
-    return makeDragPixmap(option, indexes, icon);
+    return makeDragPixmap(option, indexes, displayRatio(), icon);
 }
 
-bool ItemDelegate::acceptsToolTip(const QPoint& pos, const QRect& visualRect, const QModelIndex& index,
-                                   QRect* toolTipRect) const
+bool ItemDelegate::acceptsToolTip(const QPoint& pos,
+                                  const QRect& visualRect,
+                                  const QModelIndex& index,
+                                  QRect* toolTipRect) const
 {
     return onActualPixmapRect(pos, visualRect, index, toolTipRect);
 }
 
-bool ItemDelegate::acceptsActivation(const QPoint& pos, const QRect& visualRect, const QModelIndex& index,
-                                      QRect* activationRect) const
+bool ItemDelegate::acceptsActivation(const QPoint& pos,
+                                     const QRect& visualRect,
+                                     const QModelIndex& index,
+                                     QRect* activationRect) const
 {
     return onActualPixmapRect(pos, visualRect, index, activationRect);
 }
 
-bool ItemDelegate::onActualPixmapRect(const QPoint& pos, const QRect& visualRect, const QModelIndex& index,
-                                       QRect* returnRect) const
+bool ItemDelegate::onActualPixmapRect(const QPoint& pos,
+                                      const QRect& visualRect,
+                                      const QModelIndex& index,
+                                      QRect* returnRect) const
 {
     QRect actualRect = actualPixmapRect(index);
 
@@ -453,7 +483,8 @@ void ItemDelegate::invalidatePaintingCache()
 void ItemDelegate::updateContentWidth()
 {
     Q_D(ItemDelegate);
-    d->contentWidth = d->thumbSize.size() + 2*d->radius;
+
+    d->contentWidth = d->thumbSize.size() + 2 * d->radius;
 }
 
 void ItemDelegate::updateSizeRectsAndPixmaps()
@@ -493,6 +524,7 @@ void ItemDelegate::updateSizeRectsAndPixmaps()
 void ItemDelegate::clearCaches()
 {
     Q_D(ItemDelegate);
+
     ItemViewDelegate::clearCaches();
     d->actualPixmapRectCache.clear();
 }
@@ -500,12 +532,14 @@ void ItemDelegate::clearCaches()
 void ItemDelegate::clearModelDataCaches()
 {
     Q_D(ItemDelegate);
+
     d->actualPixmapRectCache.clear();
 }
 
 void ItemDelegate::modelChanged()
 {
     Q_D(ItemDelegate);
+
     clearModelDataCaches();
     setModel(d->currentView ? d->currentView->model() : nullptr);
 }
@@ -518,8 +552,10 @@ void ItemDelegate::modelContentsChanged()
 QRect ItemDelegate::actualPixmapRect(const QModelIndex& index) const
 {
     Q_D(const ItemDelegate);
+
     // We do not recompute if not found. Assumption is cache is always properly updated.
-    QRect* rect = d->actualPixmapRectCache.object(index.row());
+
+    QRect* const rect = d->actualPixmapRectCache.object(index.row());
 
     if (rect)
     {
@@ -534,9 +570,10 @@ QRect ItemDelegate::actualPixmapRect(const QModelIndex& index) const
 void ItemDelegate::updateActualPixmapRect(const QModelIndex& index, const QRect& rect)
 {
     Q_D(ItemDelegate);
+
     QRect* const old = d->actualPixmapRectCache.object(index.row());
 
-    if (!old || *old != rect)
+    if (!old || (*old != rect))
     {
         d->actualPixmapRectCache.insert(index.row(), new QRect(rect));
     }
@@ -549,18 +586,21 @@ int ItemDelegate::calculatethumbSizeToFit(int ws)
     int ts     = thumbnailSize().size();
     int gs     = gridSize().width();
     int sp     = spacing();
-    ws         = ws - 2*sp;
+    ws         = ws - 2 * sp;
 
     // Thumbnails size loop to check (upper/lower)
+
     int ts1, ts2;
+
     // New grid size used in loop
+
     int ngs;
 
     double rs1 = fmod((double)ws, (double)gs);
 
     for (ts1 = ts ; ts1 < ThumbnailSize::maxThumbsSize() ; ++ts1)
     {
-        ngs        = ts1 + 2*(d->margin + d->radius) + sp;
+        ngs        = ts1 + 2 * (d->margin + d->radius) + sp;
         double nrs = fmod((double)ws, (double)ngs);
 
         if (nrs <= rs1)
@@ -577,7 +617,7 @@ int ItemDelegate::calculatethumbSizeToFit(int ws)
 
     for (ts2 = ts ; ts2 > ThumbnailSize::Small ; --ts2)
     {
-        ngs        = ts2 + 2*(d->margin + d->radius) + sp;
+        ngs        = ts2 + 2 * (d->margin + d->radius) + sp;
         double nrs = fmod((double)ws, (double)ngs);
 
         if (nrs >= rs2)
@@ -600,3 +640,5 @@ int ItemDelegate::calculatethumbSizeToFit(int ws)
 }
 
 } // namespace Digikam
+
+#include "moc_itemdelegate.cpp"
