@@ -7,14 +7,13 @@
  * Description : Qt model-view for items - the delegate
  *
  * SPDX-FileCopyrightText: 2009-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ITEM_DELEGATE_H
-#define DIGIKAM_ITEM_DELEGATE_H
+#pragma once
 
 // Local includes
 
@@ -37,7 +36,7 @@ class ItemDelegate : public ItemViewDelegate
 
 public:
 
-    explicit ItemDelegate(QObject* const parent = nullptr);
+    explicit ItemDelegate(QWidget* const parent);
     ~ItemDelegate()                                                                                    override;
 
     void setView(ItemCategorizedView* view);
@@ -78,35 +77,38 @@ public:
 
 protected:
 
-    /** Reimplement this to set contentWidth. This is the maximum width of all
-     *  content rectangles, typically excluding margins on both sides.
+    /**
+     * Reimplement this to set contentWidth. This is the maximum width of all
+     * content rectangles, typically excluding margins on both sides.
      */
     virtual void updateContentWidth();
 
-    /** In a subclass, you need to implement this method to set up the rects
-     *  for drawing. The paint() method operates depending on these rects.
+    /**
+     * In a subclass, you need to implement this method to set up the rects
+     * for drawing. The paint() method operates depending on these rects.
      */
     virtual void updateRects() = 0;
 
     void clearCaches() override;
 
-    /** Reimplement to clear caches based on model indexes (hash on row number etc.)
-     *  Change signals are listened to this is called whenever such properties become invalid.
+    /**
+     * Reimplement to clear caches based on model indexes (hash on row number etc.)
+     * Change signals are listened to this is called whenever such properties become invalid.
      */
     virtual void clearModelDataCaches();
 
-    virtual QPixmap thumbnailPixmap(const QModelIndex& index)               const;
+    virtual QPixmap thumbnailPixmap(const QModelIndex& index)                                    const;
 
     bool onActualPixmapRect(const QPoint& pos, const QRect& visualRect,
-                            const QModelIndex& index, QRect* actualRect)    const;
+                            const QModelIndex& index, QRect* actualRect)                         const;
     void updateActualPixmapRect(const QModelIndex& index, const QRect& rect);
 
-    void invalidatePaintingCache() override;
-    void updateSizeRectsAndPixmaps() override;
+    void invalidatePaintingCache()                                                                      override;
+    void updateSizeRectsAndPixmaps()                                                                    override;
 
     void setModel(QAbstractItemModel* model);
 
-    ItemDelegate(ItemDelegate::ItemDelegatePrivate& dd, QObject* const parent);
+    ItemDelegate(ItemDelegate::ItemDelegatePrivate& dd, QWidget* const parent);
 
 protected Q_SLOTS:
 
@@ -119,5 +121,3 @@ private:
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_ITEM_DELEGATE_H
