@@ -7,7 +7,7 @@
  * Description : Qt model-view for face item - the delegate
  *
  * SPDX-FileCopyrightText: 2002-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2002-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2002-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2009-2010 by Andi Clemens <andi dot clemens at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
@@ -36,10 +36,6 @@ ItemFaceDelegate::ItemFaceDelegate(ItemCategorizedView* const parent)
 {
 }
 
-ItemFaceDelegate::~ItemFaceDelegate()
-{
-}
-
 QPixmap ItemFaceDelegate::thumbnailPixmap(const QModelIndex& index) const
 {
     QRect rect = largerFaceRect(index);
@@ -103,13 +99,11 @@ FaceTagsIface ItemFaceDelegate::face(const QModelIndex& index)
 void ItemFaceDelegate::updateRects()
 {
     Q_D(ItemFaceDelegate);
+
     DigikamItemDelegate::updateRects();
     d->groupRect = QRect();
 }
 
-void ItemFaceDelegate::clearModelDataCaches()
-{
-    DigikamItemDelegate::clearModelDataCaches();
-}
-
 } // namespace Digikam
+
+#include "moc_itemfacedelegate.cpp"
