@@ -7,14 +7,13 @@
  * Description : overlay for extra functionality of the group indicator
  *
  * SPDX-FileCopyrightText: 2011      by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_GROUP_INDICATOR_OVERLAY_H
-#define DIGIKAM_GROUP_INDICATOR_OVERLAY_H
+#pragma once
 
 // Qt includes
 
@@ -75,11 +74,11 @@ protected:
     void updatePosition();
     void updateRating();
 
-    QWidget* createWidget() override;
-    void setActive(bool) override;
-    void visualChange() override;
-    void slotEntered(const QModelIndex& index) override;
-    bool checkIndex(const QModelIndex& index) const override;
+    QWidget* createWidget()                           override;
+    void setActive(bool)                              override;
+    void visualChange()                               override;
+    void slotEntered(const QModelIndex& index)        override;
+    bool checkIndex(const QModelIndex& index)   const override;
 
 protected:
 
@@ -87,5 +86,3 @@ protected:
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_GROUP_INDICATOR_OVERLAY_H
