@@ -6,7 +6,7 @@
  * Date        : 2014-05-28
  * Description : overlay for GPS location indicator
  *
- * SPDX-FileCopyrightText: 2014-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2014-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -51,7 +51,9 @@ CoordinatesOverlayWidget* ItemCoordinatesOverlay::buttonWidget() const
 QWidget* ItemCoordinatesOverlay::createWidget()
 {
     QAbstractButton* const button = new CoordinatesOverlayWidget(parentWidget());
-    //button->setCursor(Qt::PointingHandCursor);
+/*
+    button->setCursor(Qt::PointingHandCursor);
+*/
     return button;
 }
 
@@ -107,3 +109,5 @@ void ItemCoordinatesOverlay::slotEntered(const QModelIndex& index)
 }
 
 } // namespace Digikam
+
+#include "moc_itemcoordinatesoverlay.cpp"
