@@ -6,14 +6,13 @@
  * Date        : 2014-05-28
  * Description : overlay for GPS location indicator
  *
- * SPDX-FileCopyrightText: 2014-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2014-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ITEM_COORDINATES_OVERLAY_H
-#define DIGIKAM_ITEM_COORDINATES_OVERLAY_H
+#pragma once
 
 // Qt includes
 
@@ -58,11 +57,11 @@ protected:
 
     void updatePosition();
 
-    QWidget* createWidget() override;
-    void setActive(bool active) override;
-    void visualChange() override;
-    bool checkIndex(const QModelIndex& index) const override;
-    void slotEntered(const QModelIndex& index) override;
+    QWidget* createWidget()                           override;
+    void setActive(bool active)                       override;
+    void visualChange()                               override;
+    bool checkIndex(const QModelIndex& index)   const override;
+    void slotEntered(const QModelIndex& index)        override;
 
 protected:
 
@@ -70,5 +69,3 @@ protected:
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_ITEM_COORDINATES_OVERLAY_H
