@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ITEM_RATING_OVERLAY_H
-#define DIGIKAM_ITEM_RATING_OVERLAY_H
+#pragma once
 
 // Qt includes
 
@@ -71,5 +70,3 @@ protected:
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_ITEM_RATING_OVERLAY_H
