@@ -38,19 +38,15 @@ class Q_DECL_HIDDEN ItemThumbnailBar::Private
 {
 public:
 
-    explicit Private()
-      : scrollPolicy    (Qt::ScrollBarAlwaysOn),
-        duplicatesFilter(nullptr)
-    {
-    }
+    Private() = default;
 
-    Qt::ScrollBarPolicy          scrollPolicy;
-    NoDuplicatesItemFilterModel* duplicatesFilter;
+    Qt::ScrollBarPolicy          scrollPolicy       = Qt::ScrollBarAlwaysOn;
+    NoDuplicatesItemFilterModel* duplicatesFilter   = nullptr;
 };
 
 ItemThumbnailBar::ItemThumbnailBar(QWidget* const parent)
     : ItemCategorizedView(parent),
-      d                  (new Private())
+      d                  (new Private)
 {
     setItemDelegate(new ItemThumbnailDelegate(this));
     setSpacing(3);
@@ -71,10 +67,12 @@ ItemThumbnailBar::ItemThumbnailBar(QWidget* const parent)
     setToolTipEnabled(ApplicationSettings::instance()->showToolTipsIsValid());
 
     // --- NOTE: use dynamic binding as slotSetupChanged() is a virtual slot which can be re-implemented in derived classes.
+
     connect(ApplicationSettings::instance(), &ApplicationSettings::setupChanged,
             this, &ItemThumbnailBar::slotSetupChanged);
 
     this->slotSetupChanged();
+
     // ---
 
     setFlow(LeftToRight);
@@ -109,13 +107,19 @@ void ItemThumbnailBar::installOverlays()
 
 void ItemThumbnailBar::slotDockLocationChanged(Qt::DockWidgetArea area)
 {
-    if (area == Qt::LeftDockWidgetArea || area == Qt::RightDockWidgetArea)
+    if ((area == Qt::LeftDockWidgetArea) || (area == Qt::RightDockWidgetArea))
     {
-        setFlow(TopToBottom);
+        if (flow() != TopToBottom)
+        {
+            setFlow(TopToBottom);
+        }
     }
     else
     {
-        setFlow(LeftToRight);
+        if (flow() != LeftToRight)
+        {
+            setFlow(LeftToRight);
+        }
     }
 
     scrollTo(currentIndex());
@@ -126,6 +130,7 @@ void ItemThumbnailBar::setScrollBarPolicy(Qt::ScrollBarPolicy policy)
     if (policy == Qt::ScrollBarAsNeeded)
     {
         // Delegate resizing will cause endless relayouting, see bug #228807
+
         qCDebug(DIGIKAM_GENERAL_LOG) << "The Qt::ScrollBarAsNeeded policy is not supported by ItemThumbnailBar";
     }
 
@@ -153,10 +158,12 @@ void ItemThumbnailBar::setFlow(QListView::Flow flow)
     del->setFlow(flow);
 
     // Reset the minimum and maximum sizes.
+
     setMinimumSize(QSize(0, 0));
     setMaximumSize(QSize(QWIDGETSIZE_MAX, QWIDGETSIZE_MAX));
 
     // Adjust minimum and maximum width to thumbnail sizes.
+
     if (flow == TopToBottom)
     {
         int viewportFullWidgetOffset = size().width() - viewport()->size().width();
@@ -186,7 +193,7 @@ void ItemThumbnailBar::assignRating(const QList<QModelIndex>& indexes, int ratin
 {
     ItemInfoList infos(imageSortFilterModel()->imageInfos(indexes));
 
-    if (needGroupResolving(ApplicationSettings::Metadata, infos))
+    if (needGroupResolving(MetadataOps, infos))
     {
         infos = resolveGrouping(infos);
     }
@@ -197,7 +204,8 @@ void ItemThumbnailBar::assignRating(const QList<QModelIndex>& indexes, int ratin
 bool ItemThumbnailBar::event(QEvent* e)
 {
     // reset widget max/min sizes
-    if (e->type() == QEvent::StyleChange || e->type() == QEvent::Show)
+
+    if ((e->type() == QEvent::StyleChange) || (e->type() == QEvent::Show))
     {
         setFlow(flow());
     }
@@ -227,9 +235,11 @@ QModelIndex ItemThumbnailBar::lastIndex() const
 
 bool ItemThumbnailBar::hasHiddenGroupedImages(const ItemInfo& info) const
 {
-    return (info.hasGroupedImages()                &&
+    return (
+            info.hasGroupedImages()                &&
             !imageFilterModel()->isAllGroupsOpen() &&
-            !imageFilterModel()->isGroupOpen(info.id()));
+            !imageFilterModel()->isGroupOpen(info.id())
+           );
 }
 
 } // namespace Digikam
