@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ITEM_THUMBNAIL_DELEGATE_P_H
-#define DIGIKAM_ITEM_THUMBNAIL_DELEGATE_P_H
+#pragma once
 
 // Qt includes
 
@@ -32,20 +31,21 @@ class Q_DECL_HIDDEN ItemThumbnailDelegatePrivate : public ItemDelegate::ItemDele
 {
 public:
 
-    explicit ItemThumbnailDelegatePrivate()
-        : flow(QListView::LeftToRight)
+    ItemThumbnailDelegatePrivate()
     {
           // switch off drawing of frames
+
           drawMouseOverFrame  = false;
           drawFocusFrame      = false;
 
           // switch off composing rating over background
+
           ratingOverThumbnail = true;
     }
 
 public:
 
-    QListView::Flow flow;
+    QListView::Flow flow    = QListView::LeftToRight;
     QRect           viewSize;
 
 public:
@@ -54,5 +54,3 @@ public:
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_ITEMS_THUMBNAIL_DELEGATE_P_H
