@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ITEM_CATEGORY_DRAWER_H
-#define DIGIKAM_ITEM_CATEGORY_DRAWER_H
+#pragma once
 
 // Local includes
 
@@ -64,9 +63,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_ITEM_CATEGORY_DRAWER_H
