@@ -6,14 +6,13 @@
  * Date        : 2008-12-10
  * Description : album icon view tool tip
  *
- * SPDX-FileCopyrightText: 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_TOOL_TIP_FILLER_H
-#define DIGIKAM_TOOL_TIP_FILLER_H
+#pragma once
 
 // Qt includes
 
@@ -36,5 +35,3 @@ namespace ToolTipFiller
 } // namespace ToolTipFiller
 
 } // namespace Digikam
-
-#endif // DIGIKAM_TOOL_TIP_FILLER_H
