@@ -7,7 +7,7 @@
  * Description : Qt model-view for items
  *
  * SPDX-FileCopyrightText: 2009-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2011      by Andi Clemens <andi dot clemens at gmail dot com>
  * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
  * SPDX-FileCopyrightText: 2014      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
@@ -36,7 +36,6 @@
 #include "coredboperationgroup.h"
 #include "advancedrenamedialog.h"
 #include "advancedrenameprocessdialog.h"
-#include "applicationsettings.h"
 #include "assignnameoverlay.h"
 #include "contextmenuhelper.h"
 #include "coredbaccess.h"
@@ -53,7 +52,6 @@
 #include "itemfullscreenoverlay.h"
 #include "itemcoordinatesoverlay.h"
 #include "tagslineeditoverlay.h"
-#include "itemviewutilities.h"
 #include "imagewindow.h"
 #include "fileactionmngr.h"
 #include "fileactionprogress.h"
@@ -232,11 +230,11 @@ void DigikamItemView::dragDropSort(const ItemInfo& pick, const QList<ItemInfo>&
     CoreDbOperationGroup group;
     group.setMaximumTime(200);
 
-    Q_FOREACH (ItemInfo info, infoList)
+    for (ItemInfo info : std::as_const(infoList))
     {
         if      (!found && info.id() == pick.id())
         {
-            Q_FOREACH (ItemInfo dropInfo, infos)
+            for (ItemInfo dropInfo : std::as_const(infos))
             {
                 dropInfo.setManualOrder(counter);
                 counter += (order ? 1 : -1);
@@ -247,8 +245,10 @@ void DigikamItemView::dragDropSort(const ItemInfo& pick, const QList<ItemInfo>&
         }
         else if (found && !infos.contains(info))
         {
-            if (( order && info.manualOrder() > counter) ||
-                (!order && info.manualOrder() < counter))
+            if (
+                ( order && info.manualOrder() > counter) ||
+                (!order && info.manualOrder() < counter)
+               )
             {
                 break;
             }
@@ -265,12 +265,12 @@ void DigikamItemView::dragDropSort(const ItemInfo& pick, const QList<ItemInfo>&
     imageFilterModel()->invalidate();
  }
 
-bool DigikamItemView::allNeedGroupResolving(const ApplicationSettings::OperationType type) const
+bool DigikamItemView::allNeedGroupResolving(const OperationType type) const
 {
     return needGroupResolving(type, allItemInfos());
 }
 
-bool DigikamItemView::selectedNeedGroupResolving(const ApplicationSettings::OperationType type) const
+bool DigikamItemView::selectedNeedGroupResolving(const OperationType type) const
 {
     return needGroupResolving(type, selectedItemInfos());
 }
@@ -283,6 +283,7 @@ int DigikamItemView::fitToWidthIcons()
 void DigikamItemView::slotSetupChanged()
 {
     imageFilterModel()->setStringTypeNatural(ApplicationSettings::instance()->isStringTypeNatural());
+    setInitialSelectedItem(ApplicationSettings::instance()->getSelectFirstAlbumItem());
     setToolTipEnabled(ApplicationSettings::instance()->showToolTipsIsValid());
     setFont(ApplicationSettings::instance()->getIconViewFont());
 
@@ -299,7 +300,7 @@ bool DigikamItemView::hasHiddenGroupedImages(const ItemInfo& info) const
 }
 
 ItemInfoList DigikamItemView::imageInfos(const QList<QModelIndex>& indexes,
-                                         ApplicationSettings::OperationType type) const
+                                         OperationType type) const
 {
     ItemInfoList infos = ItemCategorizedView::imageInfos(indexes);
 
@@ -419,24 +420,27 @@ void DigikamItemView::confirmFaces(const QList<QModelIndex>& indexes, int tagId)
         needFastRemove = (d->faceMode && (tagId != album->id()));
     }
 
-    Q_FOREACH (const QModelIndex& index, indexes)
+    for (const QModelIndex& index : std::as_const(indexes))
     {
-        faces << d->faceDelegate->face(index);
-        infos << ItemModel::retrieveItemInfo(index);
-
-        if (needFastRemove)
+        if (index.isValid())
         {
-            sourceIndexes << imageSortFilterModel()->mapToSourceItemModel(index);
+            faces << d->faceDelegate->face(index);
+            infos << ItemModel::retrieveItemInfo(index);
+
+            if (needFastRemove)
+            {
+                sourceIndexes << imageSortFilterModel()->mapToSourceItemModel(index);
+            }
         }
     }
 
-    imageAlbumModel()->removeIndexes(sourceIndexes);
-
     for (int i = 0 ; i < infos.size() ; ++i)
     {
         d->editPipeline.confirm(infos[i], faces[i], tagId);
     }
 
+    imageAlbumModel()->removeIndexes(sourceIndexes);
+
     clearSelection();
 }
 
@@ -446,20 +450,23 @@ void DigikamItemView::removeFaces(const QList<QModelIndex>& indexes)
     QList<FaceTagsIface> faces;
     QList<QModelIndex> sourceIndexes;
 
-    Q_FOREACH (const QModelIndex& index, indexes)
+    for (const QModelIndex& index : std::as_const(indexes))
     {
-        faces         << d->faceDelegate->face(index);
-        infos         << ItemModel::retrieveItemInfo(index);
-        sourceIndexes << imageSortFilterModel()->mapToSourceItemModel(index);
+        if (index.isValid())
+        {
+            faces         << d->faceDelegate->face(index);
+            infos         << ItemModel::retrieveItemInfo(index);
+            sourceIndexes << imageSortFilterModel()->mapToSourceItemModel(index);
+        }
     }
 
-    imageAlbumModel()->removeIndexes(sourceIndexes);
-
     for (int i = 0 ; i < infos.size() ; ++i)
     {
         d->editPipeline.remove(infos[i], faces[i]);
     }
 
+    imageAlbumModel()->removeIndexes(sourceIndexes);
+
     clearSelection();
 }
 
@@ -469,21 +476,24 @@ void DigikamItemView::unknownFaces(const QList<QModelIndex>& indexes)
     QList<FaceTagsIface> faces;
     QList<QModelIndex> sourceIndexes;
 
-    Q_FOREACH (const QModelIndex& index, indexes)
+    for (const QModelIndex& index : std::as_const(indexes))
     {
-        faces         << d->faceDelegate->face(index);
-        infos         << ItemModel::retrieveItemInfo(index);
-        sourceIndexes << imageSortFilterModel()->mapToSourceItemModel(index);
+        if (index.isValid())
+        {
+            faces         << d->faceDelegate->face(index);
+            infos         << ItemModel::retrieveItemInfo(index);
+            sourceIndexes << imageSortFilterModel()->mapToSourceItemModel(index);
+        }
     }
 
-    imageAlbumModel()->removeIndexes(sourceIndexes);
-
     for (int i = 0 ; i < infos.size() ; ++i)
     {
         d->editPipeline.editTag(infos[i], faces[i],
                                 FaceTags::unknownPersonTagId());
     }
 
+    imageAlbumModel()->removeIndexes(sourceIndexes);
+
     clearSelection();
 }
 
@@ -493,15 +503,16 @@ void DigikamItemView::rejectFaces(const QList<QModelIndex>& indexes)
     QList<FaceTagsIface> faces;
     QList<QModelIndex> sourceIndexes;
 
-    Q_FOREACH (const QModelIndex& index, indexes)
+    for (const QModelIndex& index : std::as_const(indexes))
     {
-        faces         << d->faceDelegate->face(index);
-        infos         << ItemModel::retrieveItemInfo(index);
-        sourceIndexes << imageSortFilterModel()->mapToSourceItemModel(index);
+        if (index.isValid())
+        {
+            faces         << d->faceDelegate->face(index);
+            infos         << ItemModel::retrieveItemInfo(index);
+            sourceIndexes << imageSortFilterModel()->mapToSourceItemModel(index);
+        }
     }
 
-    imageAlbumModel()->removeIndexes(sourceIndexes);
-
     for (int i = 0 ; i < infos.size() ; ++i)
     {
         if      (FaceTags::isTheUnknownPerson(faces[i].tagId()))
@@ -524,6 +535,8 @@ void DigikamItemView::rejectFaces(const QList<QModelIndex>& indexes)
         }
     }
 
+    imageAlbumModel()->removeIndexes(sourceIndexes);
+
     clearSelection();
 }
 
@@ -533,21 +546,24 @@ void DigikamItemView::ignoreFaces(const QList<QModelIndex>& indexes)
     QList<FaceTagsIface> faces;
     QList<QModelIndex> sourceIndexes;
 
-    Q_FOREACH (const QModelIndex& index, indexes)
+    for (const QModelIndex& index : std::as_const(indexes))
     {
-        faces         << d->faceDelegate->face(index);
-        infos         << ItemModel::retrieveItemInfo(index);
-        sourceIndexes << imageSortFilterModel()->mapToSourceItemModel(index);
+        if (index.isValid())
+        {
+            faces         << d->faceDelegate->face(index);
+            infos         << ItemModel::retrieveItemInfo(index);
+            sourceIndexes << imageSortFilterModel()->mapToSourceItemModel(index);
+        }
     }
 
-    imageAlbumModel()->removeIndexes(sourceIndexes);
-
     for (int i = 0 ; i < infos.size() ; ++i)
     {
         d->editPipeline.editTag(infos[i], faces[i],
                                 FaceTags::ignoredPersonTagId());
     }
 
+    imageAlbumModel()->removeIndexes(sourceIndexes);
+
     clearSelection();
 }
 
@@ -555,9 +571,12 @@ QList<int> DigikamItemView::getFaceIds(const QList<QModelIndex>& indexes) const
 {
     QList<int> ids;
 
-    Q_FOREACH (const QModelIndex& index, indexes)
+    for (const QModelIndex& index : std::as_const(indexes))
     {
-        ids << d->faceDelegate->face(index).tagId();
+        if (index.isValid())
+        {
+            ids << d->faceDelegate->face(index).tagId();
+        }
     }
 
     return ids;
@@ -605,6 +624,7 @@ void DigikamItemView::showContextMenuOnInfo(QContextMenuEvent* event, const Item
 void DigikamItemView::showGroupContextMenu(const QModelIndex& index, QContextMenuEvent* event)
 {
     Q_UNUSED(index);
+
     Q_EMIT signalShowGroupContextMenu(event, selectedItemInfosCurrentFirst(), imageFilterModel());
 }
 
@@ -638,7 +658,7 @@ void DigikamItemView::deleteSelectedDirectly(const ItemViewUtilities::DeleteMode
 
 void DigikamItemView::assignRating(const QList<QModelIndex>& indexes, int rating)
 {
-    ItemInfoList infos = imageInfos(indexes, ApplicationSettings::Metadata);
+    ItemInfoList infos = imageInfos(indexes, MetadataOps);
     FileActionMngr::instance()->assignRating(infos, rating);
 }
 
@@ -660,7 +680,7 @@ void DigikamItemView::rename()
 {
     ItemInfoList infos = selectedItemInfos();
 
-    if (needGroupResolving(ApplicationSettings::Rename, infos))
+    if (needGroupResolving(RenameOps, infos))
     {
         infos = resolveGrouping(infos);
     }
@@ -710,19 +730,19 @@ void DigikamItemView::rename()
 
 void DigikamItemView::slotRotateLeft(const QList<QModelIndex>& indexes)
 {
-    ItemInfoList infos = imageInfos(indexes, ApplicationSettings::Metadata);
+    ItemInfoList infos = imageInfos(indexes, MetadataOps);
     FileActionMngr::instance()->transform(infos, MetaEngineRotation::Rotate270);
 }
 
 void DigikamItemView::slotRotateRight(const QList<QModelIndex>& indexes)
 {
-    ItemInfoList infos = imageInfos(indexes, ApplicationSettings::Metadata);
+    ItemInfoList infos = imageInfos(indexes, MetadataOps);
     FileActionMngr::instance()->transform(infos, MetaEngineRotation::Rotate90);
 }
 
 void DigikamItemView::slotFullscreen(const QList<QModelIndex>& indexes)
 {
-   QList<ItemInfo> infos = imageInfos(indexes, ApplicationSettings::Slideshow);
+   QList<ItemInfo> infos = imageInfos(indexes, SlideshowOps);
 
    if (infos.isEmpty())
    {
@@ -734,8 +754,8 @@ void DigikamItemView::slotFullscreen(const QList<QModelIndex>& indexes)
    const ItemInfo& info = infos.at(0);
 
    QList<DPluginAction*> actions = DPluginLoader::instance()->
-                                      pluginActions(QLatin1String("org.kde.digikam.plugin.generic.SlideShow"),
-                                      DigikamApp::instance());
+                                   pluginActions(QLatin1String("org.kde.digikam.plugin.generic.SlideShow"),
+                                   DigikamApp::instance());
 
    if (actions.isEmpty())
    {
@@ -782,3 +802,5 @@ void DigikamItemView::scrollTo(const QModelIndex& index, ScrollHint hint)
 }
 
 } // namespace Digikam
+
+#include "moc_digikamitemview.cpp"
