@@ -6,27 +6,18 @@
  * Date        : 2009-04-24
  * Description : Qt model-view for items
  *
- * Copyright (C) 2009-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DIGIKAMITEM_VIEW_H
-#define DIGIKAM_DIGIKAMITEM_VIEW_H
+#pragma once
 
 // Local includes
 
+#include "digikam_globals.h"
 #include "applicationsettings.h"
 #include "itemcategorizedview.h"
 #include "itemviewutilities.h"
@@ -52,14 +43,15 @@ public:
 
     int  fitToWidthIcons();
     bool getFaceMode()                                                                       const;
+    QList<int> getFaceIds(const QList<QModelIndex>& indexes)                                 const;
 
     void setThumbnailSize(const ThumbnailSize& size)                                               override;
 
     ItemInfoList  allItemInfos(bool grouping = false)                                        const;
     ItemInfoList  selectedItemInfos(bool grouping = false)                                   const;
     ItemInfoList  selectedItemInfosCurrentFirst(bool grouping = false)                       const;
-    bool          allNeedGroupResolving(const ApplicationSettings::OperationType type)       const;
-    bool          selectedNeedGroupResolving(const ApplicationSettings::OperationType type)  const;
+    bool          allNeedGroupResolving(const OperationType type)       const;
+    bool          selectedNeedGroupResolving(const OperationType type)  const;
 
 public Q_SLOTS:
 
@@ -109,7 +101,6 @@ public Q_SLOTS:
      */
     void ignoreFaces(const QList<QModelIndex>& indexes);
 
-    QList<int> getFaceIds(const QList<QModelIndex>& indexes)             const;
 
     void dragDropSort(const ItemInfo& pick, const QList<ItemInfo>& infos);
 
@@ -146,7 +137,7 @@ protected:
     bool hasHiddenGroupedImages(const ItemInfo& info)                    const override;
 
     ItemInfoList imageInfos(const QList<QModelIndex>& indexes,
-                            ApplicationSettings::OperationType type)     const;
+                            OperationType type)     const;
 
 private Q_SLOTS:
 
@@ -159,9 +150,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_DIGIKAMITEM_VIEW_H
