@@ -7,7 +7,7 @@
  * Description : Private Qt model-view for items
  *
  * SPDX-FileCopyrightText: 2009-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2009      by Johannes Wienke <languitar at semipol do de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -24,20 +24,7 @@ namespace Digikam
 {
 
 DigikamItemView::Private::Private(DigikamItemView* const qq)
-    : utilities          (nullptr),
-      normalDelegate     (nullptr),
-      faceDelegate       (nullptr),
-      overlaysActive     (false),
-      fullscreenActive   (false),
-      rotateLeftOverlay  (nullptr),
-      rotateRightOverlay (nullptr),
-      fullscreenOverlay  (nullptr),
-      faceMode           (false),
-      q_ptr              (qq)
-{
-}
-
-DigikamItemView::Private::~Private()
+    : q_ptr(qq)
 {
 }
 
@@ -107,3 +94,5 @@ void DigikamItemView::Private::updateOverlays()
 }
 
 } // namespace Digikam
+
+#include "moc_digikamitemview_p.cpp"
