@@ -7,15 +7,14 @@
  * Description : Private Qt model-view for items
  *
  * SPDX-FileCopyrightText: 2009-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2009-2010 by Johannes Wienke <languitar at semipol do de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DIGIKAMITEM_VIEW_P_H
-#define DIGIKAM_DIGIKAMITEM_VIEW_P_H
+#pragma once
 
 // Qt includes
 
@@ -45,32 +44,32 @@ class Q_DECL_HIDDEN DigikamItemView::Private : public QObject
 public:
 
     explicit Private(DigikamItemView* const qq);
-    ~Private() override;
+    ~Private() override = default;
 
     void updateOverlays();
     void triggerRotateAction(const char* actionName);
 
 public:
 
-    ItemViewUtilities*       utilities;
+    ItemViewUtilities*       utilities          = nullptr;
 
     FacePipeline             editPipeline;
 
-    DigikamItemDelegate*     normalDelegate;
-    ItemFaceDelegate*        faceDelegate;
+    DigikamItemDelegate*     normalDelegate     = nullptr;
+    ItemFaceDelegate*        faceDelegate       = nullptr;
 
-    bool                     overlaysActive;
-    bool                     fullscreenActive;
+    bool                     overlaysActive     = false;
+    bool                     fullscreenActive   = false;
 
-    ItemRotateOverlay*       rotateLeftOverlay;
-    ItemRotateOverlay*       rotateRightOverlay;
-    ItemFullScreenOverlay*   fullscreenOverlay;
+    ItemRotateOverlay*       rotateLeftOverlay  = nullptr;
+    ItemRotateOverlay*       rotateRightOverlay = nullptr;
+    ItemFullScreenOverlay*   fullscreenOverlay  = nullptr;
 
-    bool                     faceMode;
+    bool                     faceMode           = false;
 
 private:
 
-    DigikamItemView*         q_ptr;
+    DigikamItemView*         q_ptr              = nullptr;
 
 private:
 
@@ -79,5 +78,3 @@ private:
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_DIGIKAMITEM_VIEW_P_H
