@@ -11,7 +11,7 @@
  * SPDX-FileCopyrightText: 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
  * SPDX-FileCopyrightText:      2013 by Michael G. Hansen <mike at mghansen dot de>
  * SPDX-FileCopyrightText: 2014-2015 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
- * SPDX-FileCopyrightText: 2002-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2002-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -33,6 +33,12 @@ DigikamApp::DigikamApp()
     setFullScreenOptions(FS_ALBUMGUI);
     setXMLFile(QLatin1String("digikamui5.rc"));
 
+#if (KXMLGUI_VERSION >= QT_VERSION_CHECK(5, 88, 0))
+
+    setStateConfigGroup(configGroupName());
+
+#endif
+
     m_instance         = this;
     d->config          = KSharedConfig::openConfig();
     KConfigGroup group = d->config->group(configGroupName());
@@ -52,14 +58,16 @@ DigikamApp::DigikamApp()
         ScanController::instance()->completeCollectionScanDeferFiles();
     }
 
-    if (ApplicationSettings::instance()->getShowSplashScreen() &&
-        !qApp->isSessionRestored())
+    if (
+        ApplicationSettings::instance()->getShowSplashScreen() &&
+        !qApp->isSessionRestored()
+       )
     {
         d->splashScreen = new DSplashScreen();
         d->splashScreen->show();
     }
 
-    // We need here QCoreApplication::processEvents().
+    // We need here QCoreApplication::processEvents() ?
 
     qApp->processEvents();
 
@@ -70,6 +78,7 @@ DigikamApp::DigikamApp()
 
     // Ensure creation
 
+    DNNModelManager::instance();
     AlbumManager::instance();
     LoadingCacheInterface::initialize();
     IccSettings::instance()->loadAllProfilesProperties();
@@ -81,8 +90,21 @@ DigikamApp::DigikamApp()
     LocalizeSettings::instance();
     NetworkManager::instance();
 
+#ifdef HAVE_GEOLOCATION
+
+    connect(GeolocationSettings::instance(), &GeolocationSettings::signalSetupGeolocation,
+            this, [this](int tab)
+        {
+            Setup::execGeolocation(this, tab);
+        }
+    );
+
+    qCDebug(DIGIKAM_GENERAL_LOG) << GeolocationSettings::instance()->settings();
+
+#endif
+
     connect(LocalizeSettings::instance(), &LocalizeSettings::signalOpenLocalizeSetup,
-            this, [=]()
+            this, [this]()
         {
             Setup::execLocalize(this);
         }
@@ -148,7 +170,6 @@ DigikamApp::DigikamApp()
     initGui();
 
     setupViewConnections();
-    applyMainWindowSettings(group);
     slotColorManagementOptionsChanged();
 
     // Check ICC profiles repository availability
@@ -162,8 +183,10 @@ DigikamApp::DigikamApp()
 
     // Clean up database if enabled in the settings
 
-    if (ApplicationSettings::instance()->getCleanAtStart() &&
-        CollectionScanner::databaseInitialScanDone())
+    if (
+        ApplicationSettings::instance()->getCleanAtStart() &&
+        CollectionScanner::databaseInitialScanDone()
+       )
     {
         if (d->splashScreen)
         {
@@ -181,6 +204,10 @@ DigikamApp::DigikamApp()
         loop.exec();
     }
 
+    // Build trash counters from all collections
+
+    DIO::buildCollectionTrashCounters();
+
     // Read albums from database
 
     if (d->splashScreen)
@@ -208,15 +235,16 @@ DigikamApp::DigikamApp()
 
     // Create BalooWrap object, because it need to register a listener
     // to update digiKam data when changes in Baloo occur
+
     BalooWrap* const baloo = BalooWrap::instance();
     Q_UNUSED(baloo);
 
-#endif //HAVE_KFILEMETADATA
-
-    setAutoSaveSettings(group, true);
+#endif // HAVE_KFILEMETADATA
 
     LoadSaveThread::setInfoProvider(new DatabaseLoadSaveFileInfoProvider);
 
+    setAutoSaveSettings(configGroupName(), true);
+
     setupSelectToolsAction();
 }
 
@@ -257,8 +285,8 @@ DigikamApp::~DigikamApp()
 
     if (TagsManager::isCreated())
     {
-        TagsManager::instance()->setAttribute(Qt::WA_DeleteOnClose, true);
         TagsManager::instance()->close();
+        delete TagsManager::internalPtr;
     }
 
     if (MetadataHubMngr::isCreated())
@@ -361,8 +389,10 @@ void DigikamApp::show()
 
     // Enable finished the collection scan as deferred process
 
-    if (settings->getScanAtStart()                  ||
-        !CollectionScanner::databaseInitialScanDone())
+    if (
+        settings->getScanAtStart()                  ||
+        !CollectionScanner::databaseInitialScanDone()
+       )
     {
         NewItemsFinder* const tool = new NewItemsFinder(NewItemsFinder::ScanDeferredFiles);
 
@@ -380,6 +410,19 @@ void DigikamApp::show()
         delete d->splashScreen;
         d->splashScreen = nullptr;
     }
+
+    QScopedPointer<ExifToolParser> const parser(new ExifToolParser(nullptr));
+
+    if (!parser->exifToolAvailable())
+    {
+        QString msg = i18n("ExifTool is not available in your digiKam installation or "
+                           "is not working correctly. Go to the digiKam settings and "
+                           "check the availability of the ExifTool binary file in "
+                           "the metadata section.\nError message: %1",
+                           parser->currentErrorString());
+
+        Q_EMIT signalNotificationError(msg, DNotificationWidget::Warning);
+    }
 }
 
 void DigikamApp::restoreSession()
@@ -630,13 +673,13 @@ void DigikamApp::slotImageSelected(const ItemInfoList& selection, const ItemInfo
 
     ItemInfoList selectionWithoutGrouped = d->view->selectedInfoList(true, false);
 
-    Q_FOREACH (const ItemInfo& info, selection)
+    for (const ItemInfo& info : std::as_const(selection))
     {
         // cppcheck-suppress useStlAlgorithm
         selectionFileSize += info.fileSize();
     }
 
-    Q_FOREACH (const ItemInfo& info, listAll)
+    for (const ItemInfo& info : std::as_const(listAll))
     {
         // cppcheck-suppress useStlAlgorithm
         listAllFileSize += info.fileSize();
@@ -821,8 +864,9 @@ void DigikamApp::slotSelectionChanged(int selectionCount)
     d->copyItemsAction->setEnabled(selectionCount > 0);
     d->openWithAction->setEnabled(selectionCount > 0);
     d->imageAutoExifActionMenu->setEnabled(selectionCount > 0);
+    const auto acs = DPluginLoader::instance()->pluginsActions(DPluginAction::GenericMetadata, this);
 
-    Q_FOREACH (DPluginAction* const ac, DPluginLoader::instance()->pluginsActions(DPluginAction::GenericMetadata, this))
+    for (DPluginAction* const ac : acs)
     {
         ac->setEnabled(selectionCount > 0);
     }
@@ -949,40 +993,58 @@ void DigikamApp::slotSetCheckedExifOrientationAction(const ItemInfo& info)
     switch (orientation)
     {
         case 1:
+        {
             d->imageSetExifOrientation1Action->setChecked(true);
             break;
+        }
 
         case 2:
+        {
             d->imageSetExifOrientation2Action->setChecked(true);
             break;
+        }
 
         case 3:
+        {
             d->imageSetExifOrientation3Action->setChecked(true);
             break;
+        }
 
         case 4:
+        {
             d->imageSetExifOrientation4Action->setChecked(true);
             break;
+        }
 
         case 5:
+        {
             d->imageSetExifOrientation5Action->setChecked(true);
             break;
+        }
 
         case 6:
+        {
             d->imageSetExifOrientation6Action->setChecked(true);
             break;
+        }
 
         case 7:
+        {
             d->imageSetExifOrientation7Action->setChecked(true);
             break;
+        }
 
         case 8:
+        {
             d->imageSetExifOrientation8Action->setChecked(true);
             break;
+        }
 
         default:
+        {
             slotResetExifOrientationActions();
             break;
+        }
     }
 }
 
@@ -1054,11 +1116,11 @@ void DigikamApp::slotSwitchedToMapView()
 
     d->zoomBar->setBarMode(DZoomBar::ThumbsSizeCtrl);
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
     d->imageMapViewAction->setChecked(true);
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
     customizedTrashView(true);
     toggleShowBar();
@@ -1096,7 +1158,7 @@ void DigikamApp::customizedTrashView(bool set)
     d->imageTableViewAction->setEnabled(set);
     d->imageIconViewAction->setEnabled(set);
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
     d->imageMapViewAction->setEnabled(set);
 
@@ -1117,8 +1179,9 @@ void DigikamApp::customizedTrashView(bool set)
     d->recurseAlbumsAction->setEnabled(set);
     d->recurseTagsAction->setEnabled(set);
     d->refreshAction->setEnabled(set);
+    const auto acs = DPluginLoader::instance()->pluginsActions(DPluginAction::GenericView, this);
 
-    Q_FOREACH (DPluginAction* const ac, DPluginLoader::instance()->pluginsActions(DPluginAction::GenericView, this))
+    for (DPluginAction* const ac : acs)
     {
         ac->setEnabled(set);
     }
@@ -1130,12 +1193,16 @@ void DigikamApp::toggleShowBar()
     {
         case StackedView::PreviewImageMode:
         case StackedView::MediaPlayerMode:
+        {
             d->showBarAction->setEnabled(true);
             break;
+        }
 
         default:
+        {
             d->showBarAction->setEnabled(false);
             break;
+        }
     }
 }
 
@@ -1174,29 +1241,39 @@ void DigikamApp::slotColorManagementOptionsChanged()
 
 DInfoInterface* DigikamApp::infoIface(DPluginAction* const ac)
 {
-    ApplicationSettings::OperationType aset = ApplicationSettings::Unspecified;
+    OperationType aset = UnspecifiedOps;
 
     switch (ac->actionCategory())
     {
         case DPluginAction::GenericExport:
         case DPluginAction::GenericImport:
-            aset = ApplicationSettings::ImportExport;
+        {
+            aset = ImportExportOps;
             break;
+        }
 
         case DPluginAction::GenericMetadata:
-            aset = ApplicationSettings::Metadata;
+        {
+            aset = MetadataOps;
             break;
+        }
 
         case DPluginAction::GenericTool:
-            aset = ApplicationSettings::Tools;
+        {
+            aset = ToolsOps;
             break;
+        }
 
         case DPluginAction::GenericView:
-            aset = ApplicationSettings::Slideshow;
+        {
+            aset = SlideshowOps;
             break;
+        }
 
         default:
+        {
             break;
+        }
     }
 
     DBInfoIface* const iface = new DBInfoIface(this, QList<QUrl>(), aset);
@@ -1204,7 +1281,7 @@ DInfoInterface* DigikamApp::infoIface(DPluginAction* const ac)
     connect(iface, SIGNAL(signalImportedImage(QUrl)),
             this, SLOT(slotImportedImagefromScanner(QUrl)));
 
-    if (aset == ApplicationSettings::Slideshow)
+    if (aset == SlideshowOps)
     {
         connect(iface, SIGNAL(signalLastItemUrl(QUrl)),
                 d->view, SLOT(slotSetCurrentUrlWhenAvailable(QUrl)));
@@ -1214,3 +1291,5 @@ DInfoInterface* DigikamApp::infoIface(DPluginAction* const ac)
 }
 
 } // namespace Digikam
+
+#include "moc_digikamapp.cpp"
