@@ -6,27 +6,17 @@
  * Date        : 2002-16-10
  * Description : main digiKam interface implementation
  *
- * Copyright (C) 2002-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C)      2006 by Tom Albers <tomalbers at kde dot nl>
- * Copyright (C) 2002-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2009-2011 by Andi Clemens <andi dot clemens at gmail dot com>
- * Copyright (C)      2013 by Michael G. Hansen <mike at mghansen dot de>
+ * SPDX-FileCopyrightText: 2002-2005 by Renchi Raju <renchi dot raju at gmail dot com>
+ * SPDX-FileCopyrightText:      2006 by Tom Albers <tomalbers at kde dot nl>
+ * SPDX-FileCopyrightText: 2002-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2011 by Andi Clemens <andi dot clemens at gmail dot com>
+ * SPDX-FileCopyrightText:      2013 by Michael G. Hansen <mike at mghansen dot de>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_APP_H
-#define DIGIKAM_APP_H
+#pragma once
 
 // Qt includes
 
@@ -89,6 +79,7 @@ Q_SIGNALS:
     void signalPasteAlbumItemsSelection();
 
     void signalWindowHasMoved();
+    void signalNotificationError(const QString& message, int type);
 
 protected:
 
@@ -272,11 +263,9 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 
     static DigikamApp* m_instance;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_APP_H
