@@ -35,6 +35,7 @@ void DigikamApp::slotSetup()
 void DigikamApp::slotSetupChanged()
 {
     // raw loading options might have changed
+
     LoadingCacheInterface::cleanCache();
 
     // TODO: clear history when location changed
@@ -89,11 +90,24 @@ void DigikamApp::slotThemeChanged()
     ApplicationSettings* const settings = ApplicationSettings::instance();
     QString theme                       = ThemeManager::instance()->currentThemeName();
 
-    if (qApp->activeWindow()                 &&
-        (settings->getCurrentTheme() != theme))
+    if (
+        qApp->activeWindow()                                     &&
+        (settings->getCurrentTheme() != theme)                   &&
+        (
+         (settings->getIconTheme() == QLatin1String(""))         ||
+         (settings->getIconTheme() == QLatin1String("breeze"))   ||
+         (settings->getIconTheme() == QLatin1String("breeze-dark"))
+        )
+       )
     {
         qApp->processEvents();
 
+#if defined HAVE_KICONTHEMES && (KICONTHEMES_VERSION >= QT_VERSION_CHECK(6, 3, 0))
+
+        settings->setIconTheme(QString());
+
+#else
+
         QColor color = qApp->palette().color(qApp->activeWindow()->backgroundRole());
         QString iconTheme;
         QString msgText;
@@ -122,6 +136,9 @@ void DigikamApp::slotThemeChanged()
 
             settings->setIconTheme(iconTheme);
         }
+
+#endif
+
     }
 
     settings->setCurrentTheme(theme);
