@@ -6,7 +6,7 @@
  * Date        : 2002-16-10
  * Description : main digiKam interface implementation - Internal setup
  *
- * SPDX-FileCopyrightText: 2002-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2002-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -139,6 +139,8 @@ void DigikamApp::setupActions()
 
 #if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
 
+    d->backwardActionMenu->setMenu(d->backwardActionMenu->popupMenu());
+
     connect(d->backwardActionMenu->popupMenu(), SIGNAL(aboutToShow()),
             this, SLOT(slotAboutToShowBackwardMenu()));
 
@@ -162,6 +164,8 @@ void DigikamApp::setupActions()
 
 #if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
 
+    d->forwardActionMenu->setMenu(d->forwardActionMenu->popupMenu());
+
     connect(d->forwardActionMenu->popupMenu(), SIGNAL(aboutToShow()),
             this, SLOT(slotAboutToShowForwardMenu()));
 
@@ -186,7 +190,9 @@ void DigikamApp::setupActions()
 
     // -----------------------------------------------------------------
 
-    Q_FOREACH (SidebarWidget* const leftWidget, d->view->leftSidebarWidgets())
+    const auto wdgs = d->view->leftSidebarWidgets();
+
+    for (SidebarWidget* const leftWidget : wdgs)
     {
         QString actionName = QLatin1String("browse_") + leftWidget->objectName()
                                                         .remove(QLatin1Char(' '))
@@ -338,7 +344,7 @@ void DigikamApp::setupActions()
     connect(d->imagePreviewAction, SIGNAL(triggered()), d->view, SLOT(slotImagePreview()));
     d->imageViewSelectionAction->addAction(d->imagePreviewAction);
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
     d->imageMapViewAction = new QAction(QIcon::fromTheme(QLatin1String("globe")),
                                         i18nc("@action: Switch to map view", "Map"), this);
@@ -347,7 +353,7 @@ void DigikamApp::setupActions()
     connect(d->imageMapViewAction, SIGNAL(triggered()), d->view, SLOT(slotMapWidgetView()));
     d->imageViewSelectionAction->addAction(d->imageMapViewAction);
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
     d->imageTableViewAction = new QAction(QIcon::fromTheme(QLatin1String("view-list-details")),
                                           i18nc("@action: Switch to table view", "Table"), this);
@@ -1147,7 +1153,9 @@ void DigikamApp::initGui()
     d->openWithAction->setEnabled(false);
     d->imageAutoExifActionMenu->setEnabled(false);
 
-    Q_FOREACH (DPluginAction* const ac, DPluginLoader::instance()->pluginsActions(DPluginAction::GenericMetadata, this))
+    const auto acs = DPluginLoader::instance()->pluginsActions(DPluginAction::GenericMetadata, this);
+
+    for (DPluginAction* const ac : acs)
     {
         ac->setEnabled(false);
     }
