@@ -6,7 +6,7 @@
  * Date        : 2002-16-10
  * Description : main digiKam interface implementation - Solid API based methods
  *
- * SPDX-FileCopyrightText: 2002-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2002-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -59,8 +59,10 @@ bool s_checkSolidCamera(const Solid::Device& cameraDevice)
 
     // We handle gphoto2 cameras in this loop
 
-    if (!(camera->supportedDrivers().contains(QLatin1String("gphoto")) ||
-        camera->supportedProtocols().contains(QLatin1String("ptp"))))
+    if (
+        !(camera->supportedDrivers().contains(QLatin1String("gphoto")) ||
+        camera->supportedProtocols().contains(QLatin1String("ptp")))
+       )
     {
         return false;
     }
@@ -84,21 +86,23 @@ bool s_checkSolidCamera(const Solid::Device& cameraDevice)
 
     QList<QVariant> driverHandleList = driverHandle.toList();
 
-    if ((driverHandleList.size() < 3)                                  ||
+    if (
+        (driverHandleList.size() < 3)                                  ||
         (driverHandleList.at(0).toString() != QLatin1String("usb"))    ||
 
 #if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
 
         !driverHandleList.at(1).canConvert(QMetaType(QMetaType::Int))  ||
-        !driverHandleList.at(2).canConvert(QMetaType(QMetaType::Int)))
+        !driverHandleList.at(2).canConvert(QMetaType(QMetaType::Int))
 
 #else
 
         !driverHandleList.at(1).canConvert(QMetaType::Int)             ||
-        !driverHandleList.at(2).canConvert(QMetaType::Int))
+        !driverHandleList.at(2).canConvert(QMetaType::Int)
 
 #endif
 
+       )
     {
         qCWarning(DIGIKAM_GENERAL_LOG) << "Solid returns unsupported driver handle for gphoto2";
         return false;
@@ -112,8 +116,10 @@ QString s_labelForSolidCamera(const Solid::Device& cameraDevice)
     QString vendor  = cameraDevice.vendor();
     QString product = cameraDevice.product();
 
-    if (product == QLatin1String("USB Imaging Interface") ||
-        product == QLatin1String("USB Vendor Specific Interface"))
+    if (
+        product == QLatin1String("USB Imaging Interface") ||
+        product == QLatin1String("USB Vendor Specific Interface")
+       )
     {
         Solid::Device parentUsbDevice = cameraDevice.parent();
 
@@ -124,7 +130,7 @@ QString s_labelForSolidCamera(const Solid::Device& cameraDevice)
 
             if (!vendor.isEmpty() && !product.isEmpty())
             {
-                if (vendor == QLatin1String("Canon, Inc."))
+                if      (vendor == QLatin1String("Canon, Inc."))
                 {
                     vendor = QLatin1String("Canon");
 
@@ -155,7 +161,7 @@ QString s_labelForSolidCamera(const Solid::Device& cameraDevice)
         }
     }
 
-    return vendor + QLatin1Char(' ') + product;
+    return (vendor + QLatin1Char(' ') + product);
 }
 
 // --------------------------------------------------------------------------------------------------
@@ -185,7 +191,7 @@ void DigikamApp::fillSolidMenus()
 
     QList<Solid::Device> cameraDevices = Solid::Device::listFromType(Solid::DeviceInterface::Camera);
 
-    Q_FOREACH (const Solid::Device& cameraDevice, cameraDevices)
+    for (const Solid::Device& cameraDevice : std::as_const(cameraDevices))
     {
         // USM camera: will be handled below
 
@@ -229,7 +235,7 @@ void DigikamApp::fillSolidMenus()
 
     QList<Solid::Device> storageDevices = Solid::Device::listFromType(Solid::DeviceInterface::StorageAccess);
 
-    Q_FOREACH (const Solid::Device& accessDevice, storageDevices)
+    for (const Solid::Device& accessDevice : std::as_const(storageDevices))
     {
         // check for StorageAccess
 
@@ -272,32 +278,44 @@ void DigikamApp::fillSolidMenus()
             case Solid::StorageDrive::Floppy:
             case Solid::StorageDrive::Tape:
             default:
+            {
                 continue;
+            }
 
             // accept card readers
 
             case Solid::StorageDrive::CompactFlash:
+            {
                 driveType = i18n("CompactFlash Card Reader");
                 break;
+            }
 
             case Solid::StorageDrive::MemoryStick:
+            {
                 driveType = i18n("Memory Stick Reader");
                 break;
+            }
 
             case Solid::StorageDrive::SmartMedia:
+            {
                 driveType = i18n("SmartMedia Card Reader");
                 break;
+            }
 
             case Solid::StorageDrive::SdMmc:
+            {
                 driveType = i18n("SD / MMC Card Reader");
                 break;
+            }
 
             case Solid::StorageDrive::Xd:
+            {
                 driveType = i18n("xD Card Reader");
                 break;
+            }
 
             case Solid::StorageDrive::HardDisk:
-
+            {
                 // We don't want to list HardDisk partitions, but USB Mass Storage devices.
                 // Don't know what is the exact difference between removable and hotpluggable.
 
@@ -320,6 +338,7 @@ void DigikamApp::fillSolidMenus()
                 {
                     continue;
                 }
+            }
         }
 
         // check for StorageVolume
@@ -556,7 +575,7 @@ void DigikamApp::openSolidCamera(const QString& udi, const QString& cameraLabel)
             return;
         }
 
-        // NOTE: See bug #262296: With KDE 4.6, Solid API return device vendor id
+        // NOTE: See bug #262296: since KDE 4.6, Solid API return device vendor id
         // and product id in hexadecimal strings.
 
         bool ok;
@@ -631,7 +650,7 @@ void DigikamApp::openSolidUsmDevice(const QString& udi, const QString& givenLabe
             // NOTE: Lambda function to not expose whole digiKam to Solid API.
 
             connect(access, &Solid::StorageAccess::setupDone,
-                    this, [=](Solid::ErrorType errorType, QVariant errorData, const QString& /*udi*/)  // clazy:exclude=function-args-by-ref
+                    this, [this](Solid::ErrorType errorType, QVariant errorData, const QString& /*udi*/)  // clazy:exclude=function-args-by-ref
                 {
                     if (!d->eventLoop)
                     {
