@@ -39,6 +39,11 @@
 #include <kmemoryinfo.h>
 #include <kaboutdata.h>
 
+#ifdef HAVE_KICONTHEMES
+#   include <kiconthemes_version.h>
+#   include <KIconTheme>
+#endif
+
 // ImageMagick includes
 
 #ifdef HAVE_IMAGE_MAGICK
@@ -146,30 +151,33 @@ extern "C" MAIN_EXPORT int MAIN_FN(int argc, char** argv)
         QCoreApplication::setAttribute(Qt::AA_UseSoftwareOpenGL);
     }
 
-    // OpenCV crash with face engine with OpenCL support
-    // https://bugs.kde.org/show_bug.cgi?id=423632
-    // https://bugs.kde.org/show_bug.cgi?id=426175
+    QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
 
-    if (system.disableOpenCL)
-    {
-        qputenv("OPENCV_OPENCL_RUNTIME", "disabled");
-        qputenv("OPENCV_OPENCL_DEVICE",  "disabled");
-    }
+    // Common OpenCL rules from digikam_globals.
 
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)) && defined(Q_OS_WIN)
+    setOpenCLEnvironment(system.enableOpenCL);
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+#   ifdef Q_OS_WIN
 
     if (system.disableHWConv)
     {
         qputenv("QT_DISABLE_HW_TEXTURES_CONVERSION", "1");
     }
 
+#   endif
+
     qputenv("QT_MEDIA_BACKEND", system.videoBackend.toLatin1());
 
 #endif
 
-    QGuiApplication::setHighDpiScaleFactorRoundingPolicy(Qt::HighDpiScaleFactorRoundingPolicy::RoundPreferFloor);
 
-    QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
+#if defined HAVE_KICONTHEMES && (KICONTHEMES_VERSION >= QT_VERSION_CHECK(6, 3, 0))
+
+    KIconTheme::initTheme();
+
+#endif
 
     QApplication app(argc, argv);
 
@@ -177,10 +185,13 @@ extern "C" MAIN_EXPORT int MAIN_FN(int argc, char** argv)
 
 #ifdef HAVE_IMAGE_MAGICK
 
-#ifdef Q_CC_MSVC
+#if defined(Q_CC_MSVC)
 
-    qputenv("MAGICK_CODER_MODULE_PATH", qApp->applicationDirPath().toUtf8());
-    qputenv("MAGICK_CODER_FILTER_PATH", qApp->applicationDirPath().toUtf8());
+    setWindowsEnvironment(app);
+
+#elif defined(Q_OS_MACOS)
+
+    setMacOSEnvironment();
 
 #endif
 
@@ -249,48 +260,6 @@ extern "C" MAIN_EXPORT int MAIN_FN(int argc, char** argv)
 
     QApplication::setWindowIcon(QIcon::fromTheme(QLatin1String("digikam"), app.windowIcon()));
 
-#ifdef Q_OS_WIN
-
-    if (
-        QSysInfo::currentCpuArchitecture().contains(QLatin1String("64")) &&
-        !QSysInfo::buildCpuArchitecture().contains(QLatin1String("64"))
-       )
-    {
-        QMessageBox::critical(qApp->activeWindow(),
-                              qApp->applicationName(),
-                              i18n("<p>You are running digiKam as a 32-bit version on a 64-bit Windows.</p>"
-                                   "<p>Please install the 64-bit version of digiKam to get "
-                                   "a better experience with digiKam.</p>"));
-    }
-
-    QString appPath = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation);
-    QUrl    appUrl  = QUrl::fromLocalFile(appPath).adjusted(QUrl::RemoveFilename);
-    appUrl.setPath(appUrl.path() + QLatin1String("digikam/facesengine"));
-
-    QFileInfo appInfo(appUrl.toLocalFile());
-
-    if (appInfo.exists() && appInfo.isDir())
-    {
-        QString appLocalPath = QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation);
-        QUrl    appLocalUrl  = QUrl::fromLocalFile(appLocalPath).adjusted(QUrl::RemoveFilename);
-        appLocalUrl.setPath(appLocalUrl.path() + QLatin1String("digikam"));
-
-        qCDebug(DIGIKAM_GENERAL_LOG) << "Copy faces engine data from"
-                                     << appUrl.toLocalFile() << "to"
-                                     << appLocalUrl.toLocalFile();
-
-        if (DFileOperations::copyFolderRecursively(appUrl.toLocalFile(), appLocalUrl.toLocalFile()))
-        {
-            qCDebug(DIGIKAM_GENERAL_LOG) << "Delete faces engine data from"
-                                         << appUrl.toLocalFile();
-
-            QDir rmAppPath(appUrl.toLocalFile());
-            rmAppPath.removeRecursively();
-        }
-    }
-
-#endif
-
     // Check if Qt database plugins are available.
 
     if (
@@ -477,7 +446,7 @@ extern "C" MAIN_EXPORT int MAIN_FN(int argc, char** argv)
 
     if (system.enableFaceEngine || system.enableAesthetic || system.enableAutoTags)
     {
-        QPointer<FilesDownloader> floader = new FilesDownloader(qApp->activeWindow());
+        QPointer<FilesDownloader> floader = new FilesDownloader(digikam);
 
         if (!floader->checkDownloadFiles())
         {
