@@ -8,14 +8,13 @@
  *
  * SPDX-FileCopyrightText: 2014      by Laurent Montel <montel at kde dot org>
  * SPDX-FileCopyrightText: 2015      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
- * SPDX-FileCopyrightText: 2014-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2014-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DEBUG_H
-#define DIGIKAM_DEBUG_H
+#pragma once
 
 // Qt includes
 
@@ -34,8 +33,11 @@ DIGIKAM_EXPORT Q_DECLARE_LOGGING_CATEGORY(DIGIKAM_DATABASESERVER_LOG)
 DIGIKAM_EXPORT Q_DECLARE_LOGGING_CATEGORY(DIGIKAM_IMPORTUI_LOG)
 DIGIKAM_EXPORT Q_DECLARE_LOGGING_CATEGORY(DIGIKAM_METAENGINE_LOG)
 DIGIKAM_EXPORT Q_DECLARE_LOGGING_CATEGORY(DIGIKAM_FACESENGINE_LOG)
+DIGIKAM_EXPORT Q_DECLARE_LOGGING_CATEGORY(DIGIKAM_AUTOTAGSENGINE_LOG)
 DIGIKAM_EXPORT Q_DECLARE_LOGGING_CATEGORY(DIGIKAM_RAWENGINE_LOG)
 DIGIKAM_EXPORT Q_DECLARE_LOGGING_CATEGORY(DIGIKAM_GEOIFACE_LOG)
+DIGIKAM_EXPORT Q_DECLARE_LOGGING_CATEGORY(DIGIKAM_MARBLE_LOG)
+DIGIKAM_EXPORT Q_DECLARE_LOGGING_CATEGORY(DIGIKAM_DNNMODELMNGR_LOG)
 
 // Tools and unit-tests debug space (to use only on core/tests)
 
@@ -43,9 +45,11 @@ DIGIKAM_EXPORT Q_DECLARE_LOGGING_CATEGORY(DIGIKAM_TESTS_LOG)
 
 // DPlugin debug spaces
 
+DIGIKAM_EXPORT Q_DECLARE_LOGGING_CATEGORY(DIGIKAM_DPLUGIN_RAWIMPORT_LOG)
 DIGIKAM_EXPORT Q_DECLARE_LOGGING_CATEGORY(DIGIKAM_DPLUGIN_GENERIC_LOG)
 DIGIKAM_EXPORT Q_DECLARE_LOGGING_CATEGORY(DIGIKAM_DPLUGIN_EDITOR_LOG)
 DIGIKAM_EXPORT Q_DECLARE_LOGGING_CATEGORY(DIGIKAM_DPLUGIN_BQM_LOG)
+DIGIKAM_EXPORT Q_DECLARE_LOGGING_CATEGORY(DIGIKAM_DPLUGIN_LOG)
 
 // Databases debug spaces
 
@@ -80,18 +84,7 @@ DIGIKAM_EXPORT Q_DECLARE_LOGGING_CATEGORY(DIGIKAM_MEDIASRV_LOG_WARN)
 DIGIKAM_EXPORT Q_DECLARE_LOGGING_CATEGORY(DIGIKAM_MEDIASRV_LOG_CRITICAL)
 DIGIKAM_EXPORT Q_DECLARE_LOGGING_CATEGORY(DIGIKAM_MEDIASRV_LOG_FATAL)
 
-// MediaPlayer debug spaces
-
-DIGIKAM_EXPORT Q_DECLARE_LOGGING_CATEGORY(DIGIKAM_QTAV_LOG)
-DIGIKAM_EXPORT Q_DECLARE_LOGGING_CATEGORY(DIGIKAM_QTAV_LOG_INFO)
-DIGIKAM_EXPORT Q_DECLARE_LOGGING_CATEGORY(DIGIKAM_QTAV_LOG_WARN)
-DIGIKAM_EXPORT Q_DECLARE_LOGGING_CATEGORY(DIGIKAM_QTAV_LOG_CRITICAL)
-
-DIGIKAM_EXPORT Q_DECLARE_LOGGING_CATEGORY(DIGIKAM_AVPLAYER_LOG)
-
 /**
  * Static method to tune debug traces at run-time.
  */
 DIGIKAM_EXPORT void digikamSetDebugFilterRules(bool on);
-
-#endif // DIGIKAM_DEBUG_H
