@@ -59,7 +59,7 @@ QStringList supportedImageMimeTypes(QIODevice::OpenModeFlag mode, QString& allTy
         }
     }
 
-    Q_FOREACH (const QByteArray& frm, supported)
+    for (const QByteArray& frm : std::as_const(supported))
     {
         if (
             QString::fromLatin1(frm).contains(QLatin1String("tif"),  Qt::CaseInsensitive) ||
@@ -323,4 +323,28 @@ void openOnlineDocumentation(const QString& section, const QString& chapter, con
     browser->show();
 }
 
+void setOpenCLEnvironment(bool b)
+{
+    /*
+     * WARNING: OpenCV can crash with face engine when OpenCL support is enabled.
+     *
+     * https://bugs.kde.org/show_bug.cgi?id=423632
+     * https://bugs.kde.org/show_bug.cgi?id=426175
+     */
+
+    if (!b)
+    {
+        qputenv("OPENCV_OPENCL_RUNTIME", "disabled");
+        qputenv("OPENCV_OPENCL_DEVICE",  "disabled");
+    }
+    else
+    {
+/*
+        FIXME: for testing only for the moment.
+        qputenv("DIGIKAM_DNN_TARGET",    "opencl");
+*/
+    }
+
+}
+
 } // namespace Digikam
