@@ -6,28 +6,19 @@
  * Date        : 2009-09-08
  * Description : global macros, variables and flags
  *
- * Copyright (C) 2009-2010 by Andi Clemens <andi dot clemens at gmail dot com>
- * Copyright (C) 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2010 by Andi Clemens <andi dot clemens at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_GLOBALS_H
-#define DIGIKAM_GLOBALS_H
+#pragma once
 
 // Qt includes
 
 #include <QStringList>
+#include <QDateTime>
 #include <QIODevice>
 #include <QProcessEnvironment>
 
@@ -40,6 +31,7 @@ class QObject;
 class QShortcut;
 class QKeySequence;
 class QApplication;
+class QDate;
 
 /**
  * Macros for image filters.
@@ -55,6 +47,15 @@ class QApplication;
  */
 #define DEG2RAD 0.017453292519943
 
+/**
+ * Macro to use right return type with qHash(), changed with new Qt6 API.
+ */
+#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
+#   define QT_HASH_TYPE /* clazy:exclude=qt6-qhash-signature */ uint
+#else
+#   define QT_HASH_TYPE size_t
+#endif
+
 namespace Digikam
 {
 
@@ -151,6 +152,23 @@ enum ChannelType
     ColorChannels
 };
 
+/**
+ * Types of operations for ApplicationSettings.
+ * Originally introduced for grouping to configure whether an operation
+ * should be done on all group members or only it's head.
+ */
+enum OperationType
+{
+    MetadataOps = 0,
+    ImportExportOps,
+    BQMOps,
+    LightTableOps,
+    SlideshowOps,
+    RenameOps,
+    ToolsOps,
+    UnspecifiedOps ///< This element must always come last
+};
+
 // --------------------------------------------------------
 
 /**
@@ -181,6 +199,16 @@ DIGIKAM_EXPORT void showRawCameraList();
  */
 DIGIKAM_EXPORT QString toolButtonStyleSheet();
 
+/**
+ * Default spacing to use in layout.
+ */
+DIGIKAM_EXPORT int layoutSpacing();
+
+/**
+ * Default margin to use in layout.
+ */
+DIGIKAM_EXPORT int layoutMargin();
+
 // --- Static functions for the bundles ---
 
 /**
@@ -188,6 +216,11 @@ DIGIKAM_EXPORT QString toolButtonStyleSheet();
  */
 DIGIKAM_EXPORT bool isRunningInAppImageBundle();
 
+/**
+ * Return true if application run on native KDE desktop.
+ */
+DIGIKAM_EXPORT bool isRunningOnNativeKDE();
+
 /**
  * If digiKam run into AppImage, return a cleaned environment for QProcess to execute a
  * program outside the bundle without broken run-time dependencies.
@@ -197,12 +230,6 @@ DIGIKAM_EXPORT bool isRunningInAppImageBundle();
  */
 DIGIKAM_EXPORT QProcessEnvironment adjustedEnvironmentForAppImage();
 
-/**
- * Static method to initialize DrMinGw crash handler under windows.
- * This method is typically called from main() function.
- */
-DIGIKAM_EXPORT void tryInitDrMingw();
-
 /**
  * Prefix of macOS Bundle to access to internal Unix hierarchy.
  */
@@ -229,10 +256,43 @@ DIGIKAM_EXPORT void loadEcmQtTranslationFiles(QApplication& app);
 DIGIKAM_EXPORT void installQtTranslationFiles(QApplication& app);
 
 /**
- * For bundles only, find or set KSycoca database file in the cache directory.
+ * For MacOS bundles only, set necessary MacOS environment variables
  */
-DIGIKAM_EXPORT void setupKSycocaDatabaseFile();
+DIGIKAM_EXPORT void setMacOSEnvironment();
+
+/**
+ * For Windows only, set necessary Windows environment variables
+ */
+DIGIKAM_EXPORT void setWindowsEnvironment(QApplication& app);
+
+/**
+ * For OpenCV framework, set necessary environment variables to use OpenCL features.
+ */
+DIGIKAM_EXPORT void setOpenCLEnvironment(bool b);
+
+/**
+ * This method returns QDateTime from with date set to parameter date and time set to start of the day.
+ */
+DIGIKAM_EXPORT QDateTime startOfDay(const QDate& date);
+
+/**
+ * This method returns QDateTime with UTC timespec.
+ */
+DIGIKAM_EXPORT QDateTime asDateTimeUTC(const QDateTime& dt);
+
+/**
+ * This method returns QDateTime with Local timespec.
+ */
+DIGIKAM_EXPORT QDateTime asDateTimeLocal(const QDateTime& dt);
+
+/**
+ * Open online handbook at the section/chapter/reference page.
+ *
+ * if section and chapter and reference are empty, fromt page is open.  (https://en.wikipedia.org/wiki/Matrix_(protocol)#Bridges)
+ * if only chapter and reference are empty, section page is open.       (as: https://docs.digikam.org/en/main_window.html)
+ * if only reference is empty, chapter from section page is open.       (as: https://docs.digikam.org/en/main_window/people_view.html)
+ * else reference at chapter from section page is open.                 (as: https://docs.digikam.org/en/main_window/people_view.html#face-recognition)
+ */
+DIGIKAM_EXPORT void openOnlineDocumentation(const QString& section = QString(), const QString& chapter = QString(), const QString& reference = QString());
 
 } // namespace Digikam
-
-#endif // DIGIKAM_GLOBALS_H
