@@ -51,6 +51,21 @@ bool isRunningOnNativeKDE()
 
 }
 
+bool isRunningOnMacOS()
+{
+
+#ifdef Q_OS_MACOS
+
+    return true;
+
+#else
+
+    return false;
+
+#endif
+
+}
+
 QProcessEnvironment adjustedEnvironmentForAppImage()
 {
     QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
@@ -151,13 +166,39 @@ QProcessEnvironment adjustedEnvironmentForAppImage()
             env.remove(QLatin1String("XDG_SESSION_DESKTOP"));
         }
     }
+    else
+    {
+        if (isRunningOnMacOS())
+        {
+
+#ifdef DK_APPLE_PACKAGE_HOMEBREW
+
+                env.insert(QLatin1String("DK_MARIADB_DIR"),
+                    macOSBundlePrefix() + QString::fromUtf8("lib/mariadb", -1));
+                env.insert(QLatin1String("PATH"),
+                    macOSBundlePrefix() + QString::fromUtf8("lib/mariadb/bin:", -1) + QString::fromLocal8Bit(qgetenv("PATH")));
+
+#endif
+
+        }
+    }
 
     return env;
 }
 
 QString macOSBundlePrefix()
 {
+
+#ifdef DK_APPLE_PACKAGE_HOMEBREW
+
+    return QCoreApplication::applicationDirPath() + QString::fromUtf8("/../");
+
+#else
+
     return QString::fromUtf8("/Applications/digiKam.org/digikam.app/Contents/");
+
+#endif
+
 }
 
 void unloadQtTranslationFiles(QApplication& app)
@@ -175,7 +216,7 @@ void unloadQtTranslationFiles(QApplication& app)
 
     QList<QTranslator*> translators = app.findChildren<QTranslator*>(QString(), Qt::FindDirectChildrenOnly);
 
-    Q_FOREACH (const auto& translator, translators)
+    for (const auto& translator : std::as_const(translators))
     {
         app.removeTranslator(translator);
     }
@@ -235,7 +276,7 @@ void loadStdQtTranslationFiles(QApplication& app)
 
         };
 
-        Q_FOREACH (const QString& catalog, qtCatalogs)
+        for (const QString& catalog : std::as_const(qtCatalogs))
         {
             QTranslator* const translator = new QTranslator(&app);
 
@@ -266,15 +307,12 @@ void loadEcmQtTranslationFiles(QApplication& app)
 
     const QStringList ecmCatalogs =
     {
-//        QLatin1String("kauth6_qt"),               Do not exists.
         QLatin1String("kbookmarks6_qt"),
         QLatin1String("kcodecs6_qt"),
         QLatin1String("kcompletion6_qt"),
         QLatin1String("kconfig6_qt"),
         QLatin1String("kcoreaddons6_qt"),
         QLatin1String("kdbusaddons6_qt"),
-//        QLatin1String("kde6_xml_mimetypes"),      Do not exists.
-//        QLatin1String("kglobalaccel6_qt"),        Do not exists.
         QLatin1String("kitemviews6_qt"),
         QLatin1String("kwidgetsaddons6_qt"),
         QLatin1String("kwindowsystem6_qt"),
@@ -342,7 +380,7 @@ void loadEcmQtTranslationFiles(QApplication& app)
     {
         const QString& localeDirName = it.previous();
 
-        Q_FOREACH (const auto& catalog, ecmCatalogs)
+        for (const auto& catalog : std::as_const(ecmCatalogs))
         {
             QString subPath    = QLatin1String("locale/")       +
                                  localeDirName                  +
@@ -424,4 +462,39 @@ void installQtTranslationFiles(QApplication& app)
     }
 }
 
+void setMacOSEnvironment()
+{
+    // Safety check
+
+    if (isRunningOnMacOS())
+    {
+
+#ifdef DK_APPLE_PACKAGE_HOMEBREW
+
+        qputenv("MAGICK_CODER_MODULE_PATH", (macOSBundlePrefix() + QString::fromUtf8("lib/ImageMagick/modules-Q16HDRI/coders", -1)).toUtf8());
+        qputenv("MAGICK_CODER_FILTER_PATH", (macOSBundlePrefix() + QString::fromUtf8("lib/ImageMagick/modules-Q16HDRI/filters", -1)).toUtf8());
+        qputenv("PATH", (macOSBundlePrefix() + QString::fromUtf8("bin:", -1) + QString::fromLocal8Bit(qgetenv("PATH"))).toUtf8());
+
+#else // Macports
+
+        // Libgphoto2 drivers
+        qputenv("CAMLIBS", (macOSBundlePrefix() + QString::fromUtf8(("/lib/libgphoto2"),      -1)).toUtf8());
+        qputenv("IOLIBS",  (macOSBundlePrefix() + QString::fromUtf8(("/lib/libgphoto2_port"), -1)).toUtf8());
+
+#endif
+
+    }
+}
+
+void setWindowsEnvironment(QApplication& app)
+{
+
+    // michmill - should probably remove QApplication app from function signature and use 
+    // QCoreApplication::applicationDirPath() below but I don't have a Windows
+    // machine to test with
+
+    qputenv("MAGICK_CODER_MODULE_PATH", app.applicationDirPath().toUtf8());
+    qputenv("MAGICK_CODER_FILTER_PATH", app.applicationDirPath().toUtf8());
+}
+
 } // namespace Digikam
