@@ -6,7 +6,7 @@
  * Date        : 2006-21-12
  * Description : a embedded item-view to show the canvas preview widget.
  *
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier  <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier  <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
  * SPDX-FileCopyrightText: 2010-2011 by Aditya Bhatt <adityabhatt1991 at gmail dot com>
  *
@@ -14,8 +14,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ITEM_PREVIEW_CANVAS_H
-#define DIGIKAM_ITEM_PREVIEW_CANVAS_H
+#pragma once
 
 // Local includes
 
@@ -59,9 +58,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_ITEM_PREVIEW_CANVAS_H
