@@ -6,25 +6,15 @@
  * Date        : 2006-21-12
  * Description : a embedded view to show item preview widget.
  *
- * Copyright (C) 2006-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
- * Copyright (C) 2010-2011 by Aditya Bhatt <adityabhatt1991 at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2011 by Aditya Bhatt <adityabhatt1991 at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ITEM_PREVIEW_VIEW_H
-#define DIGIKAM_ITEM_PREVIEW_VIEW_H
+#pragma once
 
 // Local includes
 
@@ -90,13 +80,23 @@ protected:
 
     bool acceptsMouseClick(QMouseEvent* e)  override;
     void mousePressEvent(QMouseEvent* e)    override;
-    void enterEvent(QEvent* e)              override;
     void leaveEvent(QEvent* e)              override;
     void showEvent(QShowEvent* e)           override;
     void dropEvent(QDropEvent* e)           override;
     void dragMoveEvent(QDragMoveEvent* e)   override;
     void dragEnterEvent(QDragEnterEvent* e) override;
 
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+    void enterEvent(QEnterEvent*)           override;
+
+#else
+
+    void enterEvent(QEvent*)                override;
+
+#endif
+
+
 private Q_SLOTS:
 
     void imageLoaded();
@@ -128,9 +128,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_ITEM_PREVIEW_VIEW_H
