@@ -6,22 +6,13 @@
  * Date        : 2009-12-05
  * Description : Side Bar Widget for the folder view.
  *
- * Copyright (C) 2009-2010 by Johannes Wienke <languitar at semipol dot de>
- * Copyright (C) 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2012      by Andi Clemens <andi dot clemens at gmail dot com>
- * Copyright (C) 2014      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
- * Copyright (C) 2010      by Aditya Bhatt <adityabhatt1991 at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2010 by Johannes Wienke <languitar at semipol dot de>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012      by Andi Clemens <andi dot clemens at gmail dot com>
+ * SPDX-FileCopyrightText: 2014      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
+ * SPDX-FileCopyrightText: 2010      by Aditya Bhatt <adityabhatt1991 at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -41,6 +32,7 @@
 
 // Local includes
 
+#include "digikam_globals.h"
 #include "digikam_debug.h"
 #include "albummanager.h"
 #include "albumselectiontreeview.h"
@@ -54,16 +46,11 @@ class Q_DECL_HIDDEN AlbumFolderViewSideBarWidget::Private
 {
 public:
 
-    explicit Private()
-      : albumModificationHelper(nullptr),
-        albumFolderView        (nullptr),
-        searchTextBar          (nullptr)
-    {
-    }
+    Private() = default;
 
-    AlbumModificationHelper* albumModificationHelper;
-    AlbumSelectionTreeView*  albumFolderView;
-    SearchTextBarDb*         searchTextBar;
+    AlbumModificationHelper* albumModificationHelper = nullptr;
+    AlbumSelectionTreeView*  albumFolderView         = nullptr;
+    SearchTextBarDb*         searchTextBar           = nullptr;
 };
 
 AlbumFolderViewSideBarWidget::AlbumFolderViewSideBarWidget(QWidget* const parent,
@@ -73,10 +60,10 @@ AlbumFolderViewSideBarWidget::AlbumFolderViewSideBarWidget(QWidget* const parent
       d            (new Private)
 {
     setObjectName(QLatin1String("AlbumFolderView Sidebar"));
-    setProperty("Shortcut", Qt::CTRL + Qt::SHIFT + Qt::Key_F1);
+    setProperty("Shortcut", QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_F1));
     d->albumModificationHelper = albumModificationHelper;
 
-    const int spacing          = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
+    const int spacing          = layoutSpacing();
 
     QVBoxLayout* const layout  = new QVBoxLayout(this);
     d->albumFolderView         = new AlbumSelectionTreeView(this, model, d->albumModificationHelper);
@@ -93,6 +80,7 @@ AlbumFolderViewSideBarWidget::AlbumFolderViewSideBarWidget(QWidget* const parent
     layout->setContentsMargins(0, 0, spacing, 0);
 
     // setup connection
+
     connect(d->albumFolderView, SIGNAL(signalFindDuplicates(QList<PAlbum*>)),
             this, SIGNAL(signalFindDuplicates(QList<PAlbum*>)));
 }
@@ -127,6 +115,12 @@ void AlbumFolderViewSideBarWidget::applySettings()
     d->albumFolderView->setExpandNewCurrentItem(settings->getExpandNewCurrentItem());
 }
 
+void AlbumFolderViewSideBarWidget::applyResorting()
+{
+    d->albumFolderView->setSortingEnabled(false);
+    d->albumFolderView->setSortingEnabled(true);
+}
+
 void AlbumFolderViewSideBarWidget::changeAlbumFromHistory(const QList<Album*>& album)
 {
     d->albumFolderView->setCurrentAlbums(album);
@@ -140,6 +134,7 @@ AlbumPointer<PAlbum> AlbumFolderViewSideBarWidget::currentAlbum() const
 void AlbumFolderViewSideBarWidget::setCurrentAlbum(PAlbum* album)
 {
     // Change the current album in list view.
+
     d->albumFolderView->setCurrentAlbums(QList<Album*>() << album);
 }
 
@@ -154,3 +149,5 @@ const QString AlbumFolderViewSideBarWidget::getCaption()
 }
 
 } // namespace Digikam
+
+#include "moc_albumfolderviewsidebarwidget.cpp"
