@@ -31,6 +31,7 @@
 
 // Local includes
 
+#include "digikam_globals.h"
 #include "digikam_debug.h"
 #include "albumpointer.h"
 #include "applicationsettings.h"
@@ -43,12 +44,9 @@ class Q_DECL_HIDDEN DateFolderViewSideBarWidget::Private
 {
 public:
 
-    explicit Private()
-      : dateFolderView(nullptr)
-    {
-    }
+    Private() = default;
 
-    DateFolderView* dateFolderView;
+    DateFolderView* dateFolderView = nullptr;
 };
 
 DateFolderViewSideBarWidget::DateFolderViewSideBarWidget(QWidget* const parent,
@@ -60,8 +58,7 @@ DateFolderViewSideBarWidget::DateFolderViewSideBarWidget(QWidget* const parent,
     setObjectName(QLatin1String("DateFolderView Sidebar"));
     setProperty("Shortcut", QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_F4));
 
-    const int spacing         = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
-                                     QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
+    const int spacing         = layoutSpacing();
 
     QVBoxLayout* const layout = new QVBoxLayout(this);
 
