@@ -15,8 +15,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DATE_FOLDER_VIEW_SIDE_BAR_WIDGET_H
-#define DIGIKAM_DATE_FOLDER_VIEW_SIDE_BAR_WIDGET_H
+#pragma once
 
 // Local includes
 
@@ -39,26 +38,24 @@ public:
     explicit DateFolderViewSideBarWidget(QWidget* const parent,
                                          DateAlbumModel* const model,
                                          ItemAlbumFilterModel* const imageFilterModel);
-    ~DateFolderViewSideBarWidget() override;
+    ~DateFolderViewSideBarWidget()                                    override;
 
-    void          setActive(bool active)                             override;
-    void          doLoadState()                                      override;
-    void          doSaveState()                                      override;
-    void          applySettings()                                    override;
-    void          changeAlbumFromHistory(const QList<Album*>& album) override;
-    const QIcon   getIcon()                                          override;
-    const QString getCaption()                                       override;
+    void          setActive(bool active)                              override;
+    void          doLoadState()                                       override;
+    void          doSaveState()                                       override;
+    void          applySettings()                                     override;
+    void          changeAlbumFromHistory(const QList<Album*>& album)  override;
+    const QIcon   getIcon()                                           override;
+    const QString getCaption()                                        override;
 
-    AlbumPointer<DAlbum> currentAlbum() const;
+    AlbumPointer<DAlbum> currentAlbum()                         const;
 
     void gotoDate(const QDate& date);
 
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_DATE_FOLDER_VIEW_SIDE_BAR_WIDGET_H
