@@ -15,8 +15,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_FUZZY_SEARCH_SIDE_BAR_WIDGET_H
-#define DIGIKAM_FUZZY_SEARCH_SIDE_BAR_WIDGET_H
+#pragma once
 
 // Local includes
 
@@ -37,7 +36,7 @@ public:
     explicit FuzzySearchSideBarWidget(QWidget* const parent,
                                       SearchModel* const searchModel,
                                       SearchModificationHelper* const searchModificationHelper);
-    ~FuzzySearchSideBarWidget() override;
+    ~FuzzySearchSideBarWidget()                                      override;
 
     void          setActive(bool active)                             override;
     void          doLoadState()                                      override;
@@ -58,9 +57,7 @@ Q_SIGNALS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_FUZZY_SEARCH_SIDE_BAR_WIDGET_H
