@@ -7,7 +7,7 @@
  * Description : Side Bar Widget for the gps search.
  *
  * SPDX-FileCopyrightText: 2009-2010 by Johannes Wienke <languitar at semipol dot de>
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2014      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  * SPDX-FileCopyrightText: 2010      by Aditya Bhatt <adityabhatt1991 at gmail dot com>
  *
@@ -15,8 +15,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_GPS_SEARCH_SIDE_BAR_WIDGET_H
-#define DIGIKAM_GPS_SEARCH_SIDE_BAR_WIDGET_H
+#pragma once
 
 // Local includes
 
@@ -41,7 +40,7 @@ public:
                                     SearchModificationHelper* const searchModificationHelper,
                                     ItemFilterModel* const imageFilterModel,
                                     QItemSelectionModel* const itemSelectionModel);
-    ~GPSSearchSideBarWidget() override;
+    ~GPSSearchSideBarWidget()                                        override;
 
     void          setActive(bool active)                             override;
     void          doLoadState()                                      override;
@@ -58,9 +57,7 @@ Q_SIGNALS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_GPS_SEARCH_SIDE_BAR_WIDGET_H
