@@ -7,7 +7,7 @@
  * Description : Labels sidebar widgets
  *
  * SPDX-FileCopyrightText: 2009-2010 by Johannes Wienke <languitar at semipol dot de>
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2012      by Andi Clemens <andi dot clemens at gmail dot com>
  * SPDX-FileCopyrightText: 2014      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  * SPDX-FileCopyrightText: 2010      by Aditya Bhatt <adityabhatt1991 at gmail dot com>
@@ -32,10 +32,10 @@
 
 // Local includes
 
+#include "digikam_globals.h"
 #include "digikam_debug.h"
 #include "albummanager.h"
 #include "applicationsettings.h"
-#include "labelstreeview.h"
 
 namespace Digikam
 {
@@ -45,12 +45,9 @@ class Q_DECL_HIDDEN LabelsSideBarWidget::Private
 
 public:
 
-    explicit Private()
-      : labelsTree(nullptr)
-    {
-    }
+    Private() = default;
 
-    LabelsTreeView* labelsTree;
+    LabelsTreeView* labelsTree = nullptr;
 };
 
 LabelsSideBarWidget::LabelsSideBarWidget(QWidget* const parent)
@@ -60,8 +57,7 @@ LabelsSideBarWidget::LabelsSideBarWidget(QWidget* const parent)
     setObjectName(QLatin1String("Labels Sidebar"));
     setProperty("Shortcut", QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_F3));
 
-    const int spacing         = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
-                                     QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
+    const int spacing         = layoutSpacing();
 
     QVBoxLayout* const layout = new QVBoxLayout(this);
 
@@ -125,3 +121,5 @@ QHash<LabelsTreeView::Labels, QList<int> > LabelsSideBarWidget::selectedLabels()
 }
 
 } // namespace Digikam
+
+#include "moc_labelssidebarwidget.cpp"
