@@ -7,7 +7,7 @@
  * Description : Labels sidebar widgets
  *
  * SPDX-FileCopyrightText: 2009-2010 by Johannes Wienke <languitar at semipol dot de>
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2014      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  * SPDX-FileCopyrightText: 2010      by Aditya Bhatt <adityabhatt1991 at gmail dot com>
  *
@@ -15,8 +15,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_LABELS_SIDE_BAR_WIDGET_H
-#define DIGIKAM_LABELS_SIDE_BAR_WIDGET_H
+#pragma once
 
 // Local includes
 
@@ -34,7 +33,7 @@ class LabelsSideBarWidget : public SidebarWidget
 public:
 
     explicit LabelsSideBarWidget(QWidget* const parent);
-    ~LabelsSideBarWidget() override;
+    ~LabelsSideBarWidget()                                           override;
 
     LabelsTreeView* labelsTree();
 
@@ -51,9 +50,7 @@ public:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_LABELS_SIDE_BAR_WIDGET_H
