@@ -7,10 +7,11 @@
  * Description : Side Bar Widget for People
  *
  * SPDX-FileCopyrightText: 2009-2010 by Johannes Wienke <languitar at semipol dot de>
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2012      by Andi Clemens <andi dot clemens at gmail dot com>
  * SPDX-FileCopyrightText: 2014      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  * SPDX-FileCopyrightText: 2010      by Aditya Bhatt <adityabhatt1991 at gmail dot com>
+ * SPDX-FileCopyrightText: 2024      by Michael Miller <michael underscore miller at msn dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -36,6 +37,7 @@
 
 // Local includes
 
+#include "digikam_globals.h"
 #include "digikam_debug.h"
 #include "searchtextbardb.h"
 #include "tagfolderview.h"
@@ -52,34 +54,40 @@ class Q_DECL_HIDDEN PeopleSideBarWidget::Private
 {
 public:
 
-    explicit Private()
-      : rescanButton            (nullptr),
-        searchModificationHelper(nullptr),
-        settingsWdg             (nullptr),
-        tagFolderView           (nullptr),
-        tagSearchBar            (nullptr)
-    {
-    }
+    Private() = default;
 
-    QPushButton*              rescanButton;
-    SearchModificationHelper* searchModificationHelper;
-    FaceScanWidget*           settingsWdg;
-    TagFolderView*            tagFolderView;
-    SearchTextBarDb*          tagSearchBar;
+    QPushButton*              rescanButton              = nullptr;
+    SearchModificationHelper* searchModificationHelper  = nullptr;
+    FaceScanWidget*           settingsWdg               = nullptr;
+    TagFolderView*            tagFolderView             = nullptr;
+    SearchTextBarDb*          tagSearchBar              = nullptr;
+    PeopleSideBarWidget*      parentInstance            = nullptr;
+
+    int                       ref                       = 1;
 };
 
+PeopleSideBarWidget::Private* PeopleSideBarWidget::d = nullptr;
+
 PeopleSideBarWidget::PeopleSideBarWidget(QWidget* const parent,
                                          TagModel* const model,
                                          SearchModificationHelper* const searchModificationHelper)
-    : SidebarWidget(parent),
-      d            (new Private)
+    : SidebarWidget(parent)
 {
+    if (!d)
+    {
+        d                 = new Private();
+        d->parentInstance = this;
+    }
+    else
+    {
+        ++(d->ref);
+    }
+
     setObjectName(QLatin1String("People Sidebar"));
     setProperty("Shortcut", QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_F9));
     d->searchModificationHelper   = searchModificationHelper;
 
-    const int spacing             = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
-                                         QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
+    const int spacing             = layoutSpacing();
 
     QWidget* const     mainView   = new QWidget(this);
     QScrollArea* const scrollArea = new QScrollArea(this);
@@ -111,10 +119,12 @@ PeopleSideBarWidget::PeopleSideBarWidget(QWidget* const parent,
 
     d->rescanButton   = new QPushButton;
     d->rescanButton->setText(i18n("Scan collection for faces"));
+    d->rescanButton->setIcon(QIcon::fromTheme(QLatin1String("edit-find")));
+    d->rescanButton->setWhatsThis(i18nc("@info", "Use this button to scan the selected albums for faces"));
 
     vlay->addWidget(d->tagFolderView, 10);
     vlay->addWidget(d->tagSearchBar);
-    vlay->addWidget(d->settingsWdg);
+    vlay->addWidget(d->settingsWdg,   5);
     vlay->addWidget(d->rescanButton);
     vlay->setContentsMargins(spacing, spacing, spacing, spacing);
 
@@ -129,7 +139,13 @@ PeopleSideBarWidget::PeopleSideBarWidget(QWidget* const parent,
 
 PeopleSideBarWidget::~PeopleSideBarWidget()
 {
-    delete d;
+    --(d->ref);
+
+    if (0 == d->ref)
+    {
+        delete d;
+        d = nullptr;
+    }
 }
 
 void PeopleSideBarWidget::slotInit()
@@ -150,7 +166,9 @@ void PeopleSideBarWidget::setActive(bool active)
             QString msg = i18n("Welcome to Face Management in digiKam. "
                                "If this is your first time using this feature, please consider "
                                "using the Help Box in the Bottom Left Side Panel.");
+
             Q_EMIT signalNotificationError(msg, DNotificationWidget::Information);
+
             ApplicationSettings::instance()->setHelpBoxNotificationSeen(true);
         }
     }
@@ -185,24 +203,16 @@ void PeopleSideBarWidget::slotScanForFaces()
 
     if (!d->settingsWdg->settingsConflicted())
     {
-        FacesDetector* const tool = new FacesDetector(faceScanSettings);
-        tool->start();
 
-        d->settingsWdg->setEnabled(false);
-        d->rescanButton->setEnabled(false);
+        doFaceScan(faceScanSettings);
 
-        connect(tool, SIGNAL(signalComplete()),
-                this, SLOT(slotScanComplete()));
-
-        connect(tool, SIGNAL(signalCanceled()),
-                this, SLOT(slotScanComplete()));
     }
     else
     {
         Q_EMIT signalNotificationError(i18n("Face recognition is aborted, because "
-                                          "there are no identities to recognize. "
-                                          "Please add new identities."),
-                                     DNotificationWidget::Information);
+                                            "there are no identities to recognize. "
+                                            "Please add new identities."),
+                                       DNotificationWidget::Information);
     }
 }
 
@@ -222,4 +232,27 @@ const QString PeopleSideBarWidget::getCaption()
     return i18nc("Browse images sorted by depicted people", "People");
 }
 
+// this should probably be a singleton somewhere else, but here works well
+// for controlling the FaceScanWidget
+
+void PeopleSideBarWidget::doFaceScan(const FaceScanSettings& faceScanSettings)
+{
+    FacesDetector* const facesDetector = new FacesDetector(faceScanSettings);
+    facesDetector->start();
+
+    connect(facesDetector, SIGNAL(signalComplete()),
+            d->parentInstance, SLOT(slotScanComplete()));
+
+    connect(facesDetector, SIGNAL(signalCanceled()),
+            d->parentInstance, SLOT(slotScanComplete()));
+
+    connect(facesDetector, SIGNAL(signalScanNotification(QString,int)),
+            d->parentInstance, SIGNAL(signalNotificationError(QString,int)));
+
+    d->settingsWdg->setEnabled(false);
+    d->rescanButton->setEnabled(false);
+}
+
 } // namespace Digikam
+
+#include "moc_peoplesidebarwidget.cpp"
