@@ -7,7 +7,7 @@
  * Description : Side Bar Widget for the search.
  *
  * SPDX-FileCopyrightText: 2009-2010 by Johannes Wienke <languitar at semipol dot de>
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2012      by Andi Clemens <andi dot clemens at gmail dot com>
  * SPDX-FileCopyrightText: 2014      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  * SPDX-FileCopyrightText: 2010      by Aditya Bhatt <adityabhatt1991 at gmail dot com>
@@ -31,6 +31,7 @@
 
 // Local includes
 
+#include "digikam_globals.h"
 #include "digikam_debug.h"
 #include "albumpointer.h"
 #include "applicationsettings.h"
@@ -47,16 +48,11 @@ class Q_DECL_HIDDEN SearchSideBarWidget::Private
 {
 public:
 
-    explicit Private()
-      : searchSearchBar(nullptr),
-        searchTreeView (nullptr),
-        searchTabHeader(nullptr)
-    {
-    }
+    Private() = default;
 
-    SearchTextBarDb*      searchSearchBar;
-    NormalSearchTreeView* searchTreeView;
-    SearchTabHeader*      searchTabHeader;
+    SearchTextBarDb*      searchSearchBar = nullptr;
+    NormalSearchTreeView* searchTreeView  = nullptr;
+    SearchTabHeader*      searchTabHeader = nullptr;
 };
 
 SearchSideBarWidget::SearchSideBarWidget(QWidget* const parent,
@@ -68,8 +64,7 @@ SearchSideBarWidget::SearchSideBarWidget(QWidget* const parent,
     setObjectName(QLatin1String("Search Sidebar"));
     setProperty("Shortcut", QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_F6));
 
-    const int spacing         = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
-                                     QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
+    const int spacing         = layoutSpacing();
 
     QVBoxLayout* const layout = new QVBoxLayout(this);
 
@@ -93,6 +88,9 @@ SearchSideBarWidget::SearchSideBarWidget(QWidget* const parent,
     connect(d->searchTreeView, SIGNAL(newSearch()),
             d->searchTabHeader, SLOT(newAdvancedSearch()));
 
+    connect(d->searchTreeView, SIGNAL(copySearch(SAlbum*)),
+            d->searchTabHeader, SLOT(copySearch(SAlbum*)));
+
     connect(d->searchTreeView, SIGNAL(editSearch(SAlbum*)),
             d->searchTabHeader, SLOT(editSearch(SAlbum*)));
 
@@ -157,3 +155,5 @@ void SearchSideBarWidget::newAdvancedSearch()
 }
 
 } // namespace Digikam
+
+#include "moc_searchsidebarwidget.cpp"
