@@ -7,7 +7,7 @@
  * Description : Side Bar Widget for the search.
  *
  * SPDX-FileCopyrightText: 2009-2010 by Johannes Wienke <languitar at semipol dot de>
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2014      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  * SPDX-FileCopyrightText: 2010      by Aditya Bhatt <adityabhatt1991 at gmail dot com>
  *
@@ -15,8 +15,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_SEARCH_SIDE_BAR_WIDGET_H
-#define DIGIKAM_SEARCH_SIDE_BAR_WIDGET_H
+#pragma once
 
 // Local includes
 
@@ -37,7 +36,7 @@ public:
     explicit SearchSideBarWidget(QWidget* const parent,
                                  SearchModel* const searchModel,
                                  SearchModificationHelper* const searchModificationHelper);
-    ~SearchSideBarWidget() override;
+    ~SearchSideBarWidget()                                           override;
 
     void          setActive(bool active)                             override;
     void          doLoadState()                                      override;
@@ -53,9 +52,7 @@ public:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_SEARCH_SIDE_BAR_WIDGET_H
