@@ -7,7 +7,7 @@
  * Description : Item icon view interface.
  *
  * SPDX-FileCopyrightText: 2002-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2002-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2002-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2009-2011 by Johannes Wienke <languitar at semipol dot de>
  * SPDX-FileCopyrightText: 2010-2011 by Andi Clemens <andi dot clemens at gmail dot com>
  * SPDX-FileCopyrightText: 2011-2013 by Michael G. Hansen <mike at mghansen dot de>
@@ -35,8 +35,8 @@ ItemIconView::ItemIconView(QWidget* const parent, DModelFactory* const modelColl
     d->tagModificationHelper    = new TagModificationHelper(this, this);
     d->searchModificationHelper = new SearchModificationHelper(this, this);
 
-    const int spacing           = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
-                                       QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
+    const int spacing           = layoutSpacing();
+
 
     d->splitter    = new SidebarSplitter;
     d->splitter->setFrameStyle(QFrame::NoFrame | QFrame::Plain);
@@ -64,30 +64,30 @@ ItemIconView::ItemIconView(QWidget* const parent, DModelFactory* const modelColl
     connect(d->leftSideBar, SIGNAL(signalChangedTab(QWidget*)),
             d->errorWidget, SLOT(animatedHide()));
 
-    d->stackedview = new StackedView(vbox);
+    d->stackedView = new StackedView(vbox);
 
     d->dockArea->setCentralWidget(vbox);
-    d->stackedview->setDockArea(d->dockArea);
+    d->stackedView->setDockArea(d->dockArea);
 
-    d->iconView  = d->stackedview->imageIconView();
+    d->iconView  = d->stackedView->imageIconView();
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
-    d->mapView   = d->stackedview->mapWidgetView();
+    d->mapView   = d->stackedView->mapWidgetView();
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
-    d->tableView = d->stackedview->tableView();
-    d->trashView = d->stackedview->trashView();
+    d->tableView = d->stackedView->tableView();
+    d->trashView = d->stackedView->trashView();
 
     d->utilities = d->iconView->utilities();
 
-    d->addPageUpDownActions(this, d->stackedview->imagePreviewView());
-    d->addPageUpDownActions(this, d->stackedview->thumbBar());
+    d->addPageUpDownActions(this, d->stackedView->imagePreviewView());
+    d->addPageUpDownActions(this, d->stackedView->thumbBar());
 
 #ifdef HAVE_MEDIAPLAYER
 
-    d->addPageUpDownActions(this, d->stackedview->mediaPlayerView());
+    d->addPageUpDownActions(this, d->stackedView->mediaPlayerView());
 
 #endif // HAVE_MEDIAPLAYER
 
@@ -152,7 +152,7 @@ ItemIconView::ItemIconView(QWidget* const parent, DModelFactory* const modelColl
     connect(d->fuzzySearchSideBar, SIGNAL(signalNotificationError(QString,int)),
             this, SLOT(slotNotificationError(QString,int)));
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
     d->gpsSearchSideBar    = new GPSSearchSideBarWidget(d->leftSideBar,
                                                         d->modelCollection->getSearchModel(),
@@ -162,7 +162,7 @@ ItemIconView::ItemIconView(QWidget* const parent, DModelFactory* const modelColl
 
     d->leftSideBarWidgets << d->gpsSearchSideBar;
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
     // People Sidebar
 
@@ -181,7 +181,7 @@ ItemIconView::ItemIconView(QWidget* const parent, DModelFactory* const modelColl
 
     d->leftSideBarWidgets << d->peopleSideBar;
 
-    Q_FOREACH (SidebarWidget* const leftWidget, d->leftSideBarWidgets)
+    for (SidebarWidget* const leftWidget : std::as_const(d->leftSideBarWidgets))
     {
         d->leftSideBar->appendTab(leftWidget, leftWidget->getIcon(), leftWidget->getCaption());
 
@@ -230,6 +230,9 @@ ItemIconView::ItemIconView(QWidget* const parent, DModelFactory* const modelColl
     connect(d->rightSideBar, SIGNAL(signalSetupExifTool()),
             this, SLOT(slotSetupExifTool()));
 
+    connect(d->rightSideBar, SIGNAL(signalRightSideBarBusy(bool)),
+            this, SLOT(slotLeftSideBarEnabled(bool)));
+
     connect(d->iconView, SIGNAL(signalSeparationModeChanged(int)),
             this, SIGNAL(signalSeparationModeChanged(int)));
 }
@@ -245,12 +248,14 @@ ItemIconView::~ItemIconView()
 
 void ItemIconView::applySettings()
 {
-    Q_FOREACH (SidebarWidget* const sidebarWidget, d->leftSideBarWidgets)
+    for (SidebarWidget* const sidebarWidget : std::as_const(d->leftSideBarWidgets))
     {
         sidebarWidget->applySettings();
     }
 
-    d->iconView->imageFilterModel()->setVersionItemFilterSettings(VersionItemFilterSettings(ApplicationSettings::instance()->getVersionManagerSettings()));
+    d->iconView->imageFilterModel()->setVersionItemFilterSettings(
+        VersionItemFilterSettings(
+            ApplicationSettings::instance()->getVersionManagerSettings()));
 
     refreshView();
 }
@@ -262,9 +267,6 @@ void ItemIconView::setupConnections()
     connect(d->parent, SIGNAL(signalEscapePressed()),
             this, SLOT(slotEscapePreview()));
 
-    connect(d->parent, SIGNAL(signalEscapePressed()),
-            d->stackedview, SLOT(slotEscapePreview()));
-
     connect(d->parent, SIGNAL(signalNextItem()),
             this, SLOT(slotNextItem()));
 
@@ -286,6 +288,9 @@ void ItemIconView::setupConnections()
     connect(d->parent, SIGNAL(signalPasteAlbumItemsSelection()),
             this, SLOT(slotImagePaste()));
 
+    connect(d->parent, SIGNAL(signalNotificationError(QString,int)),
+            this, SLOT(slotNotificationError(QString,int)));
+
     // -- AlbumManager connections --------------------------------
 
     connect(d->albumManager, SIGNAL(signalAlbumCurrentChanged(QList<Album*>)),
@@ -383,12 +388,12 @@ void ItemIconView::setupConnections()
     connect(this, SIGNAL(signalNoCurrentItem()),
             d->rightSideBar, SLOT(slotNoCurrentItem()));
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
     connect(d->gpsSearchSideBar, SIGNAL(signalMapSoloItems(QList<qlonglong>,QString)),
             d->iconView->imageFilterModel(), SLOT(setIdWhitelist(QList<qlonglong>,QString)));
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
     // -- Filter Bars Connections ---------------------------------
 
@@ -415,37 +420,37 @@ void ItemIconView::setupConnections()
 
     // -- Preview image widget Connections ------------------------
 
-    connect(d->stackedview, SIGNAL(signalNextItem()),
+    connect(d->stackedView, SIGNAL(signalNextItem()),
             this, SLOT(slotNextItem()));
 
-    connect(d->stackedview, SIGNAL(signalPrevItem()),
+    connect(d->stackedView, SIGNAL(signalPrevItem()),
             this, SLOT(slotPrevItem()));
 
-    connect(d->stackedview, SIGNAL(signalDeleteItem()),
+    connect(d->stackedView, SIGNAL(signalDeleteItem()),
             this, SLOT(slotImageDelete()));
 
-    connect(d->stackedview, SIGNAL(signalViewModeChanged()),
+    connect(d->stackedView, SIGNAL(signalViewModeChanged()),
             this, SLOT(slotViewModeChanged()));
 
-    connect(d->stackedview, SIGNAL(signalEscapePreview()),
+    connect(d->stackedView, SIGNAL(signalEscapePreview()),
             this, SLOT(slotEscapePreview()));
 
-    connect(d->stackedview, SIGNAL(signalZoomFactorChanged(double)),
+    connect(d->stackedView, SIGNAL(signalZoomFactorChanged(double)),
             this, SLOT(slotZoomFactorChanged(double)));
 
-    connect(d->stackedview, SIGNAL(signalAddToExistingQueue(int)),
+    connect(d->stackedView, SIGNAL(signalAddToExistingQueue(int)),
             this, SLOT(slotImageAddToExistingQueue(int)));
 
-    connect(d->stackedview, SIGNAL(signalGotoAlbumAndItem(ItemInfo)),
+    connect(d->stackedView, SIGNAL(signalGotoAlbumAndItem(ItemInfo)),
             this, SLOT(slotGotoAlbumAndItem(ItemInfo)));
 
-    connect(d->stackedview, SIGNAL(signalGotoDateAndItem(ItemInfo)),
+    connect(d->stackedView, SIGNAL(signalGotoDateAndItem(ItemInfo)),
             this, SLOT(slotGotoDateAndItem(ItemInfo)));
 
-    connect(d->stackedview, SIGNAL(signalGotoTagAndItem(int)),
+    connect(d->stackedView, SIGNAL(signalGotoTagAndItem(int)),
             this, SLOT(slotGotoTagAndItem(int)));
 
-    connect(d->stackedview, SIGNAL(signalPopupTagsView()),
+    connect(d->stackedView, SIGNAL(signalPopupTagsView()),
             d->rightSideBar, SLOT(slotPopupTagsView()));
 
     // -- FileActionMngr progress ---------------
@@ -506,7 +511,7 @@ void ItemIconView::setupConnections()
 
 void ItemIconView::loadViewState()
 {
-    Q_FOREACH (SidebarWidget* const widget, d->leftSideBarWidgets)
+    for (SidebarWidget* const widget : std::as_const(d->leftSideBarWidgets))
     {
         widget->loadState();
     }
@@ -528,13 +533,14 @@ void ItemIconView::loadViewState()
 
     d->initialAlbumID = group.readEntry(QLatin1String("InitialAlbumID"), 0);
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
     d->mapView->loadState();
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
     d->tableView->loadState();
+    d->leftSideBar->loadState();
     d->rightSideBar->loadState();
 }
 
@@ -543,7 +549,7 @@ void ItemIconView::saveViewState()
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     KConfigGroup group        = config->group(QLatin1String("MainWindow"));
 
-    Q_FOREACH (SidebarWidget* const widget, d->leftSideBarWidgets)
+    for (SidebarWidget* const widget : std::as_const(d->leftSideBarWidgets))
     {
         widget->saveState();
     }
@@ -559,7 +565,7 @@ void ItemIconView::saveViewState()
     // (when the user is in image preview mode) when the layout is saved, it
     // also reappears when restoring the view, while it should always be hidden.
 
-    d->stackedview->thumbBarDock()->close();
+    d->stackedView->thumbBarDock()->close();
     group.writeEntry(QLatin1String("ThumbbarState"), d->dockArea->saveState().toBase64());
 
     QList<Album*> albumList = AlbumManager::instance()->currentAlbums();
@@ -579,14 +585,16 @@ void ItemIconView::saveViewState()
         group.writeEntry(QLatin1String("InitialAlbumID"), 0);
     }
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
     d->mapView->saveState();
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
     d->tableView->saveState();
     d->rightSideBar->saveState();
 }
 
 } // namespace Digikam
+
+#include "moc_itemiconview.cpp"
