@@ -29,8 +29,6 @@ void ItemIconView::slotAllAlbumsLoaded()
                this, SLOT(slotAllAlbumsLoaded()));
 
     loadViewState();
-    d->leftSideBar->loadState();
-    d->rightSideBar->loadState();
     d->rightSideBar->populateTags();
 
     // now that all albums have been loaded, activate the albumHistory
@@ -171,6 +169,7 @@ void ItemIconView::slotAlbumSelected(const QList<Album*>& albums)
 
     if      (album->isRoot())
     {
+        slotTogglePreviewMode(ItemInfo());
         d->stackedView->setViewMode(StackedView::WelcomePageMode);
     }
     else if (album->isTrashAlbum())
@@ -194,11 +193,15 @@ void ItemIconView::slotAlbumSelected(const QList<Album*>& albums)
             case StackedView::MediaPlayerMode:
             case StackedView::WelcomePageMode:
             case StackedView::TrashViewMode:
+            {
                 slotTogglePreviewMode(ItemInfo());
                 break;
+            }
 
             default:
+            {
                 break;
+            }
         }
 
         d->filterWidget->setEnabled(true);
@@ -333,6 +336,16 @@ void ItemIconView::slotAlbumRefreshComplete()
 
 void ItemIconView::slotAlbumPropsEdit()
 {
+    QAction* const action     = dynamic_cast<QAction*>(sender());
+    TagFolderView* const view = dynamic_cast<TagFolderView*>(qApp->focusWidget());
+
+    if (view && action && (action->shortcut() == QKeySequence(Qt::ALT | Qt::Key_Return)))
+    {
+        view->tagPropsEdit();
+
+        return;
+    }
+
     d->albumModificationHelper->slotAlbumEdit(d->albumManager->currentPAlbum());
 }
 
@@ -346,6 +359,14 @@ void ItemIconView::slotAlbumWriteMetadata()
     }
 
     MetadataSynchronizer* const tool = new MetadataSynchronizer(AlbumList() << album, MetadataSynchronizer::WriteFromDatabaseToFile);
+
+    if (MetadataHubMngr::isCreated())
+    {
+        connect (tool, SIGNAL(signalRemovePending(ItemInfo)),
+                 MetadataHubMngr::instance(), SLOT(slotRemovePending(ItemInfo)),
+                 Qt::QueuedConnection);
+    }
+
     tool->start();
 }
 
@@ -373,18 +394,24 @@ Album* ItemIconView::currentAlbum() const
     switch (viewMode())
     {
         case StackedView::TableViewMode:
+        {
             return d->tableView->currentAlbum();
+        }
 
         case StackedView::PreviewImageMode:
         case StackedView::MediaPlayerMode:
         case StackedView::MapWidgetMode:
         case StackedView::IconViewMode:
+        {
             // all of these modes use the same selection model and data as the IconViewMode
 
             return d->iconView->currentAlbum();
+        }
 
         default:
+        {
             return nullptr;
+        }
     }
 }
 
@@ -404,18 +431,23 @@ void ItemIconView::slotRefresh()
     switch (viewMode())
     {
         case StackedView::PreviewImageMode:
+        {
             d->stackedView->imagePreviewView()->reload();
             break;
+        }
 
 #ifdef HAVE_MEDIAPLAYER
 
         case StackedView::MediaPlayerMode:
+        {
             d->stackedView->mediaPlayerView()->reload();
             break;
+        }
 
 #endif // HAVE_MEDIAPLAYER
 
         default:
+        {
             Album* const album = currentAlbum();
 
             if (!album)
@@ -447,6 +479,7 @@ void ItemIconView::slotRefresh()
             }
 
             break;
+        }
     }
 }
 
