@@ -23,43 +23,55 @@
 namespace Digikam
 {
 
-bool ItemIconView::allNeedGroupResolving(const ApplicationSettings::OperationType type) const
+bool ItemIconView::allNeedGroupResolving(const OperationType type) const
 {
     switch (viewMode())
     {
         case StackedView::TableViewMode:
+        {
             return d->tableView->allNeedGroupResolving(type);
+        }
 
         case StackedView::MapWidgetMode:
         case StackedView::PreviewImageMode:
         case StackedView::MediaPlayerMode:
         case StackedView::IconViewMode:
+        {
             // all of these modes use the same selection model and data as the IconViewMode
 
             return d->iconView->allNeedGroupResolving(type);
+        }
 
         default:
+        {
             return false;
+        }
     }
 }
 
-bool ItemIconView::selectedNeedGroupResolving(const ApplicationSettings::OperationType type) const
+bool ItemIconView::selectedNeedGroupResolving(const OperationType type) const
 {
     switch (viewMode())
     {
         case StackedView::TableViewMode:
+        {
             return d->tableView->selectedNeedGroupResolving(type);
+        }
 
         case StackedView::MapWidgetMode:
         case StackedView::PreviewImageMode:
         case StackedView::MediaPlayerMode:
         case StackedView::IconViewMode:
+        {
             // all of these modes use the same selection model and data as the IconViewMode
 
             return d->iconView->selectedNeedGroupResolving(type);
+        }
 
         default:
+        {
             return false;
+        }
     }
 }
 
