@@ -7,7 +7,7 @@
  * Description : Item icon view interface - Image Quality Sorting.
  *
  * SPDX-FileCopyrightText: 2021-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * SPDX-FileCopyrightText: 2021 by Phuoc Khanh Le <phuockhanhnk94 at gmail dot com>
+ * SPDX-FileCopyrightText: 2021      by Phuoc Khanh Le <phuockhanhnk94 at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -28,10 +28,11 @@ void ItemIconView::slotImageQualitySorter()
     Setup::execSinglePage(qApp->activeWindow(), Setup::ImageQualityPage);
 
     QStringList paths;
+    const auto urls = selectedUrls();
 
-    for (const auto& url : selectedUrls())
+    for (const auto& url : urls)
     {
-        paths<<url.toLocalFile();
+        paths << url.toLocalFile();
     }
 
     SetupImageQualitySorter* const settingWidgets = new SetupImageQualitySorter();
