@@ -7,7 +7,7 @@
  * Description : Item icon view interface - Item methods.
  *
  * SPDX-FileCopyrightText: 2002-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2002-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2002-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2009-2011 by Johannes Wienke <languitar at semipol dot de>
  * SPDX-FileCopyrightText: 2010-2011 by Andi Clemens <andi dot clemens at gmail dot com>
  * SPDX-FileCopyrightText: 2011-2013 by Michael G. Hansen <mike at mghansen dot de>
@@ -35,7 +35,7 @@ QList<QUrl> ItemIconView::selectedUrls(bool grouping) const
     return selectedInfoList(false, grouping).toImageUrlList();
 }
 
-QList<QUrl> ItemIconView::selectedUrls(const ApplicationSettings::OperationType type) const
+QList<QUrl> ItemIconView::selectedUrls(const OperationType type) const
 {
     return selectedInfoList(type).toImageUrlList();
 }
@@ -45,14 +45,18 @@ void ItemIconView::slotFirstItem()
     switch (viewMode())
     {
         case StackedView::TableViewMode:
+        {
             d->tableView->slotGoToRow(0, false);
             break;
+        }
 
         default:
+        {
             // all other views are tied to IconView's selection model
 
             d->iconView->toFirstIndex();
             break;
+        }
     }
 }
 
@@ -61,14 +65,18 @@ void ItemIconView::slotPrevItem()
     switch (viewMode())
     {
         case StackedView::TableViewMode:
+        {
             d->tableView->slotGoToRow(-1, true);
             break;
+        }
 
         default:
+        {
             // all other views are tied to IconView's selection model
 
             d->iconView->toPreviousIndex();
             break;
+        }
     }
 }
 
@@ -77,14 +85,18 @@ void ItemIconView::slotNextItem()
     switch (viewMode())
     {
         case StackedView::TableViewMode:
+        {
             d->tableView->slotGoToRow(1, true);
             break;
+        }
 
         default:
+        {
             // all other views are tied to IconView's selection model
 
             d->iconView->toNextIndex();
             break;
+        }
     }
 }
 
@@ -93,14 +105,18 @@ void ItemIconView::slotLastItem()
     switch (viewMode())
     {
         case StackedView::TableViewMode:
+        {
             d->tableView->slotGoToRow(-1, false);
             break;
+        }
 
         default:
+        {
             // all other views are tied to IconView's selection model
 
             d->iconView->toLastIndex();
             break;
+        }
     }
 }
 
@@ -121,16 +137,25 @@ void ItemIconView::slotImageSelected()
     switch (viewMode())
     {
         case StackedView::TrashViewMode:
+        {
             Q_EMIT signalTrashSelectionChanged(d->trashView->statusBarText());
+
             break;
+        }
 
         case StackedView::TableViewMode:
+        {
             Q_EMIT signalSelectionChanged(d->tableView->numberOfSelectedItems());
+
             break;
+        }
 
         default:
+        {
             Q_EMIT signalSelectionChanged(d->iconView->numberOfSelectedIndexes());
+
             break;
+        }
     }
 }
 
@@ -153,14 +178,16 @@ void ItemIconView::slotDispatchImageSelected()
     }
 
     // the list of ItemInfos of currently selected items, currentItem first
+
     ApplicationSettings::ApplyToEntireGroup applyAll =
-        ApplicationSettings::instance()->getGroupingOperateOnAll(ApplicationSettings::Metadata);
+        ApplicationSettings::instance()->getGroupingOperateOnAll(MetadataOps);
+
     const ItemInfoList& list      = selectedInfoList(true, (applyAll == ApplicationSettings::Yes));
     const ItemInfoList& allImages = allInfo(true);
 
     if (list.isEmpty())
     {
-        d->stackedview->setPreviewItem();
+        d->stackedView->setPreviewItem();
 
         Q_EMIT signalImageSelected(list, allImages);
         Q_EMIT signalNoCurrentItem();
@@ -189,7 +216,7 @@ void ItemIconView::slotDispatchImageSelected()
             (viewMode() != StackedView::TableViewMode)
            )
         {
-            d->stackedview->setPreviewItem(list.first(), previousInfo, nextInfo);
+            d->stackedView->setPreviewItem(list.first(), previousInfo, nextInfo);
         }
 
         Q_EMIT signalImageSelected(list, allImages);
@@ -198,14 +225,22 @@ void ItemIconView::slotDispatchImageSelected()
 
 void ItemIconView::slotImageWriteMetadata()
 {
-    const ItemInfoList& selected     = selectedInfoList(ApplicationSettings::Metadata);
+    const ItemInfoList& selected     = selectedInfoList(MetadataOps);
     MetadataSynchronizer* const tool = new MetadataSynchronizer(selected, MetadataSynchronizer::WriteFromDatabaseToFile);
+
+    if (MetadataHubMngr::isCreated())
+    {
+        connect (tool, SIGNAL(signalRemovePending(ItemInfo)),
+                 MetadataHubMngr::instance(), SLOT(slotRemovePending(ItemInfo)),
+                 Qt::QueuedConnection);
+    }
+
     tool->start();
 }
 
 void ItemIconView::slotImageReadMetadata()
 {
-    const ItemInfoList& selected     = selectedInfoList(ApplicationSettings::Metadata);
+    const ItemInfoList& selected     = selectedInfoList(MetadataOps);
     MetadataSynchronizer* const tool = new MetadataSynchronizer(selected, MetadataSynchronizer::ReadFromFileToDatabase);
     tool->setUseMultiCoreCPU(false);
     tool->start();
@@ -215,7 +250,7 @@ void ItemIconView::slotRefreshImagePreview()
 {
     if (viewMode() == StackedView::PreviewImageMode)
     {
-        d->stackedview->imagePreviewView()->reload();
+        d->stackedView->imagePreviewView()->reload();
     }
 }
 
@@ -224,12 +259,16 @@ void ItemIconView::slotImageRename()
     switch (viewMode())
     {
         case StackedView::TableViewMode:
+        {
             d->tableView->rename();
             break;
+        }
 
         default:
+        {
             d->iconView->rename();
             break;
+        }
     }
 }
 
@@ -238,8 +277,10 @@ void ItemIconView::slotImageDelete()
     switch (viewMode())
     {
         case StackedView::TableViewMode:
+        {
             d->tableView->slotDeleteSelected(ItemViewUtilities::DeleteUseTrash);
             break;
+        }
 
         default:
         {
@@ -248,7 +289,7 @@ void ItemIconView::slotImageDelete()
 
             if (viewMode() == StackedView::MediaPlayerMode)
             {
-                d->stackedview->mediaPlayerView()->escapePreview();
+                d->stackedView->mediaPlayerView()->escapePreview();
             }
 
 #endif // HAVE_MEDIAPLAYER
@@ -264,8 +305,10 @@ void ItemIconView::slotImageDeletePermanently()
     switch (viewMode())
     {
         case StackedView::TableViewMode:
+        {
             d->tableView->slotDeleteSelected(ItemViewUtilities::DeletePermanently);
             break;
+        }
 
         default:
         {
@@ -274,7 +317,7 @@ void ItemIconView::slotImageDeletePermanently()
 
             if (viewMode() == StackedView::MediaPlayerMode)
             {
-                d->stackedview->mediaPlayerView()->escapePreview();
+                d->stackedView->mediaPlayerView()->escapePreview();
             }
 
 #endif // HAVE_MEDIAPLAYER
@@ -290,12 +333,16 @@ void ItemIconView::slotImageDeletePermanentlyDirectly()
     switch (viewMode())
     {
         case StackedView::TableViewMode:
+        {
             d->tableView->slotDeleteSelectedWithoutConfirmation(ItemViewUtilities::DeletePermanently);
             break;
+        }
 
         default:
+        {
             d->iconView->deleteSelectedDirectly(ItemViewUtilities::DeletePermanently);
             break;
+        }
     }
 }
 
@@ -304,12 +351,16 @@ void ItemIconView::slotImageTrashDirectly()
     switch (viewMode())
     {
         case StackedView::TableViewMode:
+        {
             d->tableView->slotDeleteSelectedWithoutConfirmation(ItemViewUtilities::DeleteUseTrash);
             break;
+        }
 
         default:
+        {
             d->iconView->deleteSelectedDirectly(ItemViewUtilities::DeleteUseTrash);
             break;
+        }
     }
 }
 
@@ -318,12 +369,16 @@ void ItemIconView::slotSelectAll()
     switch (viewMode())
     {
         case StackedView::TableViewMode:
+        {
             d->tableView->selectAll();
             break;
+        }
 
         default:
+        {
             d->iconView->selectAll();
             break;
+        }
     }
 }
 
@@ -332,12 +387,16 @@ void ItemIconView::slotSelectNone()
     switch (viewMode())
     {
         case StackedView::TableViewMode:
+        {
             d->tableView->clearSelection();
             break;
+        }
 
         default:
+        {
             d->iconView->clearSelection();
             break;
+        }
     }
 }
 
@@ -346,12 +405,16 @@ void ItemIconView::slotSelectInvert()
     switch (viewMode())
     {
         case StackedView::TableViewMode:
+        {
             d->tableView->invertSelection();
             break;
+        }
 
         default:
+        {
             d->iconView->invertSelection();
             break;
+        }
     }
 }
 
@@ -414,12 +477,16 @@ void ItemIconView::slotImagePaste()
     switch (viewMode())
     {
         case StackedView::TableViewMode:
+        {
             d->tableView->slotPaste();
             break;
+        }
 
         default:
+        {
             d->iconView->paste();
             break;
+        }
     }
 }
 
@@ -446,7 +513,7 @@ void ItemIconView::slotFocusAndNextImage()
 {
     // slot is called on pressing "return" a second time after assigning a tag
 
-    d->stackedview->currentWidget()->setFocus();
+    d->stackedView->currentWidget()->setFocus();
 
     // select next image, since the user is probably done tagging the current image
 
@@ -456,13 +523,13 @@ void ItemIconView::slotFocusAndNextImage()
 void ItemIconView::slotImageExifOrientation(int orientation)
 {
     FileActionMngr::instance()->setExifOrientation(
-                selectedInfoList(ApplicationSettings::Metadata), orientation);
+                selectedInfoList(MetadataOps), orientation);
 }
 
 void ItemIconView::imageTransform(MetaEngineRotation::TransformationAction transform)
 {
     FileActionMngr::instance()->transform(
-                selectedInfoList(ApplicationSettings::Metadata), transform);
+                selectedInfoList(MetadataOps), transform);
 }
 
 ItemInfo ItemIconView::currentInfo() const
@@ -470,24 +537,32 @@ ItemInfo ItemIconView::currentInfo() const
     switch (viewMode())
     {
         case StackedView::TableViewMode:
+        {
             return d->tableView->currentInfo();
+        }
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
         case StackedView::MapWidgetMode:
+        {
             return d->mapView->currentItemInfo();
+        }
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
         case StackedView::MediaPlayerMode:
         case StackedView::PreviewImageMode:
         case StackedView::IconViewMode:
+        {
             // all of these modes use the same selection model and data as the IconViewMode
 
             return d->iconView->currentInfo();
+        }
 
         default:
+        {
             return ItemInfo();
+        }
     }
 }
 
@@ -497,6 +572,7 @@ ItemInfoList ItemIconView::selectedInfoList(const bool currentFirst,
     switch (viewMode())
     {
         case StackedView::TableViewMode:
+        {
 
             if (currentFirst)
             {
@@ -504,11 +580,13 @@ ItemInfoList ItemIconView::selectedInfoList(const bool currentFirst,
             }
 
             return d->tableView->selectedItemInfos(grouping);
+        }
 
         case StackedView::PreviewImageMode:
         case StackedView::MediaPlayerMode:
         case StackedView::MapWidgetMode:
         case StackedView::IconViewMode:
+        {
 
             // all of these modes use the same selection model and data as the IconViewMode
 
@@ -518,14 +596,16 @@ ItemInfoList ItemIconView::selectedInfoList(const bool currentFirst,
             }
 
             return d->iconView->selectedItemInfos(grouping);
+        }
 
         default:
-
+        {
             return ItemInfoList();
+        }
     }
 }
 
-ItemInfoList ItemIconView::selectedInfoList(const ApplicationSettings::OperationType type,
+ItemInfoList ItemIconView::selectedInfoList(const OperationType type,
                                             const bool currentFirst) const
 {
     return selectedInfoList(currentFirst, selectedNeedGroupResolving(type));
@@ -536,22 +616,28 @@ ItemInfoList ItemIconView::allInfo(const bool grouping) const
     switch (viewMode())
     {
         case StackedView::TableViewMode:
+        {
             return d->tableView->allItemInfos(grouping);
+        }
 
         case StackedView::MapWidgetMode:
         case StackedView::PreviewImageMode:
         case StackedView::MediaPlayerMode:
         case StackedView::IconViewMode:
+        {
             // all of these modes use the same selection model and data as the IconViewMode
 
             return d->iconView->allItemInfos(grouping);
+        }
 
         default:
+        {
             return ItemInfoList();
+        }
     }
 }
 
-ItemInfoList ItemIconView::allInfo(const ApplicationSettings::OperationType type) const
+ItemInfoList ItemIconView::allInfo(const OperationType type) const
 {
     return allInfo(allNeedGroupResolving(type));
 }
@@ -573,12 +659,16 @@ void ItemIconView::slotSetCurrentUrlWhenAvailable(const QUrl& url)
     switch (viewMode())
     {
         case StackedView::TableViewMode:
+        {
             d->tableView->slotSetCurrentUrlWhenAvailable(url);
             break;
+        }
 
         default:
+        {
             d->iconView->setCurrentUrlWhenAvailable(url);
             break;
+        }
     }
 }
 
@@ -587,12 +677,16 @@ void ItemIconView::slotSetCurrentWhenAvailable(const qlonglong id)
     switch (viewMode())
     {
         case StackedView::TableViewMode:
+        {
             d->tableView->slotSetCurrentWhenAvailable(id);
             break;
+        }
 
         default:
+        {
             d->iconView->setCurrentWhenAvailable(id);
             break;
+        }
     }
 }
 
@@ -601,12 +695,16 @@ void ItemIconView::slotAwayFromSelection()
     switch (viewMode())
     {
         case StackedView::TableViewMode:
+        {
             d->tableView->slotAwayFromSelection();
             break;
+        }
 
         default:
+        {
             d->iconView->awayFromSelection();
             break;
+        }
     }
 }
 
@@ -628,21 +726,24 @@ void ItemIconView::slotEmptyMessageTimer()
 
     if (!album || album->isRoot() || (album->type() != Album::SEARCH))
     {
-        d->errorWidget->animatedHide();
+        if (d->errorWidget->messageType() == DNotificationWidget::Notification)
+        {
+            d->errorWidget->animatedHide();
+        }
 
         return;
     }
 
-    if (!d->iconView->imageModel()->itemCount())
+    if      (!d->iconView->imageModel()->itemCount())
     {
         QString message = i18n("The current query from the database returned no results. "
                                "Change search settings or select an album with content.");
 
-        d->errorWidget->setMessageType(DNotificationWidget::Information);
+        d->errorWidget->setMessageType(DNotificationWidget::Notification);
         d->errorWidget->setText(message);
         d->errorWidget->animatedShowTemporized(5000);
     }
-    else
+    else if (d->errorWidget->messageType() == DNotificationWidget::Notification)
     {
         d->errorWidget->animatedHide();
     }
