@@ -76,6 +76,7 @@
 #include "metaenginesettings.h"
 #include "metadatasynchronizer.h"
 #include "metadataremover.h"
+#include "metadatahubmngr.h"
 #include "newitemsfinder.h"
 #include "queuemgrwindow.h"
 #include "scancontroller.h"
@@ -96,6 +97,7 @@
 #include "coredb.h"
 #include "coredbaccess.h"
 #include "addtagslineedit.h"
+#include "tagfolderview.h"
 
 #ifdef HAVE_MEDIAPLAYER
 #   include "mediaplayerview.h"
