@@ -60,12 +60,12 @@ void ItemIconView::slotEscapePreview()
 
 void ItemIconView::slotMapWidgetView()
 {
-    d->stackedView->setViewMode(StackedView::MapWidgetMode);
+    d->stackedView->setViewMode(StackedView::MapWidgetMode, true);
 }
 
 void ItemIconView::slotTableView()
 {
-    d->stackedView->setViewMode(StackedView::TableViewMode);
+    d->stackedView->setViewMode(StackedView::TableViewMode, true);
 }
 
 void ItemIconView::slotIconView()
@@ -77,7 +77,7 @@ void ItemIconView::slotIconView()
 
     // and switch to icon view
 
-    d->stackedView->setViewMode(StackedView::IconViewMode);
+    d->stackedView->setViewMode(StackedView::IconViewMode, true);
 
     // make sure the next/previous buttons are updated
 
@@ -95,37 +95,43 @@ void ItemIconView::slotImagePreview()
 void ItemIconView::slotTogglePreviewMode(const ItemInfo& info)
 {
     if (
-        (
-         (viewMode() == StackedView::IconViewMode)   ||
-         (viewMode() == StackedView::TableViewMode)  ||
-         (viewMode() == StackedView::MapWidgetMode)
-        ) &&
-        !info.isNull()
+        (viewMode() == StackedView::IconViewMode)  ||
+        (viewMode() == StackedView::TableViewMode) ||
+        (viewMode() == StackedView::MapWidgetMode)
        )
     {
-        if (info.isLocationAvailable())
-        {
-            d->lastViewMode = viewMode();
+        d->lastViewMode = viewMode();
 
-            if (viewMode() == StackedView::IconViewMode)
+        if (!info.isNull())
+        {
+            if (info.isLocationAvailable())
             {
-                d->stackedView->setPreviewItem(info, d->iconView->previousInfo(info), d->iconView->nextInfo(info));
+                if (viewMode() == StackedView::IconViewMode)
+                {
+                    d->stackedView->setPreviewItem(info,
+                                                   d->iconView->previousInfo(info),
+                                                   d->iconView->nextInfo(info));
+                }
+                else
+                {
+                    d->stackedView->setPreviewItem(info,
+                                                   ItemInfo(),
+                                                   ItemInfo());
+                }
             }
             else
             {
-                d->stackedView->setPreviewItem(info, ItemInfo(), ItemInfo());
+                QModelIndex index = d->iconView->indexForInfo(info);
+                d->iconView->showIndexNotification(index,
+                                                   i18nc("@info: item icon view",
+                                                         "The storage location of this image\n"
+                                                         "is currently not available"));
             }
         }
-        else
-        {
-            QModelIndex index = d->iconView->indexForInfo(info);
-            d->iconView->showIndexNotification(index,
-                                               i18nc("@info: item icon view", "The storage location of this image\nis currently not available"));
-        }
     }
     else
     {
-        // go back to either AlbumViewMode or MapWidgetMode
+        // go back to the last AlbumViewMode
 
         d->stackedView->setViewMode(d->lastViewMode);
     }
@@ -421,7 +427,7 @@ void ItemIconView::slotShowGroupContextMenu(QContextMenuEvent* event,
 {
     QList<qlonglong> selectedImageIDs;
 
-    Q_FOREACH (const ItemInfo& info, selectedInfos)
+    for (const ItemInfo& info : std::as_const(selectedInfos))
     {
         selectedImageIDs << info.id();
     }
