@@ -7,7 +7,7 @@
  * Description : Item icon view interface - Zoom methods.
  *
  * SPDX-FileCopyrightText: 2002-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2002-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2002-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2009-2011 by Johannes Wienke <languitar at semipol dot de>
  * SPDX-FileCopyrightText: 2010-2011 by Andi Clemens <andi dot clemens at gmail dot com>
  * SPDX-FileCopyrightText: 2011-2013 by Michael G. Hansen <mike at mghansen dot de>
@@ -25,17 +25,17 @@ namespace Digikam
 
 double ItemIconView::zoomMin() const
 {
-    return d->stackedview->zoomMin();
+    return d->stackedView->zoomMin();
 }
 
 double ItemIconView::zoomMax() const
 {
-    return d->stackedview->zoomMax();
+    return d->stackedView->zoomMax();
 }
 
 void ItemIconView::setZoomFactor(double zoom)
 {
-    d->stackedview->setZoomFactorSnapped(zoom);
+    d->stackedView->setZoomFactorSnapped(zoom);
 }
 
 void ItemIconView::slotZoomFactorChanged(double zoom)
@@ -52,18 +52,20 @@ void ItemIconView::toggleZoomActions()
         d->parent->enableZoomMinusAction(true);
         d->parent->enableZoomPlusAction(true);
 
-        if (d->stackedview->maxZoom())
+        if (d->stackedView->maxZoom())
         {
             d->parent->enableZoomPlusAction(false);
         }
 
-        if (d->stackedview->minZoom())
+        if (d->stackedView->minZoom())
         {
             d->parent->enableZoomMinusAction(false);
         }
     }
-    else if ((viewMode() == StackedView::IconViewMode) ||
-             (viewMode() == StackedView::TableViewMode))
+    else if (
+             (viewMode() == StackedView::IconViewMode) ||
+             (viewMode() == StackedView::TableViewMode)
+            )
     {
         d->parent->enableZoomMinusAction(true);
         d->parent->enableZoomPlusAction(true);
@@ -87,31 +89,37 @@ void ItemIconView::toggleZoomActions()
 
 void ItemIconView::slotZoomIn()
 {
-    if      ((viewMode() == StackedView::IconViewMode) ||
-             (viewMode() == StackedView::TableViewMode))
+    if      (
+             (viewMode() == StackedView::IconViewMode) ||
+             (viewMode() == StackedView::TableViewMode)
+            )
     {
         setThumbSize(d->thumbSize + ThumbnailSize::Step);
         toggleZoomActions();
+
         Q_EMIT signalThumbSizeChanged(d->thumbSize);
     }
     else if (viewMode() == StackedView::PreviewImageMode)
     {
-        d->stackedview->increaseZoom();
+        d->stackedView->increaseZoom();
     }
 }
 
 void ItemIconView::slotZoomOut()
 {
-    if      ((viewMode() == StackedView::IconViewMode) ||
-             (viewMode() == StackedView::TableViewMode))
+    if      (
+             (viewMode() == StackedView::IconViewMode) ||
+             (viewMode() == StackedView::TableViewMode)
+            )
     {
         setThumbSize(d->thumbSize - ThumbnailSize::Step);
         toggleZoomActions();
+
         Q_EMIT signalThumbSizeChanged(d->thumbSize);
     }
     else if (viewMode() == StackedView::PreviewImageMode)
     {
-        d->stackedview->decreaseZoom();
+        d->stackedView->decreaseZoom();
     }
 }
 
@@ -119,7 +127,7 @@ void ItemIconView::slotZoomTo100Percents()
 {
     if (viewMode() == StackedView::PreviewImageMode)
     {
-        d->stackedview->toggleFitToWindowOr100();
+        d->stackedView->toggleFitToWindowOr100();
     }
 }
 
@@ -135,11 +143,12 @@ void ItemIconView::slotFitToWindow()
         qCDebug(DIGIKAM_GENERAL_LOG) << "new thumb size = " << nts;
         setThumbSize(nts);
         toggleZoomActions();
+
         Q_EMIT signalThumbSizeChanged(d->thumbSize);
     }
     else if (viewMode() == StackedView::PreviewImageMode)
     {
-        d->stackedview->fitToWindow();
+        d->stackedView->fitToWindow();
     }
 }
 
@@ -150,9 +159,11 @@ void ItemIconView::setThumbSize(int size)
         double z = DZoomBar::zoomFromSize(size, zoomMin(), zoomMax());
         setZoomFactor(z);
     }
-    else if ((viewMode() == StackedView::IconViewMode)  ||
+    else if (
+             (viewMode() == StackedView::IconViewMode)  ||
              (viewMode() == StackedView::TableViewMode) ||
-             (viewMode() == StackedView::TrashViewMode))
+             (viewMode() == StackedView::TrashViewMode)
+            )
     {
         if      (size > ThumbnailSize::maxThumbsSize())
         {
