@@ -64,39 +64,25 @@ class Q_DECL_HIDDEN MapWidgetView::Private
 {
 public:
 
-    explicit Private()
-       : mapWidget                  (nullptr),
-         imageModel                 (nullptr),
-         imageFilterModel           (nullptr),
-         importModel                (nullptr),
-         importFilterModel          (nullptr),
-         selectionModel             (nullptr),
-         mapViewModelHelper         (nullptr),
-         gpsItemInfoSorter          (nullptr),
-         trackManager               (nullptr),
-         modelTimer                 (nullptr),
-         application                (MapWidgetView::ApplicationDigikam),
-         boundariesShouldBeAdjusted (false)
-    {
-    }
+    Private() = default;
 
-    MapWidget*                 mapWidget;
+    MapWidget*                 mapWidget                    = nullptr;
 
-    ItemAlbumModel*            imageModel;
-    ItemFilterModel*           imageFilterModel;
-    ImportItemModel*           importModel;
-    ImportFilterModel*         importFilterModel;
-    QItemSelectionModel*       selectionModel;
+    ItemAlbumModel*            imageModel                   = nullptr;
+    ItemFilterModel*           imageFilterModel             = nullptr;
+    ImportItemModel*           importModel                  = nullptr;
+    ImportFilterModel*         importFilterModel            = nullptr;
+    QItemSelectionModel*       selectionModel               = nullptr;
 
-    MapViewModelHelper*        mapViewModelHelper;
-    GPSItemInfoSorter*         gpsItemInfoSorter;
-    TrackManager*              trackManager;
+    MapViewModelHelper*        mapViewModelHelper           = nullptr;
+    GPSItemInfoSorter*         gpsItemInfoSorter            = nullptr;
+    TrackManager*              trackManager                 = nullptr;
 
-    QTimer*                    modelTimer;
+    QTimer*                    modelTimer                   = nullptr;
 
-    MapWidgetView::Application application;
+    MapWidgetView::Application application                  = MapWidgetView::ApplicationDigikam;
 
-    bool                       boundariesShouldBeAdjusted;
+    bool                       boundariesShouldBeAdjusted   = false;
 };
 
 /**
@@ -111,7 +97,7 @@ MapWidgetView::MapWidgetView(QItemSelectionModel* const selectionModel,
                              const MapWidgetView::Application application)
     : QWidget          (parent),
       StateSavingObject(this),
-      d                (new Private())
+      d                (new Private)
 {
     d->application    = application;
     d->selectionModel = selectionModel;
@@ -300,7 +286,9 @@ void MapWidgetView::slotModelChanged()
     {
         case ApplicationDigikam:
         {
-            Q_FOREACH (const ItemInfo& info, d->imageModel->imageInfos())
+            const auto infs = d->imageModel->imageInfos();
+
+            for (const ItemInfo& info : infs)
             {
                 if (info.hasCoordinates())
                 {
@@ -314,13 +302,17 @@ void MapWidgetView::slotModelChanged()
 
         case ApplicationImportUI:
         {
-            Q_FOREACH (const CamItemInfo& info, d->importModel->camItemInfos())
+            const auto infs = d->importModel->camItemInfos();
+
+            for (const CamItemInfo& info : infs)
             {
                 QScopedPointer<DMetadata> meta(new DMetadata(info.url().toLocalFile()));
                 double lat, lng;
 
-                if (meta->getGPSLatitudeNumber(&lat) &&
-                    meta->getGPSLongitudeNumber(&lng))
+                if (
+                    meta->getGPSLatitudeNumber(&lat) &&
+                    meta->getGPSLongitudeNumber(&lng)
+                   )
                 {
                     hasCoordinates = true;
                     break;
@@ -371,7 +363,9 @@ void MapWidgetView::slotLoadTracksFromAlbums()
 
     QList<QUrl> fileUrls;
 
-    Q_FOREACH (const ItemInfo& info, d->imageModel->imageInfos())
+    const auto infs = d->imageModel->imageInfos();
+
+    for (const ItemInfo& info : infs)
     {
         if (info.hasCoordinates())
         {
@@ -395,11 +389,12 @@ void MapWidgetView::slotLoadTracksFromAlbums()
     QList<QUrl> gpxList;
     const QStringList filter({QLatin1String("*.gpx")});
 
-    Q_FOREACH (const QUrl& url, fileUrls)
+    for (const QUrl& url : std::as_const(fileUrls))
     {
         QDir dir(url.toLocalFile());
+        const auto inflst = dir.entryInfoList(filter, QDir::Files);
 
-        Q_FOREACH (const QFileInfo& finfo, dir.entryInfoList(filter, QDir::Files))
+        for (const QFileInfo& finfo : inflst)
         {
             gpxList << QUrl::fromLocalFile(finfo.filePath());
         }
@@ -420,20 +415,13 @@ class Q_DECL_HIDDEN MapViewModelHelper::Private
 {
 public:
 
-    explicit Private()
-        : model              (nullptr),
-          importModel        (nullptr),
-          selectionModel     (nullptr),
-          thumbnailLoadThread(nullptr),
-          application        (MapWidgetView::ApplicationDigikam)
-    {
-    }
+    Private() = default;
 
-    ItemFilterModel*            model;
-    ImportFilterModel*          importModel;
-    QItemSelectionModel*        selectionModel;
-    ThumbnailLoadThread*        thumbnailLoadThread;
-    MapWidgetView::Application  application;
+    ItemFilterModel*            model               = nullptr;
+    ImportFilterModel*          importModel         = nullptr;
+    QItemSelectionModel*        selectionModel      = nullptr;
+    ThumbnailLoadThread*        thumbnailLoadThread = nullptr;
+    MapWidgetView::Application  application         = MapWidgetView::ApplicationDigikam;
 };
 
 MapViewModelHelper::MapViewModelHelper(QItemSelectionModel* const selection,
@@ -441,7 +429,7 @@ MapViewModelHelper::MapViewModelHelper(QItemSelectionModel* const selection,
                                        QObject* const parent,
                                        const MapWidgetView::Application application)
     : GeoModelHelper(parent),
-      d(new Private())
+      d             (new Private)
 {
     d->selectionModel = selection;
     d->application    = application;
@@ -655,7 +643,7 @@ QPersistentModelIndex MapViewModelHelper::bestRepresentativeIndexFromList(const
             const QList<ItemInfo> imageInfoList = d->model->imageInfos(indexList);
             GPSItemInfo::List gpsItemInfoList;
 
-            Q_FOREACH (const ItemInfo& imageInfo, imageInfoList)
+            for (const ItemInfo& imageInfo : std::as_const(imageInfoList))
             {
                 GPSItemInfo gpsItemInfo;
 
@@ -700,7 +688,7 @@ QPersistentModelIndex MapViewModelHelper::bestRepresentativeIndexFromList(const
             const QList<CamItemInfo> imageInfoList =  d->importModel->camItemInfos(indexList);
             GPSItemInfo::List gpsItemInfoList;
 
-            Q_FOREACH (const CamItemInfo& imageInfo, imageInfoList)
+            for (const CamItemInfo& imageInfo : std::as_const(imageInfoList))
             {
                 QScopedPointer<DMetadata> meta(new DMetadata(imageInfo.url().toLocalFile()));
                 double          lat, lng;
@@ -781,6 +769,7 @@ void MapViewModelHelper::slotThumbnailLoaded(const LoadingDescription& loadingDe
     if (currentIndex.isValid())
     {
         QPersistentModelIndex goodIndex(currentIndex);
+
         Q_EMIT signalThumbnailAvailableForIndex(goodIndex, thumb.copy(1, 1, thumb.size().width()-2, thumb.size().height()-2));
     }
 }
@@ -808,6 +797,7 @@ void MapViewModelHelper::slotThumbnailLoaded(const CamItemInfo& info)
     if (currentIndex.isValid())
     {
         QPersistentModelIndex goodIndex(currentIndex);
+
         Q_EMIT signalThumbnailAvailableForIndex(goodIndex, pix.copy(1, 1, pix.size().width()-2, pix.size().height()-2));
     }
 }
@@ -852,21 +842,27 @@ void MapViewModelHelper::onIndicesClicked(const QList<QPersistentModelIndex>& cl
 void MapViewModelHelper::slotImageChange(const ImageChangeset& changeset)
 {
     const DatabaseFields::Set changes = changeset.changes();
-//    const DatabaseFields::ItemPositions imagePositionChanges = changes;
-
+/*
+    const DatabaseFields::ItemPositions imagePositionChanges = changes;
+*/
     /// @todo More detailed check
 
-    if ((changes & DatabaseFields::LatitudeNumber)  ||
+    if (
+        (changes & DatabaseFields::LatitudeNumber)  ||
         (changes & DatabaseFields::LongitudeNumber) ||
-        (changes & DatabaseFields::Altitude))
+        (changes & DatabaseFields::Altitude)
+       )
     {
-        Q_FOREACH (const qlonglong& id, changeset.ids())
+        const auto ids = changeset.ids();
+
+        for (const qlonglong& id : ids)
         {
             const QModelIndex index = d->model->indexForImageId(id);
 
             if (index.isValid())
             {
                 Q_EMIT signalModelChangedDrastically();
+
                 break;
             }
         }
