@@ -150,7 +150,6 @@ StackedView::StackedView(QWidget* const parent)
 #endif // HAVE_MEDIAPLAYER
 
     setViewMode(IconViewMode);
-    setAttribute(Qt::WA_DeleteOnClose);
 
     readSettings();
 
@@ -383,7 +382,7 @@ StackedView::StackedViewMode StackedView::viewMode() const
     return StackedViewMode(d->stackMap.value(currentIndex()));
 }
 
-void StackedView::setViewMode(const StackedViewMode mode)
+void StackedView::setViewMode(const StackedViewMode mode, bool focus)
 {
     qCDebug(DIGIKAM_GENERAL_LOG) << "Stacked View Mode : " << mode;
 
@@ -439,23 +438,26 @@ void StackedView::setViewMode(const StackedViewMode mode)
 
     d->tableView->slotSetActive(mode == TableViewMode);
 
-    if      (mode == IconViewMode)
+    if (focus)
     {
-        d->imageIconView->setFocus();
-    }
+        if      (mode == IconViewMode)
+        {
+            d->imageIconView->setFocus();
+        }
 
 #ifdef HAVE_GEOLOCATION
 
-    else if (mode == MapWidgetMode)
-    {
-        d->mapWidgetView->setFocus();
-    }
+        else if (mode == MapWidgetMode)
+        {
+            d->mapWidgetView->setFocus();
+        }
 
 #endif // HAVE_GEOLOCATION
 
-    else if (mode == TableViewMode)
-    {
-        d->tableView->setFocus();
+        else if (mode == TableViewMode)
+        {
+            d->tableView->setFocus();
+        }
     }
 
     Q_EMIT signalViewModeChanged();
@@ -472,7 +474,7 @@ void StackedView::syncSelection(ItemCategorizedView* const from, ItemCategorized
     QItemSelection selection              = from->selectionModel()->selection();
     QItemSelection newSelection;
 
-    Q_FOREACH (const QItemSelectionRange& range, selection)
+    for (const QItemSelectionRange& range : std::as_const(selection))
     {
         QModelIndex topLeft     = toModel->indexForItemInfo(fromModel->imageInfo(range.topLeft()));
         QModelIndex bottomRight = toModel->indexForItemInfo(fromModel->imageInfo(range.bottomRight()));
