@@ -49,33 +49,20 @@ class Q_DECL_HIDDEN TrashView::Private
 
 public:
 
-    explicit Private()
-        : model             (nullptr),
-          thumbDelegate     (nullptr),
-          mainLayout        (nullptr),
-          btnsLayout        (nullptr),
-          tableView         (nullptr),
-          undoButton        (nullptr),
-          deleteButton      (nullptr),
-          restoreAction     (nullptr),
-          deleteAction      (nullptr),
-          deleteAllAction   (nullptr),
-          thumbSize         (ThumbnailSize::Large)
-    {
-    }
+    Private() = default;
 
 public:
 
-    DTrashItemModel*               model;
-    ThumbnailAligningDelegate*     thumbDelegate;
-    QVBoxLayout*                   mainLayout;
-    QHBoxLayout*                   btnsLayout;
-    QTableView*                    tableView;
-    QPushButton*                   undoButton;
-    QPushButton*                   deleteButton;
-    QAction*                       restoreAction;
-    QAction*                       deleteAction;
-    QAction*                       deleteAllAction;
+    DTrashItemModel*               model                    = nullptr;
+    ThumbnailAligningDelegate*     thumbDelegate            = nullptr;
+    QVBoxLayout*                   mainLayout               = nullptr;
+    QHBoxLayout*                   btnsLayout               = nullptr;
+    QTableView*                    tableView                = nullptr;
+    QPushButton*                   undoButton               = nullptr;
+    QPushButton*                   deleteButton             = nullptr;
+    QAction*                       restoreAction            = nullptr;
+    QAction*                       deleteAction             = nullptr;
+    QAction*                       deleteAllAction          = nullptr;
 
     QModelIndex                    lastSelectedIndex;
 
@@ -83,7 +70,7 @@ public:
 
     DTrashItemInfo                 lastSelectedItem;
     QModelIndexList                selectedIndexesToRemove;
-    ThumbnailSize                  thumbSize;
+    ThumbnailSize                  thumbSize                = ThumbnailSize(ThumbnailSize::Large);
 };
 
 TrashView::TrashView(QWidget* const parent)
@@ -247,25 +234,33 @@ void TrashView::slotUndoLastDeletedItems()
     d->selectedIndexesToRemove.clear();
     QDateTime lastDateTime = QDateTime::fromMSecsSinceEpoch(0);
 
-    Q_FOREACH (const DTrashItemInfo& item, d->model->allItems())
     {
-        if (item.deletionTimestamp > lastDateTime)
+        const auto its       = d->model->allItems();
+
+        for (const DTrashItemInfo& item : its)
         {
-            // cppcheck-suppress useStlAlgorithm
-            lastDateTime = item.deletionTimestamp;
+            if (item.deletionTimestamp > lastDateTime)
+            {
+                // cppcheck-suppress useStlAlgorithm
+                lastDateTime = item.deletionTimestamp;
+            }
         }
     }
 
-    Q_FOREACH (const DTrashItemInfo& item, d->model->allItems())
     {
-        if (item.deletionTimestamp == lastDateTime)
-        {
-            QModelIndex index = d->model->indexForItem(item);
+        const auto its = d->model->allItems();
 
-            if (index.isValid())
+        for (const DTrashItemInfo& item : its)
+        {
+            if (item.deletionTimestamp == lastDateTime)
             {
-                items << item;
-                d->selectedIndexesToRemove << index;
+                QModelIndex index = d->model->indexForItem(item);
+
+                if (index.isValid())
+                {
+                    items << item;
+                    d->selectedIndexesToRemove << index;
+                }
             }
         }
     }
