@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_TRASH_VIEW_H
-#define DIGIKAM_TRASH_VIEW_H
+#pragma once
 
 // Qt includes
 
@@ -89,7 +88,7 @@ Q_SIGNALS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 // --------------------------------------------------
@@ -106,5 +105,3 @@ public:
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_TRASH_VIEW_H
