@@ -15,8 +15,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_WELCOME_PAGE_VIEW_H
-#define DIGIKAM_WELCOME_PAGE_VIEW_H
+#pragma once
 
 #include "digikam_config.h"
 
@@ -28,13 +27,9 @@
 #include <QWidget>
 #include <QLabel>
 
-#ifdef HAVE_QWEBENGINE
-#   include <QWebEngineView>
-#   include <QWebEnginePage>
-#   include <QWebEngineSettings>
-#else
-#   include <qwebview.h>
-#endif
+#include <QWebEngineView>
+#include <QWebEnginePage>
+#include <QWebEngineSettings>
 
 // Local includes
 
@@ -43,8 +38,6 @@
 namespace Digikam
 {
 
-#ifdef HAVE_QWEBENGINE
-
 class WelcomePageViewPage : public QWebEnginePage
 {
     Q_OBJECT
@@ -52,33 +45,27 @@ class WelcomePageViewPage : public QWebEnginePage
 public:
 
     explicit WelcomePageViewPage(QObject* const parent = nullptr);
-    ~WelcomePageViewPage()                                                          override;
+    ~WelcomePageViewPage()                                          override = default;
 
-    bool acceptNavigationRequest(const QUrl&, QWebEnginePage::NavigationType, bool) override;
+    bool acceptNavigationRequest(const QUrl&,
+                                 QWebEnginePage::NavigationType,
+                                 bool)                              override;
 
 Q_SIGNALS:
 
     void linkClicked(const QUrl&);
-
 };
 
 // -------------------------------------------------------------------
 
 class WelcomePageView : public QWebEngineView
-
-#else
-
-class WelcomePageView : public QWebView
-
-#endif
-
 {
     Q_OBJECT
 
 public:
 
     explicit WelcomePageView(QWidget* const parent);
-    ~WelcomePageView()                                       override;
+    ~WelcomePageView()                                       override = default;
 
 private:
 
@@ -92,7 +79,4 @@ private Q_SLOTS:
     void slotThemeChanged();
 };
 
-
 } // namespace Digikam
-
-#endif // DIGIKAM_WELCOME_PAGE_VIEW_H
