@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_TABLE_VIEW_COLUMN_DIGIKAM_H
-#define DIGIKAM_TABLE_VIEW_COLUMN_DIGIKAM_H
+#pragma once
 
 // Qt includes
 
@@ -53,7 +52,7 @@ public:
             const TableViewColumnConfiguration& pConfiguration,
             const SubColumn pSubColumn,
             QObject* const parent = nullptr);
-    ~ColumnDigikamProperties() override;
+    ~ColumnDigikamProperties()                                                                              override = default;
 
     QString getTitle()                                                                                const override;
     ColumnFlags getColumnFlags()                                                                      const override;
@@ -66,11 +65,9 @@ public:
 
 private:
 
-    SubColumn subColumn;
+    SubColumn subColumn = SubColumnRating;
 };
 
 } // namespace TableViewColumns
 
 } // namespace Digikam
-
-#endif // DIGIKAM_TABLE_VIEW_COLUMN_DIGIKAM_H
