@@ -6,7 +6,7 @@
  * Date        : 2013-02-25
  * Description : Table view column helpers: File properties
  *
- * SPDX-FileCopyrightText: 2017-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -221,9 +221,7 @@ TableViewColumn::ColumnCompareResult ColumnFileProperties::compare(TableViewMode
 ColumnFileConfigurationWidget::ColumnFileConfigurationWidget(TableViewShared* const sharedObject,
                                                              const TableViewColumnConfiguration& columnConfiguration,
                                                              QWidget* const parentWidget)
-    : TableViewColumnConfigurationWidget(sharedObject, columnConfiguration, parentWidget),
-      subColumn(ColumnFileProperties::SubColumnName),
-      selectorSizeType(nullptr)
+    : TableViewColumnConfigurationWidget(sharedObject, columnConfiguration, parentWidget)
 {
     ColumnFileProperties::getSubColumnIndex<ColumnFileProperties>(configuration.columnId, &subColumn);
 
@@ -251,10 +249,6 @@ ColumnFileConfigurationWidget::ColumnFileConfigurationWidget(TableViewShared* co
     }
 }
 
-ColumnFileConfigurationWidget::~ColumnFileConfigurationWidget()
-{
-}
-
 TableViewColumnConfiguration ColumnFileConfigurationWidget::getNewConfiguration()
 {
     const QString formatKey = selectorSizeType->itemData(selectorSizeType->currentIndex()).toString();
@@ -279,3 +273,5 @@ TableViewColumnConfigurationWidget* ColumnFileProperties::getConfigurationWidget
 
 } // namespace Digikam
 
+
+#include "moc_tableview_column_file.cpp"
