@@ -6,15 +6,14 @@
  * Date        : 2013-02-25
  * Description : Table view column helpers: File properties
  *
- * SPDX-FileCopyrightText: 2017-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_TABLE_VIEW_COLUMN_FILE_H
-#define DIGIKAM_TABLE_VIEW_COLUMN_FILE_H
+#pragma once
 
 // Qt includes
 
@@ -52,7 +51,7 @@ public:
                                   const TableViewColumnConfiguration& pConfiguration,
                                   const SubColumn pSubColumn,
                                   QObject* const parent = nullptr);
-    ~ColumnFileProperties() override {};
+    ~ColumnFileProperties()                                                                                 override = default;
 
     TableViewColumnConfigurationWidget* getConfigurationWidget(QWidget* const parentWidget)           const override;
     void setConfiguration(const TableViewColumnConfiguration& newConfiguration) override;
@@ -68,7 +67,7 @@ public:
 
 private:
 
-    SubColumn subColumn;
+    SubColumn subColumn = SubColumnName;
 };
 
 // ---------------------------------------------------------------------------------------
@@ -82,18 +81,16 @@ public:
     explicit ColumnFileConfigurationWidget(TableViewShared* const sharedObject,
                                            const TableViewColumnConfiguration& columnConfiguration,
                                            QWidget* const parentWidget);
-    ~ColumnFileConfigurationWidget() override;
+    ~ColumnFileConfigurationWidget()                    override = default;
 
-    TableViewColumnConfiguration getNewConfiguration() override;
+    TableViewColumnConfiguration getNewConfiguration()  override;
 
 private:
 
-    ColumnFileProperties::SubColumn subColumn;
-    QComboBox*                      selectorSizeType;
+    ColumnFileProperties::SubColumn subColumn        = ColumnFileProperties::SubColumnName;
+    QComboBox*                      selectorSizeType = nullptr;
 };
 
 } // namespace TableViewColumns
 
 } // namespace Digikam
-
-#endif // DIGIKAM_TABLE_VIEW_COLUMN_FILE_H
