@@ -6,15 +6,14 @@
  * Date        : 2013-02-25
  * Description : Table view column helpers: Geographic column
  *
- * SPDX-FileCopyrightText: 2017-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_TABLE_VIEW_COLUMN_GEO_H
-#define DIGIKAM_TABLE_VIEW_COLUMN_GEO_H
+#pragma once
 
 // Qt includes
 
@@ -51,7 +50,7 @@ public:
                                  const TableViewColumnConfiguration& pConfiguration,
                                  const SubColumn pSubColumn,
                                  QObject* const parent = nullptr);
-    ~ColumnGeoProperties() override;
+    ~ColumnGeoProperties()                                                                                  override = default;
 
     QString getTitle()                                                                                const override;
     ColumnFlags getColumnFlags()                                                                      const override;
@@ -74,19 +73,16 @@ public:
     explicit ColumnGeoConfigurationWidget(TableViewShared* const sharedObject,
                                           const TableViewColumnConfiguration& columnConfiguration,
                                           QWidget* const parentWidget);
-    ~ColumnGeoConfigurationWidget() override;
+    ~ColumnGeoConfigurationWidget()                     override = default;
 
-    TableViewColumnConfiguration getNewConfiguration() override;
+    TableViewColumnConfiguration getNewConfiguration()  override;
 
 private:
 
-    ColumnGeoProperties::SubColumn subColumn;
-    QComboBox*                     selectorAltitudeUnit;
+    ColumnGeoProperties::SubColumn subColumn            = ColumnGeoProperties::SubColumnHasCoordinates;
+    QComboBox*                     selectorAltitudeUnit = nullptr;
 };
 
 } // namespace TableViewColumns
 
 } // namespace Digikam
-
-#endif // DIGIKAM_TABLE_VIEW_COLUMN_GEO_H
-
