@@ -6,15 +6,14 @@
  * Date        : 2013-02-25
  * Description : Table view column helpers: Item properties
  *
- * SPDX-FileCopyrightText: 2017-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_TABLE_VIEW_COLUMN_ITEM_H
-#define DIGIKAM_TABLE_VIEW_COLUMN_ITEM_H
+#pragma once
 
 // Qt includes
 
@@ -57,7 +56,7 @@ public:
                                   const TableViewColumnConfiguration& pConfiguration,
                                   const SubColumn pSubColumn,
                                   QObject* const parent = nullptr);
-    ~ColumnItemProperties() override;
+    ~ColumnItemProperties()                                                                                 override = default;
 
     QString getTitle()                                                                                const override;
     ColumnFlags getColumnFlags()                                                                      const override;
@@ -69,11 +68,9 @@ public:
 
 private:
 
-    SubColumn subColumn;
+    SubColumn subColumn = SubColumnCreationDateTime;
 };
 
 } // namespace TableViewColumns
 
 } // namespace Digikam
-
-#endif // DIGIKAM_TABLE_VIEW_COLUMN_ITEM_H
