@@ -48,10 +48,6 @@ ColumnPhotoProperties::ColumnPhotoProperties(TableViewShared* const tableViewSha
 {
 }
 
-ColumnPhotoProperties::~ColumnPhotoProperties()
-{
-}
-
 QStringList ColumnPhotoProperties::getSubColumns()
 {
     QStringList columns;
@@ -428,10 +424,7 @@ TableViewColumnConfigurationWidget* ColumnPhotoProperties::getConfigurationWidge
 ColumnPhotoConfigurationWidget::ColumnPhotoConfigurationWidget(TableViewShared* const sharedObject,
                                                                const TableViewColumnConfiguration& columnConfiguration,
                                                                QWidget* const parentWidget)
-    : TableViewColumnConfigurationWidget(sharedObject, columnConfiguration, parentWidget),
-      subColumn                         (ColumnPhotoProperties::SubColumnExposure),
-      selectorExposureTimeFormat        (nullptr),
-      selectorExposureTimeUnit          (nullptr)
+    : TableViewColumnConfigurationWidget(sharedObject, columnConfiguration, parentWidget)
 {
     ColumnPhotoProperties::getSubColumnIndex<ColumnPhotoProperties>(configuration.columnId, &subColumn);
 
@@ -472,10 +465,6 @@ ColumnPhotoConfigurationWidget::ColumnPhotoConfigurationWidget(TableViewShared*
     }
 }
 
-ColumnPhotoConfigurationWidget::~ColumnPhotoConfigurationWidget()
-{
-}
-
 TableViewColumnConfiguration ColumnPhotoConfigurationWidget::getNewConfiguration()
 {
     const QString formatKey = selectorExposureTimeFormat->itemData(selectorExposureTimeFormat->currentIndex()).toString();
