@@ -6,15 +6,14 @@
  * Date        : 2013-03-14
  * Description : Table view column helpers: Photo properties
  *
- * SPDX-FileCopyrightText: 2017-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_TABLE_VIEW_COLUMN_PHOTO_H
-#define DIGIKAM_TABLE_VIEW_COLUMN_PHOTO_H
+#pragma once
 
 // Qt includes
 
@@ -52,17 +51,13 @@ public:
         SubColumnWhiteBalance = 9
     };
 
-private:
-
-    SubColumn subColumn;
-
 public:
 
     explicit ColumnPhotoProperties(TableViewShared* const tableViewShared,
                                    const TableViewColumnConfiguration& pConfiguration,
                                    const SubColumn pSubColumn,
                                    QObject* const parent = nullptr);
-    ~ColumnPhotoProperties() override;
+    ~ColumnPhotoProperties()                                                                                override = default;
 
     QString getTitle()                                                                                const override;
     ColumnFlags getColumnFlags()                                                                      const override;
@@ -73,6 +68,10 @@ public:
 
     static TableViewColumnDescription getDescription();
     static QStringList getSubColumns();
+
+private:
+
+    SubColumn subColumn = SubColumnExposure;
 };
 
 // ----------------------------------------------------------------------------------------------------------------------
@@ -86,9 +85,9 @@ public:
     explicit ColumnPhotoConfigurationWidget(TableViewShared* const sharedObject,
                                             const TableViewColumnConfiguration& columnConfiguration,
                                             QWidget* const parentWidget);
-    ~ColumnPhotoConfigurationWidget() override;
+    ~ColumnPhotoConfigurationWidget()                   override = default;
 
-    TableViewColumnConfiguration getNewConfiguration() override;
+    TableViewColumnConfiguration getNewConfiguration()  override;
 
 private Q_SLOTS:
 
@@ -96,13 +95,11 @@ private Q_SLOTS:
 
 private:
 
-    ColumnPhotoProperties::SubColumn subColumn;
-    QComboBox*                       selectorExposureTimeFormat;
-    QComboBox*                       selectorExposureTimeUnit;
+    ColumnPhotoProperties::SubColumn subColumn                  = ColumnPhotoProperties::SubColumnExposure;
+    QComboBox*                       selectorExposureTimeFormat = nullptr;
+    QComboBox*                       selectorExposureTimeUnit   = nullptr;
 };
 
 } // namespace TableViewColumns
 
 } // namespace Digikam
-
-#endif // DIGIKAM_TABLE_VIEW_COLUMN_PHOTO_H
