@@ -6,7 +6,7 @@
  * Date        : 2013-02-12
  * Description : Table view column helpers
  *
- * SPDX-FileCopyrightText: 2017-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -38,16 +38,13 @@ TableViewColumn::TableViewColumn(TableViewShared* const tableViewShared,
 {
 }
 
-TableViewColumn::~TableViewColumn()
-{
-}
-
 // ---------------------------------------------------------------------------------------------
 
 TableViewColumnFactory::TableViewColumnFactory(TableViewShared* const tableViewShared,
-                                               QObject* const parent)
-    : QObject(parent),
-      s      (tableViewShared)
+                                               QWidget* const parent)
+    : QObject        (parent),
+      m_displayWidget(parent),
+      s              (tableViewShared)
 {
 }
 
@@ -55,7 +52,7 @@ TableViewColumn* TableViewColumnFactory::getColumn(const Digikam::TableViewColum
 {
     TableViewColumn* newColumn = nullptr;
 
-    if (TableViewColumns::ColumnThumbnail::CreateFromConfiguration(s, columnConfiguration, &newColumn, this))
+    if (TableViewColumns::ColumnThumbnail::CreateFromConfiguration(s, columnConfiguration, &newColumn, m_displayWidget))
     {
         return newColumn;
     }
@@ -110,7 +107,9 @@ QList<TableViewColumnDescription> TableViewColumnFactory::getColumnDescriptionLi
 
 // ---------------------------------------------------------------------------------------------
 
-bool TableViewColumn::paint(QPainter* const painter, const QStyleOptionViewItem& option, TableViewModel::Item* const item) const
+bool TableViewColumn::paint(QPainter* const painter,
+                            const QStyleOptionViewItem& option,
+                            TableViewModel::Item* const item) const
 {
     Q_UNUSED(painter)
     Q_UNUSED(option)
@@ -208,18 +207,11 @@ bool TableViewColumn::columnAffectedByChangeset(const ImageChangeset& /*imageCha
 
 // ---------------------------------------------------------------------------------------------
 
-TableViewColumnProfile::TableViewColumnProfile()
-{
-}
-
-TableViewColumnProfile::~TableViewColumnProfile()
-{
-}
-
 void TableViewColumnProfile::loadSettings(const KConfigGroup& configGroup)
 {
     name               = configGroup.readEntry("Profile Name", QString());
     headerState        = configGroup.readEntry("Header State", QByteArray());
+    headerState        = QByteArray::fromBase64(headerState);
     const int nColumns = configGroup.readEntry("Column Count", int(0));
 
     for (int i = 0 ; i < nColumns ; ++i)
@@ -284,7 +276,7 @@ void TableViewColumnProfile::saveSettings(KConfigGroup& configGroup)
     configGroup.writeEntry(QLatin1String("Profile Name"), name);
     const int nColumns = columnConfigurationList.count();
     configGroup.writeEntry(QLatin1String("Column Count"), nColumns);
-    configGroup.writeEntry(QLatin1String("Header State"), headerState);
+    configGroup.writeEntry(QLatin1String("Header State"), headerState.toBase64());
 
     for (int i = 0 ; i < nColumns ; ++i)
     {
@@ -336,14 +328,12 @@ void TableViewColumnConfiguration::saveSettings(KConfigGroup& configGroup) const
 TableViewColumnConfigurationWidget::TableViewColumnConfigurationWidget(TableViewShared* const sharedObject,
                                                                        const TableViewColumnConfiguration& currentConfiguration,
                                                                        QWidget* const parent)
-    : QWidget(parent),
-      s(sharedObject),
+    : QWidget      (parent),
+      s            (sharedObject),
       configuration(currentConfiguration)
 {
 }
 
-TableViewColumnConfigurationWidget::~TableViewColumnConfigurationWidget()
-{
-}
-
 } // namespace Digikam
+
+#include "moc_tableview_columnfactory.cpp"
