@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_TABLE_VIEW_COLUMNFACTORY_H
-#define DIGIKAM_TABLE_VIEW_COLUMNFACTORY_H
+#pragma once
 
 // Qt includes
 
@@ -172,13 +171,13 @@ public:
     explicit TableViewColumnConfigurationWidget(TableViewShared* const sharedObject,
                                                 const TableViewColumnConfiguration& currentConfiguration,
                                                 QWidget* const parent = nullptr);
-    ~TableViewColumnConfigurationWidget() override;
+    ~TableViewColumnConfigurationWidget() override = default;
 
     virtual TableViewColumnConfiguration getNewConfiguration() = 0;
 
 public:
 
-    TableViewShared* const       s;
+    TableViewShared* const       s = nullptr;
     TableViewColumnConfiguration configuration;
 };
 
@@ -190,7 +189,7 @@ class TableViewColumn : public QObject
 
 protected:
 
-    TableViewShared* const       s;
+    TableViewShared* const       s = nullptr;
     TableViewColumnConfiguration configuration;
 
 public:
@@ -216,7 +215,7 @@ public:
     explicit TableViewColumn(TableViewShared* const tableViewShared,
                              const TableViewColumnConfiguration& pConfiguration,
                              QObject* const parent = nullptr);
-    ~TableViewColumn() override;
+    ~TableViewColumn() override = default;
 
 public:
 
@@ -307,8 +306,8 @@ public:
 
 private:
 
-    QWidget*         m_displayWidget;
-    TableViewShared* const s;
+    QWidget*         m_displayWidget = nullptr;
+    TableViewShared* const s         = nullptr;
 };
 
 // ----------------------------------------------------------------------------
@@ -317,8 +316,8 @@ class TableViewColumnProfile
 {
 public:
 
-    TableViewColumnProfile();
-    ~TableViewColumnProfile();
+    TableViewColumnProfile()  = default;
+    ~TableViewColumnProfile() = default;
 
     void loadSettings(const KConfigGroup& configGroup);
     void saveSettings(KConfigGroup& configGroup);
@@ -335,5 +334,3 @@ public:
 Q_DECLARE_METATYPE(Digikam::TableViewColumnDescription)
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(Digikam::TableViewColumn::ColumnFlags)
-
-#endif // DIGIKAM_TABLE_VIEW_COLUMNFACTORY_H
