@@ -6,7 +6,7 @@
  * Date        : 2013-02-12
  * Description : Wrapper model for table view
  *
- * SPDX-FileCopyrightText: 2017-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -29,7 +29,6 @@
 #include "digikam_debug.h"
 #include "coredb.h"
 #include "coredbaccess.h"
-#include "coredbchangesets.h"
 #include "coredbfields.h"
 #include "coredbwatch.h"
 #include "itemfiltermodel.h"
@@ -48,13 +47,6 @@
 namespace Digikam
 {
 
-TableViewModel::Item::Item()
-  : imageId (0),
-    parent  (nullptr),
-    children()
-{
-}
-
 TableViewModel::Item::~Item()
 {
     qDeleteAll(children);
@@ -86,7 +78,7 @@ TableViewModel::Item* TableViewModel::Item::findChildWithImageId(const qlonglong
         return this;
     }
 
-    Q_FOREACH (Item* const item, children)
+    for (Item* const item : std::as_const(children))
     {
         Item* const iItem = item->findChildWithImageId(searchImageId);
 
@@ -105,32 +97,22 @@ class Q_DECL_HIDDEN TableViewModel::Private
 {
 public:
 
-    explicit Private()
-      : columnObjects      (),
-        rootItem           (nullptr),
-        imageFilterSettings(),
-        sortColumn         (0),
-        sortOrder          (Qt::AscendingOrder),
-        sortRequired       (false),
-        groupingMode       (GroupingShowSubItems),
-        outdated           (true)
-    {
-    }
+    Private() = default;
 
     QList<TableViewColumn*>     columnObjects;
-    TableViewModel::Item*       rootItem;
+    TableViewModel::Item*       rootItem            = nullptr;
     ItemFilterSettings          imageFilterSettings;
-    int                         sortColumn;
-    Qt::SortOrder               sortOrder;
-    bool                        sortRequired;
-    GroupingMode                groupingMode;
-    bool                        outdated;
+    int                         sortColumn          = 0;
+    Qt::SortOrder               sortOrder           = Qt::AscendingOrder;
+    bool                        sortRequired        = false;
+    GroupingMode                groupingMode        = GroupingShowSubItems;
+    bool                        outdated            = true;
 };
 
 TableViewModel::TableViewModel(TableViewShared* const sharedObject, QObject* const parent)
     : QAbstractItemModel(parent),
       s                 (sharedObject),
-      d                 (new Private())
+      d                 (new Private)
 {
     d->rootItem            = new Item();
     d->imageFilterSettings = s->imageFilterModel->imageFilterSettings();
@@ -518,6 +500,7 @@ void TableViewModel::slotSourceRowsInserted(const QModelIndex& parent, int start
     if (!s->isActive)
     {
         slotClearModel(true);
+
         return;
     }
 
@@ -534,6 +517,7 @@ void TableViewModel::slotSourceRowsAboutToBeRemoved(const QModelIndex& parent, i
     if (!s->isActive)
     {
         slotClearModel(true);
+
         return;
     }
 
@@ -657,6 +641,7 @@ void TableViewModel::slotDatabaseImageChanged(const ImageChangeset& imageChanges
     if (!s->isActive)
     {
         slotClearModel(true);
+
         return;
     }
 /*
@@ -677,7 +662,9 @@ void TableViewModel::slotDatabaseImageChanged(const ImageChangeset& imageChanges
         needToResort                            = sortColumnObject->columnAffectedByChangeset(imageChangeset);
     }
 
-    Q_FOREACH (const qlonglong& id, imageChangeset.ids())
+    const auto ids = imageChangeset.ids();
+
+    for (const qlonglong& id : ids)
     {
         // first clear the item's cached values
         /// @todo Clear only the fields which were changed
@@ -811,6 +798,7 @@ void TableViewModel::slotPopulateModel(const bool sendNotifications)
     if (!s->isActive)
     {
         slotClearModel(sendNotifications);
+
         return;
     }
 
@@ -878,22 +866,25 @@ void TableViewModel::addSourceModelIndex(const QModelIndex& imageModelIndex, con
         switch (d->groupingMode)
         {
             case GroupingHideGrouped:
-
+            {
                 // we do not show grouped items at all
 
                 return;
+            }
 
             case GroupingIgnoreGrouping:
-
+            {
                 // nothing to do, we just add it to the root item
 
                 break;
+            }
 
             case GroupingShowSubItems:
-
+            {
                 // we do not add this subitem, because it has been automatically added to the group leader
 
                 return;
+            }
         }
     }
 
@@ -935,7 +926,7 @@ void TableViewModel::addSourceModelIndex(const QModelIndex& imageModelIndex, con
             beginInsertRows(groupLeaderIndex, 0, groupedImages.count()-1);
         }
 
-        Q_FOREACH (const ItemInfo& groupedInfo, groupedImages)
+        for (const ItemInfo& groupedInfo : std::as_const(groupedImages))
         {
             /// @todo Grouped items are currently not filtered. Should they?
 
@@ -1024,7 +1015,7 @@ ItemInfoList TableViewModel::infosFromItems(const QList<TableViewModel::Item*>&
 {
     ItemInfoList infos;
 
-    Q_FOREACH (TableViewModel::Item* const item, items)
+    for (TableViewModel::Item* const item : std::as_const(items))
     {
         infos << infoFromItem(item);
     }
@@ -1087,7 +1078,7 @@ QList<qlonglong> TableViewModel::imageIds(const QModelIndexList& indexList) cons
 {
     QList<qlonglong> idList;
 
-    Q_FOREACH (const QModelIndex& index, indexList)
+    for (const QModelIndex& index : std::as_const(indexList))
     {
         ASSERT_MODEL(index, this);
 
@@ -1113,7 +1104,7 @@ QList<ItemInfo> TableViewModel::imageInfos(const QModelIndexList& indexList) con
 {
     QList<ItemInfo> infoList;
 
-    Q_FOREACH (const QModelIndex& index, indexList)
+    for (const QModelIndex& index : std::as_const(indexList))
     {
         ASSERT_MODEL(index, this);
 
@@ -1179,7 +1170,7 @@ public:
 
 public:
 
-    TableViewModel* m;
+    TableViewModel* m = nullptr;
 };
 
 QList<TableViewModel::Item*> TableViewModel::sortItems(const QList<TableViewModel::Item*>& itemList)
@@ -1209,7 +1200,7 @@ void TableViewModel::sort(int column, Qt::SortOrder order)
     {
         Item* const itemToSort = itemsRequiringSorting.takeFirst();
 
-        Q_FOREACH (Item* const itemToCheck, itemToSort->children)
+        for (Item* const itemToCheck : std::as_const(itemToSort->children))
         {
             if (!itemToCheck->children.isEmpty())
             {
@@ -1268,7 +1259,7 @@ QMimeData* TableViewModel::mimeData(const QModelIndexList& indexes) const
 
     QModelIndexList imageModelIndexList;
 
-    Q_FOREACH (const QModelIndex& i, indexes)
+    for (const QModelIndex& i : std::as_const(indexes))
     {
         if (i.column() > 0)
         {
@@ -1661,6 +1652,7 @@ int TableViewModel::findChildSortedPosition(TableViewModel::Item* const parentIt
         }
 
         // can we go lower?
+
         const bool lowerThere = (pos > 0);
 
         if (!lowerThere)
@@ -1699,3 +1691,5 @@ int TableViewModel::findChildSortedPosition(TableViewModel::Item* const parentIt
 }
 
 } // namespace Digikam
+
+#include "moc_tableview_model.cpp"
