@@ -33,17 +33,14 @@ class Q_DECL_HIDDEN TableViewSelectionModelSyncer::Private
 {
 public:
 
-    explicit Private()
-      : syncing(false)
-    {
-    }
+    Private() = default;
 
-    bool syncing;
+    bool syncing = false;
 };
 
 TableViewSelectionModelSyncer::TableViewSelectionModelSyncer(TableViewShared* const sharedObject, QObject* const parent)
     : QObject(parent),
-      d      (new Private()),
+      d      (new Private),
       s      (sharedObject)
 {
     connect(s->imageFilterSelectionModel, SIGNAL(currentChanged(QModelIndex,QModelIndex)),
@@ -158,7 +155,7 @@ QItemSelection TableViewSelectionModelSyncer::itemSelectionToSource(const QItemS
 {
     QItemSelection sourceSelection;
 
-    Q_FOREACH (const QItemSelectionRange& range, selection)
+    for (const QItemSelectionRange& range : std::as_const(selection))
     {
         const int firstRow = range.top();
         const int lastRow  = range.bottom();
@@ -183,7 +180,7 @@ QItemSelection TableViewSelectionModelSyncer::itemSelectionToTarget(const QItemS
     const int      targetColumnCount = targetModelColumnCount();
     QItemSelection targetSelection;
 
-    Q_FOREACH (const QItemSelectionRange& range, selection)
+    for (const QItemSelectionRange& range : std::as_const(selection))
     {
         const int firstRow = range.top();
         const int lastRow  = range.bottom();
