@@ -6,15 +6,14 @@
  * Date        : 2013-02-18
  * Description : Sync QItemSelectionModel of ItemFilterModel and TableViewModel
  *
- * SPDX-FileCopyrightText: 2017-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_TABLE_VIEW_SELECTION_MODEL_SYNCER_H
-#define DIGIKAM_TABLE_VIEW_SELECTION_MODEL_SYNCER_H
+#pragma once
 
 // Qt includes
 
@@ -33,7 +32,7 @@ class TableViewSelectionModelSyncer : public QObject
 public:
 
     explicit TableViewSelectionModelSyncer(TableViewShared* const sharedObject, QObject* const parent = nullptr);
-    ~TableViewSelectionModelSyncer() override;
+    ~TableViewSelectionModelSyncer()                                                   override;
 
     QModelIndex toSource(const QModelIndex& targetIndex)                         const;
     QModelIndex toTarget(const QModelIndex& sourceIndex)                         const;
@@ -69,11 +68,9 @@ public Q_SLOTS:
 private:
 
     class Private;
-
     const QScopedPointer<Private> d;
-    TableViewShared* const        s;
+
+    TableViewShared* const        s = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_TABLE_VIEW_SELECTION_MODEL_SYNCER_H
