@@ -6,7 +6,7 @@
  * Date        : 2013-03-02
  * Description : Table view: Tree view subelement
  *
- * SPDX-FileCopyrightText: 2017-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -17,7 +17,6 @@
 
 // Qt includes
 
-#include <QTreeView>
 
 // Local includes
 
@@ -33,10 +32,8 @@
 #include "importimagemodel.h"
 #include "importui.h"
 #include "tableview_column_configuration_dialog.h"
-#include "tableview_columnfactory.h"
 #include "tableview_model.h"
 #include "tableview_selection_model_syncer.h"
-#include "thumbnailloadthread.h"
 
 namespace Digikam
 {
@@ -47,10 +44,6 @@ TableViewItemDelegate::TableViewItemDelegate(TableViewShared* const tableViewSha
 {
 }
 
-TableViewItemDelegate::~TableViewItemDelegate()
-{
-}
-
 void TableViewItemDelegate::paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& tableViewModelIndex) const
 {
     const int columnIndex               = tableViewModelIndex.column();
@@ -130,3 +123,5 @@ QSize TableViewItemDelegate::sizeHint(const QStyleOptionViewItem& option, const
 }
 
 } // namespace Digikam
+
+#include "moc_tableview_treeview_delegate.cpp"
