@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_TABLE_VIEW_TREEVIEW_DELEGATE_H
-#define DIGIKAM_TABLE_VIEW_TREEVIEW_DELEGATE_H
+#pragma once
 
 // Qt includes
 
@@ -44,16 +43,14 @@ class TableViewItemDelegate : public QItemDelegate
 public:
 
     explicit TableViewItemDelegate(TableViewShared* const tableViewShared, QObject* const parent = nullptr);
-    ~TableViewItemDelegate() override;
+    ~TableViewItemDelegate()                                                                                        override = default;
 
     void paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& tableViewModelIndex) const override;
     QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& tableViewModelIndex)                const override;
 
 private:
 
-    TableViewShared* const s;
+    TableViewShared* const s = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_TABLE_VIEW_TREEVIEW_DELEGATE_H
