@@ -19,6 +19,7 @@
 #include <QApplication>
 #include <QString>
 #include <QMap>
+#include <QSqlDatabase>
 
 // KDE includes
 
@@ -188,6 +189,10 @@ public:
         // TODO: add sqlite versions here? Could be useful for debugging sqlite problems..
         // Use this sqlite request; https://www.sqlite.org/lang_corefunc.html#sqlite_version
 
+        new QTreeWidgetItem(m_libraries, QStringList() <<
+                            i18nc("@item: component info", "Qt Sql drivers") <<         QSqlDatabase::drivers().join(QLatin1Char(' ')));
+
+
         QString dbBe = ApplicationSettings::instance()->getDbEngineParameters().databaseType;
         new QTreeWidgetItem(m_features, QStringList() <<
                             i18nc("@item: component info", "Database backend") <<       dbBe);
@@ -207,7 +212,8 @@ public:
 
         // --- FFMPEG Video codecs ---
 
-        FFMpegProperties propsVid     = FFMpegConfigHelper::getVideoCodecsProperties();
+        FFMpegProperties propsVid = FFMpegConfigHelper::getVideoCodecsProperties();
+
         QTreeWidgetItem* const vidDec = new QTreeWidgetItem(ffmpegEntry, QStringList() << i18nc("@item: component info", "Video Decoders"));
 
         for (FFMpegProperties::const_iterator it = propsVid.constBegin() ; it != propsVid.constEnd() ; ++it)
@@ -220,6 +226,11 @@ public:
             }
         }
 
+        if (vidDec->childCount() == 0)
+        {
+            new QTreeWidgetItem(vidDec, QStringList() << i18n("no entry"));
+        }
+
         QTreeWidgetItem* const vidEnc = new QTreeWidgetItem(ffmpegEntry, QStringList() << i18nc("@item: component info", "Video Encoders"));
 
         for (FFMpegProperties::const_iterator it = propsVid.constBegin() ; it != propsVid.constEnd() ; ++it)
@@ -232,6 +243,11 @@ public:
             }
         }
 
+        if (vidEnc->childCount() == 0)
+        {
+            new QTreeWidgetItem(vidEnc, QStringList() << i18n("no entry"));
+        }
+
         // --- FFMPEG Audio codecs ---
 
         FFMpegProperties propsAud     = FFMpegConfigHelper::getAudioCodecsProperties();
@@ -243,10 +259,15 @@ public:
 
             if ((vals.size() > 1) && (vals[1] == QLatin1String("R")))
             {
-                new QTreeWidgetItem(audDec, QStringList() << it.key() << vals[0]);
+                    new QTreeWidgetItem(audDec, QStringList() << it.key() << vals[0]);
             }
         }
 
+        if (audDec->childCount() == 0)
+        {
+            new QTreeWidgetItem(audDec, QStringList() << i18n("no entry"));
+        }
+
         QTreeWidgetItem* const audEnc = new QTreeWidgetItem(ffmpegEntry, QStringList() << i18nc("@item: component info", "Audio Encoders"));
 
         for (FFMpegProperties::const_iterator it = propsAud.constBegin() ; it != propsAud.constEnd() ; ++it)
@@ -259,6 +280,11 @@ public:
             }
         }
 
+        if (audEnc->childCount() == 0)
+        {
+             new QTreeWidgetItem(audEnc, QStringList() << i18n("no entry"));
+        }
+
         // --- FFMPEG supported extensions ---
 
         FFMpegProperties propsExt       = FFMpegConfigHelper::getExtensionsProperties();
@@ -272,13 +298,16 @@ public:
             }
         }
 
+        if (extEntry->childCount() == 0)
+        {
+             new QTreeWidgetItem(extEntry, QStringList() << i18n("no entry"));
+        }
+
 #endif
 
     }
 
-    ~ComponentsInfoDlg()
-    {
-    }
+    ~ComponentsInfoDlg() = default;
 };
 
 // --------------------------------------------------------
