@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_AUTO_CORRECTION_H
-#define DIGIKAM_BQM_AUTO_CORRECTION_H
+#pragma once
 
 // Local includes
 
@@ -33,7 +32,7 @@ class AutoCorrection : public BatchTool
 public:
 
     explicit AutoCorrection(QObject* const parent = nullptr);
-    ~AutoCorrection()                                       override;
+    ~AutoCorrection()                                       override = default;
 
     BatchToolSettings defaultSettings()                     override;
 
@@ -61,9 +60,7 @@ private:
         AutoExposureCorrection
     };
 
-    QComboBox* m_comboBox;
+    QComboBox* m_comboBox = nullptr;
 };
 
 } // namespace DigikamBqmAutoCorrectionPlugin
-
-#endif // DIGIKAM_BQM_AUTO_CORRECTION_H
