@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_AUTO_CORRECTION_PLUGIN_H
-#define DIGIKAM_AUTO_CORRECTION_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class AutoCorrectionPlugin : public DPluginBqm
 public:
 
     explicit AutoCorrectionPlugin(QObject* const parent = nullptr);
-    ~AutoCorrectionPlugin()              override;
+    ~AutoCorrectionPlugin()              override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -51,5 +50,3 @@ public:
 };
 
 } // namespace DigikamBqmAutoCorrectionPlugin
-
-#endif // DIGIKAM_AUTO_CORRECTION_PLUGIN_H
