@@ -6,14 +6,13 @@
  * Date        : 2010-02-09
  * Description : Brightness/Contrast/Gamma batch tool.
  *
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_BCG_CORRECTION_H
-#define DIGIKAM_BQM_BCG_CORRECTION_H
+#pragma once
 
 // Local includes
 
@@ -32,7 +31,7 @@ class BCGCorrection : public BatchTool
 public:
 
     explicit BCGCorrection(QObject* const parent = nullptr);
-    ~BCGCorrection()                                        override;
+    ~BCGCorrection()                                        override = default;
 
     BatchToolSettings defaultSettings()                     override;
 
@@ -51,9 +50,7 @@ private Q_SLOTS:
 
 private:
 
-    BCGSettings* m_settingsView;
+    BCGSettings* m_settingsView = nullptr;
 };
 
 } // namespace DigikamBqmBCGCorrectionPlugin
-
-#endif // DIGIKAM_BQM_BCG_CORRECTION_H
