@@ -6,18 +6,9 @@
  * Date        : 2010-02-23
  * Description : Black and White conversion batch tool.
  *
- * Copyright (C) 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -40,12 +31,7 @@ namespace DigikamBqmBWConvertPlugin
 {
 
 BWConvert::BWConvert(QObject* const parent)
-    : BatchTool(QLatin1String("BWConvert"), ColorTool, parent),
-      m_settingsView(nullptr)
-{
-}
-
-BWConvert::~BWConvert()
+    : BatchTool(QLatin1String("BWConvert"), ColorTool, parent)
 {
 }
 
@@ -149,3 +135,5 @@ bool BWConvert::toolOperations()
 }
 
 } // namespace DigikamBqmBWConvertPlugin
+
+#include "moc_bwconvert.cpp"
