@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_BW_CONVERT_H
-#define DIGIKAM_BQM_BW_CONVERT_H
+#pragma once
 
 // Local includes
 
@@ -32,7 +31,7 @@ class BWConvert : public BatchTool
 public:
 
     explicit BWConvert(QObject* const parent = nullptr);
-    ~BWConvert()                                            override;
+    ~BWConvert()                                            override = default;
 
     BatchToolSettings defaultSettings()                     override;
 
@@ -56,9 +55,7 @@ private Q_SLOTS:
 private:
 
     DImg             m_preview;
-    BWSepiaSettings* m_settingsView;
+    BWSepiaSettings* m_settingsView = nullptr;
 };
 
 } // namespace DigikamBqmBWConvertPlugin
-
-#endif // DIGIKAM_BQM_BW_CONVERT_H
