@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BW_CONVERT_PLUGIN_H
-#define DIGIKAM_BW_CONVERT_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class BWConvertPlugin : public DPluginBqm
 public:
 
     explicit BWConvertPlugin(QObject* const parent = nullptr);
-    ~BWConvertPlugin()                   override;
+    ~BWConvertPlugin()                   override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -51,5 +50,3 @@ public:
 };
 
 } // namespace DigikamBqmBWConvertPlugin
-
-#endif // DIGIKAM_BW_CONVERT_PLUGIN_H
