@@ -6,14 +6,13 @@
  * Date        : 2010-02-19
  * Description : Channel Mixer batch tool.
  *
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_CHANNEL_MIXER_H
-#define DIGIKAM_BQM_CHANNEL_MIXER_H
+#pragma once
 
 // Local includes
 
@@ -32,7 +31,7 @@ class ChannelMixer : public BatchTool
 public:
 
     explicit ChannelMixer(QObject* const parent = nullptr);
-    ~ChannelMixer()                                         override;
+    ~ChannelMixer()                                         override = default;
 
     BatchToolSettings defaultSettings()                     override;
 
@@ -51,9 +50,7 @@ private Q_SLOTS:
 
 private:
 
-    MixerSettings* m_settingsView;
+    MixerSettings* m_settingsView = nullptr;
 };
 
 } // namespace DigikamBqmChannelMixerPlugin
-
-#endif // DIGIKAM_BQM_CHANNEL_MIXER_H
