@@ -31,8 +31,7 @@ namespace DigikamBqmColorBalancePlugin
 {
 
 ColorBalance::ColorBalance(QObject* const parent)
-    : BatchTool(QLatin1String("ColorBalance"), ColorTool, parent),
-      m_settingsView(nullptr)
+    : BatchTool(QLatin1String("ColorBalance"), ColorTool, parent)
 {
 
     setToolTitle(i18n("Color Balance"));
@@ -40,10 +39,6 @@ ColorBalance::ColorBalance(QObject* const parent)
     setToolIconName(QLatin1String("adjustrgb"));
 }
 
-ColorBalance::~ColorBalance()
-{
-}
-
 BatchTool* ColorBalance::clone(QObject* const parent) const
 {
     return new ColorBalance(parent);
