@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_COLOR_BALANCE_H
-#define DIGIKAM_BQM_COLOR_BALANCE_H
+#pragma once
 
 // Local includes
 
@@ -32,7 +31,7 @@ class ColorBalance : public BatchTool
 public:
 
     explicit ColorBalance(QObject* const parent = nullptr);
-    ~ColorBalance()                                         override;
+    ~ColorBalance()                                         override = default;
 
     BatchToolSettings defaultSettings()                     override;
 
@@ -51,9 +50,7 @@ private Q_SLOTS:
 
 private:
 
-    CBSettings* m_settingsView;
+    CBSettings* m_settingsView = nullptr;
 };
 
 } // namespace DigikamBqmColorBalancePlugin
-
-#endif // DIGIKAM_BQM_COLOR_BALANCE_H
