@@ -6,18 +6,9 @@
  * Date        : 2010-03-16
  * Description : 16 to 8 bits color depth converter batch tool.
  *
- * Copyright (C) 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -43,10 +34,6 @@ Convert16to8::Convert16to8(QObject* const parent)
     setToolIconName(QLatin1String("depth16to8"));
 }
 
-Convert16to8::~Convert16to8()
-{
-}
-
 BatchToolSettings Convert16to8::defaultSettings()
 {
     return BatchToolSettings();
@@ -71,3 +58,5 @@ bool Convert16to8::toolOperations()
 }
 
 } // namespace DigikamBqmConvert16To8Plugin
+
+#include "moc_convert16to8.cpp"
