@@ -6,14 +6,13 @@
  * Date        : 2010-03-16
  * Description : 16 to 8 bits color depth converter batch tool.
  *
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_CONVERT_16TO8_H
-#define DIGIKAM_BQM_CONVERT_16TO8_H
+#pragma once
 
 // Local includes
 
@@ -31,7 +30,7 @@ class Convert16to8 : public BatchTool
 public:
 
     explicit Convert16to8(QObject* const parent = nullptr);
-    ~Convert16to8()                                         override;
+    ~Convert16to8()                                         override = default;
 
     BatchToolSettings defaultSettings()                     override;
 
@@ -48,5 +47,3 @@ private Q_SLOTS:
 };
 
 } // namespace DigikamBqmConvert16To8Plugin
-
-#endif // DIGIKAM_BQM_CONVERT_16TO8_H
