@@ -6,7 +6,7 @@
  * Date        : 2010-03-16
  * Description : 8 to 16 bits color depth converter batch tool.
  *
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -31,10 +31,6 @@ Convert8to16::Convert8to16(QObject* const parent)
 {
 }
 
-Convert8to16::~Convert8to16()
-{
-}
-
 BatchToolSettings Convert8to16::defaultSettings()
 {
     return BatchToolSettings();
@@ -59,3 +55,5 @@ bool Convert8to16::toolOperations()
 }
 
 } // namespace DigikamBqmConvert8To16Plugin
+
+#include "moc_convert8to16.cpp"
