@@ -6,7 +6,7 @@
  * Date        : 2010-03-02
  * Description : Curves Adjust batch tool.
  *
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -36,19 +36,13 @@ namespace DigikamBqmCurvesAdjustPlugin
 {
 
 CurvesAdjust::CurvesAdjust(QObject* const parent)
-    : BatchTool     (QLatin1String("CurvesAdjust"), ColorTool, parent),
-      m_channelCB   (nullptr),
-      m_settingsView(nullptr)
+    : BatchTool(QLatin1String("CurvesAdjust"), ColorTool, parent)
 {
     setToolTitle(i18nc("@title", "Curves Adjust"));
     setToolDescription(i18nc("@info", "Perform curves adjustments."));
     setToolIconName(QLatin1String("adjustcurves"));
 }
 
-CurvesAdjust::~CurvesAdjust()
-{
-}
-
 BatchTool* CurvesAdjust::clone(QObject* const parent) const
 {
     return new CurvesAdjust(parent);
@@ -185,3 +179,5 @@ bool CurvesAdjust::toolOperations()
 }
 
 } // namespace DigikamBqmCurvesAdjustPlugin
+
+#include "moc_curvesadjust.cpp"
