@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_CURVES_ADJUST_H
-#define DIGIKAM_BQM_CURVES_ADJUST_H
+#pragma once
 
 // Local includes
 
@@ -34,7 +33,7 @@ class CurvesAdjust : public BatchTool
 public:
 
     explicit CurvesAdjust(QObject* const parent = nullptr);
-    ~CurvesAdjust()                                         override;
+    ~CurvesAdjust()                                         override = default;
 
     BatchToolSettings defaultSettings()                     override;
 
@@ -60,10 +59,8 @@ private Q_SLOTS:
 private:
 
     DImg            m_preview;
-    QComboBox*      m_channelCB;
-    CurvesSettings* m_settingsView;
+    QComboBox*      m_channelCB     = nullptr;
+    CurvesSettings* m_settingsView  = nullptr;
 };
 
 } // namespace DigikamBqmCurvesAdjustPlugin
-
-#endif // DIGIKAM_BQM_CURVES_ADJUST_H
