@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_CURVES_ADJUST_PLUGIN_H
-#define DIGIKAM_CURVES_ADJUST_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class CurvesAdjustPlugin : public DPluginBqm
 public:
 
     explicit CurvesAdjustPlugin(QObject* const parent = nullptr);
-    ~CurvesAdjustPlugin()                override;
+    ~CurvesAdjustPlugin()                override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -51,5 +50,3 @@ public:
 };
 
 } // namespace DigikamBqmCurvesAdjustPlugin
-
-#endif // DIGIKAM_CURVES_ADJUST_PLUGIN_H
