@@ -6,7 +6,7 @@
  * Date        : 2010-02-17
  * Description : Color profile conversion tool.
  *
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -37,12 +37,7 @@ namespace DigikamBqmIccConvertPlugin
 {
 
 IccConvert::IccConvert(QObject* const parent)
-    : BatchTool(QLatin1String("IccConvert"), ColorTool, parent),
-      m_settingsView(nullptr)
-{
-}
-
-IccConvert::~IccConvert()
+    : BatchTool(QLatin1String("IccConvert"), ColorTool, parent)
 {
 }
 
@@ -122,3 +117,5 @@ bool IccConvert::toolOperations()
 }
 
 } // namespace DigikamBqmIccConvertPlugin
+
+#include "moc_iccconvert.cpp"
