@@ -6,14 +6,13 @@
  * Date        : 2010-02-17
  * Description : Color profile conversion tool.
  *
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_ICC_CONVERT_H
-#define DIGIKAM_BQM_ICC_CONVERT_H
+#pragma once
 
 // Local includes
 
@@ -32,7 +31,7 @@ class IccConvert : public BatchTool
 public:
 
     explicit IccConvert(QObject* const parent = nullptr);
-    ~IccConvert()                                           override;
+    ~IccConvert()                                           override = default;
 
     BatchToolSettings defaultSettings()                     override;
 
@@ -51,9 +50,7 @@ private Q_SLOTS:
 
 private:
 
-    IccProfilesSettings* m_settingsView;
+    IccProfilesSettings* m_settingsView = nullptr;
 };
 
 } // namespace DigikamBqmIccConvertPlugin
-
-#endif // DIGIKAM_BQM_ICC_CONVERT_H
