@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ICC_CONVERT_PLUGIN_H
-#define DIGIKAM_ICC_CONVERT_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class IccConvertPlugin : public DPluginBqm
 public:
 
     explicit IccConvertPlugin(QObject* const parent = nullptr);
-    ~IccConvertPlugin()                  override;
+    ~IccConvertPlugin()                  override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -51,5 +50,3 @@ public:
 };
 
 } // namespace DigikamBqmIccConvertPlugin
-
-#endif // DIGIKAM_ICC_CONVERT_PLUGIN_H
