@@ -6,7 +6,7 @@
  * Date        : 2010-03-16
  * Description : Invert colors batch tool.
  *
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -35,10 +35,6 @@ Invert::Invert(QObject* const parent)
 {
 }
 
-Invert::~Invert()
-{
-}
-
 BatchToolSettings Invert::defaultSettings()
 {
     return BatchToolSettings();
@@ -63,3 +59,5 @@ bool Invert::toolOperations()
 }
 
 } // namespace DigikamBqmInvertPlugin
+
+#include "moc_invert.cpp"
