@@ -6,14 +6,13 @@
  * Date        : 2010-03-16
  * Description : Invert colors batch tool.
  *
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_INVERT_H
-#define DIGIKAM_BQM_INVERT_H
+#pragma once
 
 // Local includes
 
@@ -31,7 +30,7 @@ class Invert : public BatchTool
 public:
 
     explicit Invert(QObject* const parent = nullptr);
-    ~Invert()                                               override;
+    ~Invert()                                               override = default;
 
     BatchToolSettings defaultSettings()                     override;
 
@@ -48,5 +47,3 @@ private Q_SLOTS:
 };
 
 } // namespace DigikamBqmInvertPlugin
-
-#endif // DIGIKAM_BQM_INVERT_H
