@@ -6,14 +6,13 @@
  * Date        : 2010-02-27
  * Description : White Balance batch tool.
  *
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_WHITE_BALANCE_H
-#define DIGIKAM_BQM_WHITE_BALANCE_H
+#pragma once
 
 // Local includes
 
@@ -32,7 +31,7 @@ class WhiteBalance : public BatchTool
 public:
 
     explicit WhiteBalance(QObject* const parent = nullptr);
-    ~WhiteBalance()                                         override;
+    ~WhiteBalance()                                         override = default;
 
     BatchToolSettings defaultSettings()                     override;
 
@@ -51,9 +50,7 @@ private Q_SLOTS:
 
 private:
 
-    WBSettings* m_settingsView;
+    WBSettings* m_settingsView = nullptr;
 };
 
 } // namespace DigikamBqmWhiteBalancePlugin
-
-#endif // DIGIKAM_BQM_WHITE_BALANCE_H
