@@ -6,7 +6,7 @@
  * Date        : 2015-07-18
  * Description : DNG Raw Converter batch tool.
  *
- * SPDX-FileCopyrightText: 2015-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2015-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -32,12 +32,7 @@ namespace DigikamBqmConvertToDngPlugin
 {
 
 ConvertToDNG::ConvertToDNG(QObject* const parent)
-    : BatchTool(QLatin1String("ConvertToDNG"), ConvertTool, parent),
-      m_changeSettings(true)
-{
-}
-
-ConvertToDNG::~ConvertToDNG()
+    : BatchTool(QLatin1String("ConvertToDNG"), ConvertTool, parent)
 {
 }
 
@@ -152,3 +147,5 @@ bool ConvertToDNG::toolOperations()
 }
 
 } // namespace DigikamBqmConvertToDngPlugin
+
+#include "moc_converttodng.cpp"
