@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_CONVERT_TO_DNG_PLUGIN_H
-#define DIGIKAM_CONVERT_TO_DNG_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class ConvertToDngPlugin : public DPluginBqm
 public:
 
     explicit ConvertToDngPlugin(QObject* const parent = nullptr);
-    ~ConvertToDngPlugin()                override;
+    ~ConvertToDngPlugin()                override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -50,5 +49,3 @@ public:
 };
 
 } // namespace DigikamBqmConvertToDngPlugin
-
-#endif // DIGIKAM_CONVERT_TO_DNG_PLUGIN_H
