@@ -6,7 +6,7 @@
  * Date        : 2019-09-02
  * Description : HEIF image Converter batch tool.
  *
- * SPDX-FileCopyrightText: 2020-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2020-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -34,12 +34,7 @@ namespace DigikamBqmConvertToHeifPlugin
 {
 
 ConvertToHEIF::ConvertToHEIF(QObject* const parent)
-    : BatchTool(QLatin1String("ConvertToHEIF"), ConvertTool, parent),
-      m_changeSettings(true)
-{
-}
-
-ConvertToHEIF::~ConvertToHEIF()
+    : BatchTool(QLatin1String("ConvertToHEIF"), ConvertTool, parent)
 {
 }
 
@@ -125,3 +120,5 @@ bool ConvertToHEIF::toolOperations()
 }
 
 } // namespace DigikamBqmConvertToHeifPlugin
+
+#include "moc_converttoheif.cpp"
