@@ -6,14 +6,13 @@
  * Date        : 2019-09-02
  * Description : HEIF image Converter batch tool.
  *
- * SPDX-FileCopyrightText: 2020-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2020-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_CONVERT_TO_HEIF_H
-#define DIGIKAM_BQM_CONVERT_TO_HEIF_H
+#pragma once
 
 // Local includes
 
@@ -31,7 +30,7 @@ class ConvertToHEIF : public BatchTool
 public:
 
     explicit ConvertToHEIF(QObject* const parent = nullptr);
-    ~ConvertToHEIF()                                        override;
+    ~ConvertToHEIF()                                        override = default;
 
     QString outputSuffix()                            const override;
     BatchToolSettings defaultSettings()                     override;
@@ -51,9 +50,7 @@ private:
 
 private:
 
-    bool m_changeSettings;
+    bool m_changeSettings = true;
 };
 
 } // namespace DigikamBqmConvertToHeifPlugin
-
-#endif // DIGIKAM_BQM_CONVERT_TO_HEIF_H
