@@ -6,7 +6,7 @@
  * Date        : 2019-09-02
  * Description : a BQM plugin to convert to HEIF.
  *
- * SPDX-FileCopyrightText: 2020-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2020-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -37,10 +37,6 @@ ConvertToHeifPlugin::ConvertToHeifPlugin(QObject* const parent)
 {
 }
 
-ConvertToHeifPlugin::~ConvertToHeifPlugin()
-{
-}
-
 QString ConvertToHeifPlugin::name() const
 {
     return i18nc("@title", "Convert To HEIF");
@@ -94,7 +90,7 @@ QList<DPluginAuthor> ConvertToHeifPlugin::authors() const
     return QList<DPluginAuthor>()
             << DPluginAuthor(QString::fromUtf8("Gilles Caulier"),
                              QString::fromUtf8("caulier dot gilles at gmail dot com"),
-                             QString::fromUtf8("(C) 2019-2022"))
+                             QString::fromUtf8("(C) 2019-2024"))
             ;
 }
 
@@ -107,3 +103,5 @@ void ConvertToHeifPlugin::setup(QObject* const parent)
 }
 
 } // namespace DigikamBqmConvertToHeifPlugin
+
+#include "moc_converttoheifplugin.cpp"
