@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_CONVERT_TO_HEIF_PLUGIN_H
-#define DIGIKAM_CONVERT_TO_HEIF_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class ConvertToHeifPlugin : public DPluginBqm
 public:
 
     explicit ConvertToHeifPlugin(QObject* const parent = nullptr);
-    ~ConvertToHeifPlugin()               override;
+    ~ConvertToHeifPlugin()               override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -51,5 +50,3 @@ public:
 };
 
 } // namespace DigikamBqmConvertToHeifPlugin
-
-#endif // DIGIKAM_CONVERT_TO_HEIF_PLUGIN_H
