@@ -6,14 +6,13 @@
  * Date        : 2018-07-30
  * Description : a BQM plugin to convert to JPEG2000.
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_CONVERT_TO_JP2_PLUGIN_H
-#define DIGIKAM_CONVERT_TO_JP2_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class ConvertToJp2Plugin : public DPluginBqm
 public:
 
     explicit ConvertToJp2Plugin(QObject* const parent = nullptr);
-    ~ConvertToJp2Plugin()                override;
+    ~ConvertToJp2Plugin()                override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -51,5 +50,3 @@ public:
 };
 
 } // namespace DigikamBqmConvertToJp2Plugin
-
-#endif // DIGIKAM_CONVERT_TO_JP2_PLUGIN_H
