@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_CONVERT_TO_JPEG_H
-#define DIGIKAM_BQM_CONVERT_TO_JPEG_H
+#pragma once
 
 // Local includes
 
@@ -31,7 +30,7 @@ class ConvertToJPEG : public BatchTool
 public:
 
     explicit ConvertToJPEG(QObject* const parent = nullptr);
-    ~ConvertToJPEG()                                        override;
+    ~ConvertToJPEG()                                        override = default;
 
     QString outputSuffix()                            const override;
     BatchToolSettings defaultSettings()                     override;
@@ -51,9 +50,7 @@ private:
 
 private:
 
-    bool m_changeSettings;
+    bool m_changeSettings = true;
 };
 
 } // namespace DigikamBqmConvertToJpegPlugin
-
-#endif // DIGIKAM_BQM_CONVERT_TO_JPEG_H
