@@ -6,7 +6,7 @@
  * Date        : 2009-06-18
  * Description : PGF image Converter batch tool.
  *
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -34,12 +34,7 @@ namespace DigikamBqmConvertToPgfPlugin
 {
 
 ConvertToPGF::ConvertToPGF(QObject* const parent)
-    : BatchTool(QLatin1String("ConvertToPGF"), ConvertTool, parent),
-      m_changeSettings(true)
-{
-}
-
-ConvertToPGF::~ConvertToPGF()
+    : BatchTool(QLatin1String("ConvertToPGF"), ConvertTool, parent)
 {
 }
 
@@ -125,3 +120,5 @@ bool ConvertToPGF::toolOperations()
 }
 
 } // namespace DigikamBqmConvertToPgfPlugin
+
+#include "moc_converttopgf.cpp"
