@@ -6,14 +6,13 @@
  * Date        : 2009-06-18
  * Description : PGF image Converter batch tool.
  *
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_CONVERT_TO_PGF_H
-#define DIGIKAM_BQM_CONVERT_TO_PGF_H
+#pragma once
 
 // Local includes
 
@@ -31,7 +30,7 @@ class ConvertToPGF : public BatchTool
 public:
 
     explicit ConvertToPGF(QObject* const parent = nullptr);
-    ~ConvertToPGF()                                         override;
+    ~ConvertToPGF()                                         override = default;
 
     QString outputSuffix()                            const override;
     BatchToolSettings defaultSettings()                     override;
@@ -51,9 +50,7 @@ private:
 
 private:
 
-    bool m_changeSettings;
+    bool m_changeSettings = true;
 };
 
 } // namespace DigikamBqmConvertToPgfPlugin
-
-#endif // DIGIKAM_BQM_CONVERT_TO_PGF_H
