@@ -6,22 +6,13 @@
  * Date        : 2018-07-30
  * Description : a BQM plugin to convert to PGF.
  *
- * Copyright (C) 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_CONVERT_TO_PGF_PLUGIN_H
-#define DIGIKAM_CONVERT_TO_PGF_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -43,7 +34,7 @@ class ConvertToPgfPlugin : public DPluginBqm
 public:
 
     explicit ConvertToPgfPlugin(QObject* const parent = nullptr);
-    ~ConvertToPgfPlugin()                override;
+    ~ConvertToPgfPlugin()                override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -51,10 +42,11 @@ public:
     QString details()              const override;
     QString description()          const override;
     QList<DPluginAuthor> authors() const override;
+    QString handbookSection()      const override;
+    QString handbookChapter()      const override;
+    QString handbookReference()    const override;
 
     void setup(QObject* const)           override;
 };
 
 } // namespace DigikamBqmConvertToPgfPlugin
-
-#endif // DIGIKAM_CONVERT_TO_PGF_PLUGIN_H
