@@ -6,18 +6,9 @@
  * Date        : 2008-11-28
  * Description : PNG image Converter batch tool.
  *
- * Copyright (C) 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -39,18 +30,14 @@
 // Local includes
 
 #include "dimg.h"
-#include "pngsettings.h"
+#include "dimgloader.h"
+#include "dpluginloader.h"
 
 namespace DigikamBqmConvertToPngPlugin
 {
 
 ConvertToPNG::ConvertToPNG(QObject* const parent)
-    : BatchTool(QLatin1String("ConvertToPNG"), ConvertTool, parent),
-      m_changeSettings(true)
-{
-}
-
-ConvertToPNG::~ConvertToPNG()
+    : BatchTool(QLatin1String("ConvertToPNG"), ConvertTool, parent)
 {
 }
 
@@ -61,13 +48,13 @@ BatchTool* ConvertToPNG::clone(QObject* const parent) const
 
 void ConvertToPNG::registerSettingsWidget()
 {
-    QWidget* const box        = new QWidget();
-    QVBoxLayout* const vlay   = new QVBoxLayout(box);
-    PNGSettings* const PNGBox = new PNGSettings();
-    QLabel* const note        = new QLabel(i18n("<b>If conversion to PNG fails, this may be due to the "
-                                                "color profile check. Simply insert the tool for "
-                                                "color profile conversion before this tool and "
-                                                "select the desired color profile.</b>"));
+    QWidget* const box               = new QWidget();
+    QVBoxLayout* const vlay          = new QVBoxLayout(box);
+    DImgLoaderSettings* const PNGBox = DPluginLoader::instance()->exportWidget(QLatin1String("PNG"));
+    QLabel* const note               = new QLabel(i18n("<b>If conversion to PNG fails, this may be due to the "
+                                                       "color profile check. Simply insert the tool for "
+                                                       "color profile conversion before this tool and "
+                                                       "select the desired color profile.</b>"));
     note->setWordWrap(true);
     note->setFrameStyle(QFrame::StyledPanel | QFrame::Raised);
 
@@ -90,6 +77,7 @@ BatchToolSettings ConvertToPNG::defaultSettings()
     int compression           = group.readEntry(QLatin1String("PNGCompression"), 9);
     BatchToolSettings settings;
     settings.insert(QLatin1String("quality"), compression);
+
     return settings;
 }
 
@@ -97,11 +85,13 @@ void ConvertToPNG::slotAssignSettings2Widget()
 {
     m_changeSettings = false;
 
-    PNGSettings* const PNGBox = dynamic_cast<PNGSettings*>(m_settingsWidget);
+    DImgLoaderSettings* const PNGBox = dynamic_cast<DImgLoaderSettings*>(m_settingsWidget);
 
     if (PNGBox)
     {
-        PNGBox->setCompressionValue(settings()[QLatin1String("quality")].toInt());
+        DImgLoaderPrms set;
+        set.insert(QLatin1String("quality"),  settings()[QLatin1String("quality")].toInt());
+        PNGBox->setSettings(set);
     }
 
     m_changeSettings = true;
@@ -111,12 +101,12 @@ void ConvertToPNG::slotSettingsChanged()
 {
     if (m_changeSettings)
     {
-        PNGSettings* const PNGBox = dynamic_cast<PNGSettings*>(m_settingsWidget);
+        DImgLoaderSettings* const PNGBox = dynamic_cast<DImgLoaderSettings*>(m_settingsWidget);
 
         if (PNGBox)
         {
             BatchToolSettings settings;
-            settings.insert(QLatin1String("quality"), PNGBox->getCompressionValue());
+            settings.insert(QLatin1String("quality"),  PNGBox->settings()[QLatin1String("quality")].toInt());
             BatchTool::slotSettingsChanged(settings);
         }
     }
@@ -134,10 +124,12 @@ bool ConvertToPNG::toolOperations()
         return false;
     }
 
-    int PNGCompression = PNGSettings::convertCompressionForLibPng(settings()[QLatin1String("quality")].toInt());
+    int PNGCompression = DImgLoader::convertCompressionForLibPng(settings()[QLatin1String("quality")].toInt());
     image().setAttribute(QLatin1String("quality"), PNGCompression);
 
     return (savefromDImg());
 }
 
 } // namespace DigikamBqmConvertToPngPlugin
+
+#include "moc_converttopng.cpp"
