@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_CONVERT_TO_PNG_H
-#define DIGIKAM_BQM_CONVERT_TO_PNG_H
+#pragma once
 
 // Local includes
 
@@ -31,7 +30,7 @@ class ConvertToPNG : public BatchTool
 public:
 
     explicit ConvertToPNG(QObject* const parent = nullptr);
-    ~ConvertToPNG()                                         override;
+    ~ConvertToPNG()                                         override = default;
 
     QString outputSuffix()                            const override;
     BatchToolSettings defaultSettings()                     override;
@@ -51,9 +50,7 @@ private:
 
 private:
 
-    bool m_changeSettings;
+    bool m_changeSettings = true;
 };
 
 } // namespace DigikamBqmConvertToPngPlugin
-
-#endif // DIGIKAM_BQM_CONVERT_TO_PNG_H
