@@ -6,7 +6,7 @@
  * Date        : 2018-07-30
  * Description : a BQM plugin to convert to TIFF.
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -37,10 +37,6 @@ ConvertToTiffPlugin::ConvertToTiffPlugin(QObject* const parent)
 {
 }
 
-ConvertToTiffPlugin::~ConvertToTiffPlugin()
-{
-}
-
 QString ConvertToTiffPlugin::name() const
 {
     return i18nc("@title", "Convert To TIFF");
@@ -88,7 +84,7 @@ QList<DPluginAuthor> ConvertToTiffPlugin::authors() const
     return QList<DPluginAuthor>()
             << DPluginAuthor(QString::fromUtf8("Gilles Caulier"),
                              QString::fromUtf8("caulier dot gilles at gmail dot com"),
-                             QString::fromUtf8("(C) 2008-2022"))
+                             QString::fromUtf8("(C) 2008-2024"))
             ;
 }
 
@@ -101,3 +97,5 @@ void ConvertToTiffPlugin::setup(QObject* const parent)
 }
 
 } // namespace DigikamBqmConvertToTiffPlugin
+
+#include "moc_converttotiffplugin.cpp"
