@@ -61,17 +61,12 @@ public:
 
 public:
 
-    explicit Private()
-      : comboBox      (nullptr),
-        textEdit      (nullptr),
-        changeSettings(true)
-    {
-    }
+    Private() = default;
 
-    DComboBox*      comboBox;
-    QPlainTextEdit* textEdit;
+    DComboBox*      comboBox        = nullptr;
+    QPlainTextEdit* textEdit        = nullptr;
 
-    bool            changeSettings;
+    bool            changeSettings  = true;
 };
 
 UserScript::UserScript(QObject* const parent)
@@ -247,7 +242,7 @@ bool UserScript::toolOperations()
                                              QDir::toNativeSeparators(outputUrl().toLocalFile()) +
                                              QLatin1Char('"'));
 
-    // Empties d->image, not to pass it to the next tool in chain
+    // Empties image: not to pass it to the next tool in chain
 
     setImageData(DImg());
 
