@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_USER_SCRIPT_H
-#define DIGIKAM_BQM_USER_SCRIPT_H
+#pragma once
 
 // Local includes
 
@@ -54,9 +53,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamBqmUserScriptPlugin
-
-#endif // DIGIKAM_BQM_USER_SCRIPT_H
