@@ -6,14 +6,13 @@
  * Date        : 2018-07-30
  * Description : a BQM plugin to run user script.
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_USER_SCRIPT_PLUGIN_H
-#define DIGIKAM_USER_SCRIPT_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class UserScriptPlugin : public DPluginBqm
 public:
 
     explicit UserScriptPlugin(QObject* const parent = nullptr);
-    ~UserScriptPlugin()                  override;
+    ~UserScriptPlugin()                  override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -50,5 +49,3 @@ public:
 };
 
 } // namespace DigikamBqmUserScriptPlugin
-
-#endif // DIGIKAM_USER_SCRIPT_PLUGIN_H
