@@ -6,7 +6,7 @@
  * Date        : 2010-03-17
  * Description : batch tool to add border.
  *
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -32,12 +32,7 @@ namespace DigikamBqmBorderPlugin
 {
 
 Border::Border(QObject* const parent)
-    : BatchTool(QLatin1String("Border"), DecorateTool, parent),
-      m_settingsView(nullptr)
-{
-}
-
-Border::~Border()
+    : BatchTool(QLatin1String("Border"), DecorateTool, parent)
 {
 }
 
@@ -164,3 +159,5 @@ bool Border::toolOperations()
 }
 
 } // namespace DigikamBqmBorderPlugin
+
+#include "moc_border.cpp"
