@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_TEXTURE_H
-#define DIGIKAM_BQM_TEXTURE_H
+#pragma once
 
 // Local includes
 
@@ -32,7 +31,7 @@ class Texture : public BatchTool
 public:
 
     explicit Texture(QObject* const parent = nullptr);
-    ~Texture()                                              override;
+    ~Texture()                                              override = default;
 
     BatchToolSettings defaultSettings()                     override;
 
@@ -51,9 +50,7 @@ private:
 
 private:
 
-    TextureSettings* m_settingsView;
+    TextureSettings* m_settingsView = nullptr;
 };
 
 } // namespace DigikamBqmTexturePlugin
-
-#endif // DIGIKAM_BQM_TEXTURE_H
