@@ -6,7 +6,7 @@
  * Date        : 2020-08-13
  * Description : a BQM plugin to add texture
  *
- * SPDX-FileCopyrightText: 2020-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2020-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -37,10 +37,6 @@ TexturePlugin::TexturePlugin(QObject* const parent)
 {
 }
 
-TexturePlugin::~TexturePlugin()
-{
-}
-
 QString TexturePlugin::name() const
 {
     return i18nc("@title", "Add Texture");
@@ -89,7 +85,7 @@ QList<DPluginAuthor> TexturePlugin::authors() const
                              QString::fromUtf8("(C) 2006-2010"))
             << DPluginAuthor(QString::fromUtf8("Gilles Caulier"),
                              QString::fromUtf8("caulier dot gilles at gmail dot com"),
-                             QString::fromUtf8("(C) 2005-2022"))
+                             QString::fromUtf8("(C) 2005-2024"))
             ;
 }
 
@@ -102,3 +98,5 @@ void TexturePlugin::setup(QObject* const parent)
 }
 
 } // namespace DigikamBqmTexturePlugin
+
+#include "moc_textureplugin.cpp"
