@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_ANTI_VIGNETTING_H
-#define DIGIKAM_BQM_ANTI_VIGNETTING_H
+#pragma once
 
 // Local includes
 
@@ -32,7 +31,7 @@ class AntiVignetting : public BatchTool
 public:
 
     explicit AntiVignetting(QObject* const parent = nullptr);
-    ~AntiVignetting()                                       override;
+    ~AntiVignetting()                                       override = default;
 
     BatchToolSettings defaultSettings()                     override;
 
@@ -51,9 +50,7 @@ private Q_SLOTS:
 
 private:
 
-    AntiVignettingSettings* m_settingsView;
+    AntiVignettingSettings* m_settingsView = nullptr;
 };
 
 } // namespace DigikamBqmAntiVignettingPlugin
-
-#endif // DIGIKAM_BQM_ANTI_VIGNETTING_H
