@@ -6,14 +6,13 @@
  * Date        : 2018-07-30
  * Description : a BQM plugin to correct vignetting
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ANTI_VIGNETTING_PLUGIN_H
-#define DIGIKAM_ANTI_VIGNETTING_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class AntiVignettingPlugin : public DPluginBqm
 public:
 
     explicit AntiVignettingPlugin(QObject* const parent = nullptr);
-    ~AntiVignettingPlugin()              override;
+    ~AntiVignettingPlugin()              override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -51,5 +50,3 @@ public:
 };
 
 } // namespace DigikamBqmAntiVignettingPlugin
-
-#endif // DIGIKAM_ANTI_VIGNETTING_PLUGIN_H
