@@ -6,14 +6,13 @@
  * Date        : 2010-05-03
  * Description : blur image batch tool.
  *
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_BLUR_H
-#define DIGIKAM_BQM_BLUR_H
+#pragma once
 
 #include "batchtool.h"
 #include "dnuminput.h"
@@ -30,7 +29,7 @@ class Blur : public BatchTool
 public:
 
     explicit Blur(QObject* const parent = nullptr);
-    ~Blur()                                                 override;
+    ~Blur()                                                 override = default;
 
     BatchToolSettings defaultSettings()                     override;
 
@@ -49,10 +48,8 @@ private Q_SLOTS:
 
 private:
 
-    DIntNumInput* m_radiusInput;
-    bool          m_changeSettings;
+    DIntNumInput* m_radiusInput     = nullptr;
+    bool          m_changeSettings  = true;
 };
 
 } // namespace DigikamBqmBlurPlugin
-
-#endif // DIGIKAM_BQM_BLUR_H
