@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BLUR_PLUGIN_H
-#define DIGIKAM_BLUR_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class BlurPlugin : public DPluginBqm
 public:
 
     explicit BlurPlugin(QObject* const parent = nullptr);
-    ~BlurPlugin()                        override;
+    ~BlurPlugin()                        override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -51,5 +50,3 @@ public:
 };
 
 } // namespace DigikamBqmBlurPlugin
-
-#endif // DIGIKAM_BLUR_PLUGIN_H
