@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_HOT_PIXELS_H
-#define DIGIKAM_BQM_HOT_PIXELS_H
+#pragma once
 
 // Local includes
 
@@ -32,7 +31,7 @@ class HotPixels : public BatchTool
 public:
 
     explicit HotPixels(QObject* const parent = nullptr);
-    ~HotPixels()                                            override;
+    ~HotPixels()                                            override = default;
 
     BatchToolSettings defaultSettings()                     override;
 
@@ -51,9 +50,7 @@ private Q_SLOTS:
 
 private:
 
-    HotPixelSettings* m_settingsView;
+    HotPixelSettings* m_settingsView = nullptr;
 };
 
 } // namespace DigikamBqmHotPixelsPlugin
-
-#endif // DIGIKAM_BQM_HOT_PIXELS_H
