@@ -6,14 +6,13 @@
  * Date        : 2020-08-07
  * Description : a BQM plugin to fix hot pixels
  *
- * SPDX-FileCopyrightText: 2020-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2020-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_HOT_PIXELS_PLUGIN_H
-#define DIGIKAM_HOT_PIXELS_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class HotPixelsPlugin : public DPluginBqm
 public:
 
     explicit HotPixelsPlugin(QObject* const parent = nullptr);
-    ~HotPixelsPlugin()                   override;
+    ~HotPixelsPlugin()                   override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -51,5 +50,3 @@ public:
 };
 
 } // namespace DigikamBqmHotPixelsPlugin
-
-#endif // DIGIKAM_HOT_PIXELS_PLUGIN_H
