@@ -6,14 +6,13 @@
  * Date        : 2010-09-18
  * Description : lens auto-fix batch tool.
  *
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_LENS_AUTO_FIX_H
-#define DIGIKAM_BQM_LENS_AUTO_FIX_H
+#pragma once
 
 #include "batchtool.h"
 
@@ -49,9 +48,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamBqmLensAutoFixPlugin
-
-#endif // DIGIKAM_BQM_LENS_AUTO_FIX_H
