@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_LOCAL_CONTRAST_H
-#define DIGIKAM_BQM_LOCAL_CONTRAST_H
+#pragma once
 
 // Local includes
 
@@ -32,7 +31,7 @@ class LocalContrast : public BatchTool
 public:
 
     explicit LocalContrast(QObject* const parent = nullptr);
-    ~LocalContrast()                                        override;
+    ~LocalContrast()                                        override = default;
 
     BatchToolSettings defaultSettings()                     override;
 
@@ -51,9 +50,7 @@ private Q_SLOTS:
 
 private:
 
-    LocalContrastSettings* m_settingsView;
+    LocalContrastSettings* m_settingsView = nullptr;
 };
 
 } // namespace DigikamBqmLocalContrastPlugin
-
-#endif // DIGIKAM_BQM_LOCAL_CONTRAST_H
