@@ -6,14 +6,13 @@
  * Date        : 2009-11-21
  * Description : Wavelets Noise Reduction batch tool.
  *
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_NOISE_REDUCTION_H
-#define DIGIKAM_BQM_NOISE_REDUCTION_H
+#pragma once
 
 // Local includes
 
@@ -32,7 +31,7 @@ class NoiseReduction : public BatchTool
 public:
 
     explicit NoiseReduction(QObject* const parent = nullptr);
-    ~NoiseReduction()                                       override;
+    ~NoiseReduction()                                       override = default;
 
     BatchToolSettings defaultSettings()                     override;
 
@@ -51,9 +50,7 @@ private Q_SLOTS:
 
 private:
 
-    NRSettings* m_settingsView;
+    NRSettings* m_settingsView = nullptr;
 };
 
 } // namespace DigikamBqmNoiseReductionPlugin
-
-#endif // DIGIKAM_BQM_NOISE_REDUCTION_H
