@@ -6,7 +6,7 @@
  * Date        : 2009-02-19
  * Description : Restoration batch tool.
  *
- * SPDX-FileCopyrightText: 2009-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -35,13 +35,7 @@ namespace DigikamBqmRestorationPlugin
 {
 
 Restoration::Restoration(QObject* const parent)
-    : BatchTool(QLatin1String("Restoration"), EnhanceTool, parent),
-      m_comboBox (nullptr),
-      m_cimgIface(nullptr)
-{
-}
-
-Restoration::~Restoration()
+    : BatchTool(QLatin1String("Restoration"), EnhanceTool, parent)
 {
 }
 
@@ -166,3 +160,5 @@ void Restoration::cancel()
 }
 
 } // namespace DigikamBqmRestorationPlugin
+
+#include "moc_restoration.cpp"
