@@ -6,23 +6,13 @@
  * Date        : 2009-02-19
  * Description : Restoration batch tool.
  *
- * Copyright (C) 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_RESTORATION_H
-#define DIGIKAM_BQM_RESTORATION_H
+#pragma once
 
 // Local includes
 
@@ -33,7 +23,7 @@ class QComboBox;
 
 using namespace Digikam;
 
-namespace Digikam
+namespace DigikamBqmRestorationPlugin
 {
 
 class Restoration : public BatchTool
@@ -43,7 +33,7 @@ class Restoration : public BatchTool
 public:
 
     explicit Restoration(QObject* const parent = nullptr);
-    ~Restoration()                                          override;
+    ~Restoration()                                          override = default;
 
     BatchToolSettings defaultSettings()                     override;
 
@@ -71,11 +61,9 @@ private:
         ReduceTexturing
     };
 
-    QComboBox*            m_comboBox;
+    QComboBox*            m_comboBox  = nullptr;
 
-    GreycstorationFilter* m_cimgIface;
+    GreycstorationFilter* m_cimgIface = nullptr;
 };
 
-} // namespace Digikam
-
-#endif // DIGIKAM_BQM_RESTORATION_H
+} // namespace DigikamBqmRestorationPlugin
