@@ -6,7 +6,7 @@
  * Date        : 2018-07-30
  * Description : a BQM plugin to restore images
  *
- * SPDX-FileCopyrightText: 2018-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -37,10 +37,6 @@ RestorationPlugin::RestorationPlugin(QObject* const parent)
 {
 }
 
-RestorationPlugin::~RestorationPlugin()
-{
-}
-
 QString RestorationPlugin::name() const
 {
     return i18nc("@title", "Restoration");
@@ -86,7 +82,7 @@ QList<DPluginAuthor> RestorationPlugin::authors() const
     return QList<DPluginAuthor>()
             << DPluginAuthor(QString::fromUtf8("Gilles Caulier"),
                              QString::fromUtf8("caulier dot gilles at gmail dot com"),
-                             QString::fromUtf8("(C) 2009-2023"))
+                             QString::fromUtf8("(C) 2009-2024"))
             ;
 }
 
@@ -99,3 +95,5 @@ void RestorationPlugin::setup(QObject* const parent)
 }
 
 } // namespace DigikamBqmRestorationPlugin
+
+#include "moc_restorationplugin.cpp"
