@@ -7,7 +7,7 @@
  * Description : sharpen image batch tool.
  *
  * SPDX-FileCopyrightText: 2009      by Matthias Welwarsky <matze at welwarsky dot de>
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -39,12 +39,7 @@ namespace DigikamBqmSharpenPlugin
 {
 
 Sharpen::Sharpen(QObject* const parent)
-    : BatchTool(QLatin1String("Sharpen"), EnhanceTool, parent),
-      m_settingsView(nullptr)
-{
-}
-
-Sharpen::~Sharpen()
+    : BatchTool(QLatin1String("Sharpen"), EnhanceTool, parent)
 {
 }
 
@@ -234,3 +229,5 @@ bool Sharpen::toolOperations()
 }
 
 } // namespace DigikamBqmSharpenPlugin
+
+#include "moc_sharpen.cpp"
