@@ -7,14 +7,13 @@
  * Description : sharpen image batch tool.
  *
  * SPDX-FileCopyrightText: 2009      by Matthias Welwarsky <matze at welwarsky dot de>
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_SHARPEN_H
-#define DIGIKAM_BQM_SHARPEN_H
+#pragma once
 
 #include "batchtool.h"
 #include "sharpsettings.h"
@@ -31,7 +30,7 @@ class Sharpen : public BatchTool
 public:
 
     explicit Sharpen(QObject* const parent = nullptr);
-    ~Sharpen()                                              override;
+    ~Sharpen()                                              override = default;
 
     BatchToolSettings defaultSettings()                     override;
 
@@ -50,9 +49,7 @@ private Q_SLOTS:
 
 private:
 
-    SharpSettings* m_settingsView;
+    SharpSettings* m_settingsView = nullptr;
 };
 
 } // namespace DigikamBqmSharpenPlugin
-
-#endif // DIGIKAM_BQM_SHARPEN_H
