@@ -6,17 +6,9 @@
  * Date        : 2018-07-30
  * Description : a BQM plugin to apply color effects
  *
- * Copyright (C) 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -45,13 +37,9 @@ ColorFXPlugin::ColorFXPlugin(QObject* const parent)
 {
 }
 
-ColorFXPlugin::~ColorFXPlugin()
-{
-}
-
 QString ColorFXPlugin::name() const
 {
-    return i18n("Color Effects");
+    return i18nc("@title", "Color Effects");
 }
 
 QString ColorFXPlugin::iid() const
@@ -66,12 +54,27 @@ QIcon ColorFXPlugin::icon() const
 
 QString ColorFXPlugin::description() const
 {
-    return i18n("A tool to apply color effects");
+    return i18nc("@info", "A tool to apply color effects");
 }
 
 QString ColorFXPlugin::details() const
 {
-    return i18n("<p>This Batch Queue Manager tool can apply color effects over images.</p>");
+    return xi18nc("@info", "<para>This Batch Queue Manager tool can apply color effects over images.</para>");
+}
+
+QString ColorFXPlugin::handbookSection() const
+{
+    return QLatin1String("batch_queue");
+}
+
+QString ColorFXPlugin::handbookChapter() const
+{
+    return QLatin1String("base_tools");
+}
+
+QString ColorFXPlugin::handbookReference() const
+{
+    return QLatin1String("bqm-effecttools");
 }
 
 QList<DPluginAuthor> ColorFXPlugin::authors() const
@@ -92,3 +95,5 @@ void ColorFXPlugin::setup(QObject* const parent)
 }
 
 } // namespace DigikamBqmColorFXPlugin
+
+#include "moc_colorfxplugin.cpp"
