@@ -6,18 +6,9 @@
  * Date        : 2010-05-03
  * Description : a batch tool to add film grain to images.
  *
- * Copyright (C) 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -42,12 +33,7 @@ namespace DigikamBqmFilmGrainPlugin
 {
 
 FilmGrain::FilmGrain(QObject* const parent)
-    : BatchTool(QLatin1String("FilmGrain"), FiltersTool, parent),
-      m_settingsView(nullptr)
-{
-}
-
-FilmGrain::~FilmGrain()
+    : BatchTool(QLatin1String("FilmGrain"), FiltersTool, parent)
 {
 }
 
@@ -176,3 +162,5 @@ bool FilmGrain::toolOperations()
 }
 
 } // namespace DigikamBqmFilmGrainPlugin
+
+#include "moc_filmgrain.cpp"
