@@ -6,14 +6,13 @@
  * Date        : 2010-05-03
  * Description : a batch tool to add film grain to images.
  *
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_FILM_GRAIN_H
-#define DIGIKAM_BQM_FILM_GRAIN_H
+#pragma once
 
 // Local includes
 
@@ -32,7 +31,7 @@ class FilmGrain : public BatchTool
 public:
 
     explicit FilmGrain(QObject* const parent = nullptr);
-    ~FilmGrain()                                            override;
+    ~FilmGrain()                                            override = default;
 
     BatchToolSettings defaultSettings()                     override;
 
@@ -51,9 +50,7 @@ private Q_SLOTS:
 
 private:
 
-    FilmGrainSettings* m_settingsView;
+    FilmGrainSettings* m_settingsView = nullptr;
 };
 
 } // namespace DigikamBqmFilmGrainPlugin
-
-#endif // DIGIKAM_BQM_FILM_GRAIN_H
