@@ -6,7 +6,7 @@
  * Date        : 2018-07-30
  * Description : a BQM plugin to apply film grain
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -37,10 +37,6 @@ FilmGrainPlugin::FilmGrainPlugin(QObject* const parent)
 {
 }
 
-FilmGrainPlugin::~FilmGrainPlugin()
-{
-}
-
 QString FilmGrainPlugin::name() const
 {
     return i18nc("@title", "Film Grain");
@@ -86,7 +82,7 @@ QList<DPluginAuthor> FilmGrainPlugin::authors() const
     return QList<DPluginAuthor>()
             << DPluginAuthor(QString::fromUtf8("Gilles Caulier"),
                              QString::fromUtf8("caulier dot gilles at gmail dot com"),
-                             QString::fromUtf8("(C) 2010-2022"))
+                             QString::fromUtf8("(C) 2010-2024"))
             ;
 }
 
@@ -99,3 +95,5 @@ void FilmGrainPlugin::setup(QObject* const parent)
 }
 
 } // namespace DigikamBqmFilmGrainPlugin
+
+#include "moc_filmgrainplugin.cpp"
