@@ -6,14 +6,13 @@
  * Date        : 2022-09-24
  * Description : assign captions metadata batch tool.
  *
- * SPDX-FileCopyrightText: 2021-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_ASSIGN_CAPTIONS_H
-#define DIGIKAM_BQM_ASSIGN_CAPTIONS_H
+#pragma once
 
 // Local includes
 
@@ -51,9 +50,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamBqmAssignCaptionsPlugin
-
-#endif // DIGIKAM_BQM_ASSIGN_CAPTIONS_H
