@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ASSIGN_CAPTIONS_PLUGIN_H
-#define DIGIKAM_ASSIGN_CAPTIONS_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class AssignCaptionsPlugin : public DPluginBqm
 public:
 
     explicit AssignCaptionsPlugin(QObject* const parent = nullptr);
-    ~AssignCaptionsPlugin()              override;
+    ~AssignCaptionsPlugin()              override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -51,5 +50,3 @@ public:
 };
 
 } // namespace DigikamBqmAssignCaptionsPlugin
-
-#endif // DIGIKAM_ASSIGN_CAPTIONS_PLUGIN_H
