@@ -6,14 +6,13 @@
  * Date        : 2022-09-23
  * Description : a BQM plugin to assign labels metadata.
  *
- * SPDX-FileCopyrightText: 2021-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ASSIGN_LABELS_PLUGIN_H
-#define DIGIKAM_ASSIGN_LABELS_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class AssignLabelsPlugin : public DPluginBqm
 public:
 
     explicit AssignLabelsPlugin(QObject* const parent = nullptr);
-    ~AssignLabelsPlugin()                override;
+    ~AssignLabelsPlugin()                override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -51,5 +50,3 @@ public:
 };
 
 } // namespace DigikamBqmAssignLabelsPlugin
-
-#endif // DIGIKAM_ASSIGN_LABELS_PLUGIN_H
