@@ -4,16 +4,15 @@
  * https://www.digikam.org
  *
  * Date        : 2022-10-03
- * Description : assign tags metadata batch tool.
+ * Description : auto assign tags batch tool.
  *
- * SPDX-FileCopyrightText: 2021-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2022-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_ASSIGN_TAGS_H
-#define DIGIKAM_BQM_ASSIGN_TAGS_H
+#pragma once
 
 // Local includes
 
@@ -31,7 +30,7 @@ class AssignTags : public BatchTool
 public:
 
     explicit AssignTags(QObject* const parent = nullptr);
-    ~AssignTags()                                          override;
+    ~AssignTags()                                           override;
 
     BatchToolSettings defaultSettings()                     override;
 
@@ -51,9 +50,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamBqmAssignTagsPlugin
-
-#endif // DIGIKAM_BQM_ASSIGN_TAGS_H
