@@ -6,18 +6,9 @@
  * Date        : 2009-03-04
  * Description : assign metadata template batch tool.
  *
- * Copyright (C) 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -40,18 +31,13 @@
 #include "dmetadata.h"
 #include "template.h"
 #include "templatemanager.h"
+#include "dfileoperations.h"
 
 namespace DigikamBqmAssignTemplatePlugin
 {
 
 AssignTemplate::AssignTemplate(QObject* const parent)
-    : BatchTool(QLatin1String("AssignTemplate"), MetadataTool, parent),
-      m_templateSelector(nullptr),
-      m_templateViewer(nullptr)
-{
-}
-
-AssignTemplate::~AssignTemplate()
+    : BatchTool(QLatin1String("AssignTemplate"), MetadataTool, parent)
 {
 }
 
@@ -133,14 +119,11 @@ bool AssignTemplate::toolOperations()
     {
         meta->removeMetadataTemplate();
     }
-    else if (title.isEmpty())
+    else if (!title.isEmpty())
     {
-        // Nothing to do.
-    }
-    else
-    {
-        Template t = TemplateManager::defaultManager()->findByTitle(title);
-        meta->removeMetadataTemplate();
+        Template t = meta->getMetadataTemplate();
+        t.merge(TemplateManager::defaultManager()->findByTitle(title));
+
         meta->setMetadataTemplate(t);
     }
 
@@ -149,7 +132,7 @@ bool AssignTemplate::toolOperations()
     if (image().isNull())
     {
         QFile::remove(outputUrl().toLocalFile());
-        ret = QFile::copy(inputUrl().toLocalFile(), outputUrl().toLocalFile());
+        ret = DFileOperations::copyFile(inputUrl().toLocalFile(), outputUrl().toLocalFile());
 
         if (ret && !title.isEmpty())
         {
@@ -170,3 +153,5 @@ bool AssignTemplate::toolOperations()
 }
 
 } // namespace DigikamBqmAssignTemplatePlugin
+
+#include "moc_assigntemplate.cpp"
