@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_ASSIGN_TEMPLATE_H
-#define DIGIKAM_BQM_ASSIGN_TEMPLATE_H
+#pragma once
 
 // Local includes
 
@@ -33,7 +32,7 @@ class AssignTemplate : public BatchTool
 public:
 
     explicit AssignTemplate(QObject* const parent = nullptr);
-    ~AssignTemplate()                                       override;
+    ~AssignTemplate()                                       override = default;
 
     BatchToolSettings defaultSettings()                     override;
 
@@ -52,10 +51,8 @@ private Q_SLOTS:
 
 private:
 
-    TemplateSelector* m_templateSelector;
-    TemplateViewer*   m_templateViewer;
+    TemplateSelector* m_templateSelector = nullptr;
+    TemplateViewer*   m_templateViewer   = nullptr;
 };
 
 } // namespace DigikamBqmAssignTemplatePlugin
-
-#endif // DIGIKAM_BQM_ASSIGN_TEMPLATE_H
