@@ -6,14 +6,13 @@
  * Date        : 2018-07-30
  * Description : a BQM plugin to assign template
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ASSIGN_TEMPLATE_PLUGIN_H
-#define DIGIKAM_ASSIGN_TEMPLATE_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class AssignTemplatePlugin : public DPluginBqm
 public:
 
     explicit AssignTemplatePlugin(QObject* const parent = nullptr);
-    ~AssignTemplatePlugin()              override;
+    ~AssignTemplatePlugin()              override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -51,5 +50,3 @@ public:
 };
 
 } // namespace DigikamBqmAssignTemplatePlugin
-
-#endif // DIGIKAM_ASSIGN_TEMPLATE_PLUGIN_H
