@@ -6,14 +6,13 @@
  * Date        : 2022-09-22
  * Description : assign pick label metadata by image quality batch tool.
  *
- * SPDX-FileCopyrightText: 2021-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_QUALITY_SORT_H
-#define DIGIKAM_BQM_QUALITY_SORT_H
+#pragma once
 
 // Local includes
 
@@ -53,9 +52,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamBqmQualitySortPlugin
-
-#endif // DIGIKAM_BQM_QUALITY_SORT_H
