@@ -6,14 +6,13 @@
  * Date        : 2022-09-22
  * Description : a BQM plugin to assign pick label metadata by image quality
  *
- * SPDX-FileCopyrightText: 2021-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_QUALITY_SORT_PLUGIN_H
-#define DIGIKAM_QUALITY_SORT_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class QualitySortPlugin : public DPluginBqm
 public:
 
     explicit QualitySortPlugin(QObject* const parent = nullptr);
-    ~QualitySortPlugin()                 override;
+    ~QualitySortPlugin()                 override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -51,5 +50,3 @@ public:
 };
 
 } // namespace DigikamBqmQualitySortPlugin
-
-#endif // DIGIKAM_QUALITY_SORT_PLUGIN_H
