@@ -6,7 +6,7 @@
  * Date        : 2010-09-14
  * Description : remove metadata batch tool.
  *
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -52,32 +52,24 @@ public:
         COMMENT,
         DIGIKAM,
         HISTORY,
+        PREVIEW,
         XPKEYWORDS
 
     };
 
 public:
 
-    explicit Private()
-      : removeExif      (nullptr),
-        removeIptc      (nullptr),
-        removeXmp       (nullptr),
-        exifComboBox    (nullptr),
-        iptcComboBox    (nullptr),
-        xmpComboBox     (nullptr),
-        changeSettings  (true)
-    {
-    }
+    Private() = default;
 
-    QCheckBox* removeExif;
-    QCheckBox* removeIptc;
-    QCheckBox* removeXmp;
+    QCheckBox* removeExif       = nullptr;
+    QCheckBox* removeIptc       = nullptr;
+    QCheckBox* removeXmp        = nullptr;
 
-    QComboBox* exifComboBox;
-    QComboBox* iptcComboBox;
-    QComboBox* xmpComboBox;
+    QComboBox* exifComboBox     = nullptr;
+    QComboBox* iptcComboBox     = nullptr;
+    QComboBox* xmpComboBox      = nullptr;
 
-    bool       changeSettings;
+    bool       changeSettings   = true;
 };
 
 RemoveMetadata::RemoveMetadata(QObject* const parent)
@@ -103,28 +95,31 @@ void RemoveMetadata::registerSettingsWidget()
 
     d->removeExif            = new QCheckBox(i18nc("@title", "Exif:"), panel);
     d->exifComboBox          = new QComboBox(panel);
-    d->exifComboBox->addItem(i18nc("@item: exif namespace", "Completely"),              Private::ALL);
-    d->exifComboBox->addItem(i18nc("@item: exif namespace", "Date"),                    Private::DATE);
-    d->exifComboBox->addItem(i18nc("@item: exif namespace", "GPS"),                     Private::GPS);
-    d->exifComboBox->addItem(i18nc("@item: exif namespace", "XPKeywords"),              Private::XPKEYWORDS);
-    d->exifComboBox->addItem(i18nc("@item: exif namespace", "Comment and description"), Private::COMMENT);
+    d->exifComboBox->addItem(i18nc("@item: exif namespace", "Completely"),                     Private::ALL);
+    d->exifComboBox->addItem(i18nc("@item: exif namespace", "Date"),                           Private::DATE);
+    d->exifComboBox->addItem(i18nc("@item: exif namespace", "GPS"),                            Private::GPS);
+    d->exifComboBox->addItem(i18nc("@item: exif namespace", "XPKeywords"),                     Private::XPKEYWORDS);
+    d->exifComboBox->addItem(i18nc("@item: exif namespace", "Comment and description"),        Private::COMMENT);
 
     d->removeIptc            = new QCheckBox(i18nc("@title", "Iptc:"), panel);
     d->iptcComboBox          = new QComboBox(panel);
-    d->iptcComboBox->addItem(i18nc("@item: iptc namespace", "Completely"), Private::ALL);
-    d->iptcComboBox->addItem(i18nc("@item: iptc namespace", "Date"),       Private::DATE);
-    d->iptcComboBox->addItem(i18nc("@item: iptc namespace", "Caption"),    Private::COMMENT);
+    d->iptcComboBox->addItem(i18nc("@item: iptc namespace", "Completely"),                     Private::ALL);
+    d->iptcComboBox->addItem(i18nc("@item: iptc namespace", "Date"),                           Private::DATE);
+    d->iptcComboBox->addItem(i18nc("@item: iptc namespace", "Caption"),                        Private::COMMENT);
+    d->iptcComboBox->addItem(i18nc("@item: iptc namespace", "Preview image"),                  Private::PREVIEW);
 
     d->removeXmp             = new QCheckBox(i18nc("@title", "Xmp:"), panel);
     d->xmpComboBox           = new QComboBox(panel);
     d->xmpComboBox->addItem(i18nc("@item: xmp namespace", "Completely"),                       Private::ALL);
     d->xmpComboBox->addItem(i18nc("@item: xmp namespace", "Date"),                             Private::DATE);
-    d->xmpComboBox->addItem(i18nc("@item: xmp namespace", "DigiKam"),                          Private::DIGIKAM);
-    d->xmpComboBox->addItem(i18nc("@item: xmp namespace", "DigiKam image history"),            Private::HISTORY);
+    d->xmpComboBox->addItem(i18nc("@item: xmp namespace", "digiKam completely"),               Private::DIGIKAM);
+    d->xmpComboBox->addItem(i18nc("@item: xmp namespace", "digiKam image history"),            Private::HISTORY);
+    d->xmpComboBox->addItem(i18nc("@item: xmp namespace", "digiKam preview image"),            Private::PREVIEW);
     d->xmpComboBox->addItem(i18nc("@item: xmp namespace", "Dublin Core"),                      Private::DUBLIN);
     d->xmpComboBox->addItem(i18nc("@item: xmp namespace", "Exif"),                             Private::EXIF);
     d->xmpComboBox->addItem(i18nc("@item: xmp namespace", "Video"),                            Private::VIDEO);
-    d->xmpComboBox->addItem(i18nc("@item: xmp namespace", "Caption, Comment and Description"), Private::COMMENT);
+    d->xmpComboBox->addItem(i18nc("@item: xmp namespace", "Caption, comment and description"), Private::COMMENT);
+
 
     grid->addWidget(d->removeExif,   0, 0, 1, 1);
     grid->addWidget(d->exifComboBox, 0, 1, 1, 2);
@@ -294,6 +289,12 @@ bool RemoveMetadata::toolOperations()
             meta->removeIptcTag("Iptc.Application2.Caption");
             meta->clearComments();
         }
+        else if (iptcData == Private::PREVIEW)
+        {
+            meta->removeIptcTag("Iptc.Application2.Preview");
+            meta->removeIptcTag("Iptc.Application2.PreviewFormat");
+            meta->removeIptcTag("Iptc.Application2.PreviewVersion");
+        }
     }
 
     if (removeXmp)
@@ -315,13 +316,17 @@ bool RemoveMetadata::toolOperations()
             meta->removeXmpTag("Xmp.video.ModificationDate");
             meta->removeXmpTag("Xmp.video.DateUTC");
         }
+        else if (xmpData == Private::DIGIKAM)
+        {
+            meta->removeXmpTags(QStringList() << QLatin1String("digiKam"));
+        }
         else if (xmpData == Private::HISTORY)
         {
             meta->removeXmpTag("Xmp.digiKam.ImageHistory");
         }
-        else if (xmpData == Private::DIGIKAM)
+        else if (xmpData == Private::PREVIEW)
         {
-            meta->removeXmpTags(QStringList() << QLatin1String("digiKam"));
+            meta->removeXmpTag("Xmp.digiKam.Preview");
         }
         else if (xmpData == Private::DUBLIN)
         {
@@ -357,3 +362,5 @@ bool RemoveMetadata::toolOperations()
 }
 
 } // namespace DigikamBqmRemoveMetadataPlugin
+
+#include "moc_removemetadata.cpp"
