@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_REMOVE_METADATA_PLUGIN_H
-#define DIGIKAM_REMOVE_METADATA_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class RemoveMetadataPlugin : public DPluginBqm
 public:
 
     explicit RemoveMetadataPlugin(QObject* const parent = nullptr);
-    ~RemoveMetadataPlugin()              override;
+    ~RemoveMetadataPlugin()              override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -51,5 +50,3 @@ public:
 };
 
 } // namespace DigikamBqmRemoveMetadataPlugin
-
-#endif // DIGIKAM_REMOVE_METADATA_PLUGIN_H
