@@ -6,14 +6,13 @@
  * Date        : 2009-03-04
  * Description : a tool to adjust date time stamp of images
  *
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_TIME_ADJUST_H
-#define DIGIKAM_BQM_TIME_ADJUST_H
+#pragma once
 
 // Local includes
 
@@ -32,7 +31,7 @@ class TimeAdjust : public BatchTool
 public:
 
     explicit TimeAdjust(QObject* const parent = nullptr);
-    ~TimeAdjust()                                           override;
+    ~TimeAdjust()                                           override = default;
 
     BatchToolSettings defaultSettings()                     override;
 
@@ -51,10 +50,8 @@ private Q_SLOTS:
 
 private:
 
-    TimeAdjustSettings* m_taWidget;
-    int                 m_changeSettings;
+    TimeAdjustSettings* m_taWidget       = nullptr;
+    bool                m_changeSettings = true;
 };
 
 } // namespace DigikamBqmTimeAdjustPlugin
-
-#endif // DIGIKAM_BQM_TIME_ADJUST_H
