@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_TIME_ADJUST_PLUGIN_H
-#define DIGIKAM_TIME_ADJUST_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class TimeAdjustPlugin : public DPluginBqm
 public:
 
     explicit TimeAdjustPlugin(QObject* const parent = nullptr);
-    ~TimeAdjustPlugin()                  override;
+    ~TimeAdjustPlugin()                  override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -51,5 +50,3 @@ public:
 };
 
 } // namespace DigikamBqmTimeAdjustPlugin
-
-#endif // DIGIKAM_TIME_ADJUST_PLUGIN_H
