@@ -6,14 +6,13 @@
  * Date        : 2022-08-30
  * Description : a BQM plugin to translate metadata
  *
- * SPDX-FileCopyrightText: 2021-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_TRANSLATE_PLUGIN_H
-#define DIGIKAM_TRANSLATE_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class TranslatePlugin : public DPluginBqm
 public:
 
     explicit TranslatePlugin(QObject* const parent = nullptr);
-    ~TranslatePlugin()              override;
+    ~TranslatePlugin()                   override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -51,5 +50,3 @@ public:
 };
 
 } // namespace DigikamBqmTranslatePlugin
-
-#endif // DIGIKAM_TRANSLATE_PLUGIN_H
