@@ -6,14 +6,13 @@
  * Date        : 2012-12-28
  * Description : crop image batch tool.
  *
- * SPDX-FileCopyrightText: 2012-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_CROP_H
-#define DIGIKAM_BQM_CROP_H
+#pragma once
 
 // Local includes
 
@@ -56,9 +55,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamBqmCropPlugin
-
-#endif // DIGIKAM_BQM_CROP_H
