@@ -6,7 +6,7 @@
  * Date        : 2018-07-30
  * Description : a BQM plugin to crop images.
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -37,10 +37,6 @@ CropPlugin::CropPlugin(QObject* const parent)
 {
 }
 
-CropPlugin::~CropPlugin()
-{
-}
-
 QString CropPlugin::name() const
 {
     return i18nc("@title", "Crop");
@@ -86,7 +82,7 @@ QList<DPluginAuthor> CropPlugin::authors() const
     return QList<DPluginAuthor>()
             << DPluginAuthor(QString::fromUtf8("Gilles Caulier"),
                              QString::fromUtf8("caulier dot gilles at gmail dot com"),
-                             QString::fromUtf8("(C) 2012-2022"))
+                             QString::fromUtf8("(C) 2012-2024"))
             ;
 }
 
@@ -99,3 +95,5 @@ void CropPlugin::setup(QObject* const parent)
 }
 
 } // namespace DigikamBqmCropPlugin
+
+#include "moc_cropplugin.cpp"
