@@ -6,14 +6,13 @@
  * Date        : 2009-02-10
  * Description : flip image batch tool.
  *
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_FLIP_H
-#define DIGIKAM_BQM_FLIP_H
+#pragma once
 
 // Local includes
 
@@ -33,7 +32,7 @@ class Flip : public BatchTool
 public:
 
     explicit Flip(QObject* const parent = nullptr);
-    ~Flip()                                                 override;
+    ~Flip()                                                 override = default;
 
     BatchToolSettings defaultSettings()                     override;
 
@@ -52,9 +51,7 @@ private Q_SLOTS:
 
 private:
 
-    QComboBox* m_comboBox;
+    QComboBox* m_comboBox = nullptr;
 };
 
 } // namespace DigikamBqmFlipPlugin
-
-#endif // DIGIKAM_BQM_FLIP_H
