@@ -6,14 +6,13 @@
  * Date        : 2009-02-17
  * Description : resize image batch tool.
  *
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_RESIZE_H
-#define DIGIKAM_BQM_RESIZE_H
+#pragma once
 
 // Local includes
 
@@ -52,9 +51,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamBqmResizePlugin
-
-#endif // DIGIKAM_BQM_RESIZE_H
