@@ -6,14 +6,13 @@
  * Date        : 2018-07-30
  * Description : a BQM plugin to resize images.
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_RESIZE_PLUGIN_H
-#define DIGIKAM_RESIZE_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class ResizePlugin : public DPluginBqm
 public:
 
     explicit ResizePlugin(QObject* const parent = nullptr);
-    ~ResizePlugin()                      override;
+    ~ResizePlugin()                      override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -51,5 +50,3 @@ public:
 };
 
 } // namespace DigikamBqmResizePlugin
-
-#endif // DIGIKAM_RESIZE_PLUGIN_H
