@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_ROTATE_H
-#define DIGIKAM_BQM_ROTATE_H
+#pragma once
 
 // Local includes
 
@@ -51,9 +50,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamBqmRotatePlugin
-
-#endif // DIGIKAM_BQM_ROTATE_H
