@@ -6,14 +6,13 @@
  * Date        : 2019-10-02
  * Description : HEIF image export settings widget.
  *
- * SPDX-FileCopyrightText: 2020-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2020-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DIMG_HEIF_EXPORT_SETTINGS_H
-#define DIGIKAM_DIMG_HEIF_EXPORT_SETTINGS_H
+#pragma once
 
 // Local includes
 
@@ -46,9 +45,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_DIMG_HEIF_EXPORT_SETTINGS_H
