@@ -6,7 +6,7 @@
  * Date        : 2019-09-26
  * Description : A HEIF IO file for DImg framework
  *
- * SPDX-FileCopyrightText: 2019-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2019-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -18,7 +18,6 @@
 
 #include "digikam_config.h"
 #include "digikam_debug.h"
-#include "dimg.h"
 #include "dimgloaderobserver.h"
 
 namespace Digikam
@@ -26,13 +25,6 @@ namespace Digikam
 
 DImgHEIFLoader::DImgHEIFLoader(DImg* const image)
     : DImgLoader(image)
-{
-    m_hasAlpha   = false;
-    m_sixteenBit = false;
-    m_observer   = nullptr;
-}
-
-DImgHEIFLoader::~DImgHEIFLoader()
 {
 }
 
@@ -61,7 +53,7 @@ bool DImgHEIFLoader::isReadOnly() const
 
 }
 
-bool DImgHEIFLoader::isHeifSuccess(struct heif_error* const error)
+bool DImgHEIFLoader::isHeifSuccess(const struct heif_error* const error)
 {
     if (error->code == 0)
     {
