@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DIMG_HEIF_PLUGIN_H
-#define DIGIKAM_DIMG_HEIF_PLUGIN_H
+#pragma once
 
 // Qt includes
 
@@ -41,7 +40,7 @@ class DImgHEIFPlugin : public DPluginDImg
 public:
 
     explicit DImgHEIFPlugin(QObject* const parent = nullptr);
-    ~DImgHEIFPlugin()                                                                             override;
+    ~DImgHEIFPlugin()                                                                             override = default;
 
     QString name()                                                                          const override;
     QString iid()                                                                           const override;
@@ -68,5 +67,3 @@ public:
 };
 
 } // namespace DigikamHEIFDImgPlugin
-
-#endif // DIGIKAM_DIMG_HEIF_PLUGIN_H
