@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DIMG_JPEG_EXPORT_SETTINGS_H
-#define DIGIKAM_DIMG_JPEG_EXPORT_SETTINGS_H
+#pragma once
 
 // Local includes
 
@@ -42,9 +41,7 @@ public:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_DIMG_JPEG_EXPORT_SETTINGS_H
