@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DIMG_JPEG_PLUGIN_H
-#define DIGIKAM_DIMG_JPEG_PLUGIN_H
+#pragma once
 
 // Qt includes
 
@@ -42,7 +41,7 @@ class DImgJPEGPlugin : public DPluginDImg
 public:
 
     explicit DImgJPEGPlugin(QObject* const parent = nullptr);
-    ~DImgJPEGPlugin()                                                                             override;
+    ~DImgJPEGPlugin()                                                                             override = default;
 
     QString name()                                                                          const override;
     QString iid()                                                                           const override;
@@ -67,5 +66,3 @@ public:
 };
 
 } // namespace DigikamJPEGDImgPlugin
-
-#endif // DIGIKAM_DIMG_JPEG_PLUGIN_H
