@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DIMG_JPEG2000_EXPORT_SETTINGS_H
-#define DIGIKAM_DIMG_JPEG2000_EXPORT_SETTINGS_H
+#pragma once
 
 // Local includes
 
@@ -46,9 +45,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_DIMG_JPEG2000_EXPORT_SETTINGS_H
