@@ -6,7 +6,7 @@
  * Date        : 2006-06-14
  * Description : A JPEG-2000 IO file for DImg framework
  *
- * SPDX-FileCopyrightText: 2006-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * Others Linux JPEG-2000 Loader implementation:
  *    https://github.com/ImageMagick/ImageMagick/blob/master/coders/jp2.c
@@ -18,8 +18,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DIMG_JPEG_2000_LOADER_H
-#define DIGIKAM_DIMG_JPEG_2000_LOADER_H
+#pragma once
 
 // Local includes
 
@@ -37,7 +36,7 @@ class DImgJPEG2000Loader : public DImgLoader
 public:
 
     explicit DImgJPEG2000Loader(DImg* const image);
-    ~DImgJPEG2000Loader()                                                  override;
+    ~DImgJPEG2000Loader()                                                  override = default;
 
     bool load(const QString& filePath, DImgLoaderObserver* const observer) override;
     bool save(const QString& filePath, DImgLoaderObserver* const observer) override;
@@ -53,10 +52,8 @@ private:
 
 private:
 
-    bool m_sixteenBit;
-    bool m_hasAlpha;
+    bool m_sixteenBit = false;
+    bool m_hasAlpha   = false;
 };
 
 } // namespace DigikamJPEG2000DImgPlugin
-
-#endif // DIGIKAM_DIMG_JPEG_2000_LOADER_H
