@@ -12,54 +12,7 @@
  *
  * ============================================================ */
 
-#include "dimgjpeg2000loader.h"
-
-// Qt includes
-
-#include <QFile>
-#include <QByteArray>
-#include <QTextStream>
-
-// Local includes
-
-#include "dimg.h"
-#include "digikam_debug.h"
-#include "digikam_config.h"
-#include "dimgloaderobserver.h"
-#include "dmetadata.h"
-
-// Jasper includes
-
-#ifndef Q_CC_MSVC
-extern "C"
-{
-#endif
-
-#if !defined(Q_OS_DARWIN) && defined(Q_CC_GNU)
-#   pragma GCC diagnostic push
-#   pragma GCC diagnostic ignored "-Wcpp"
-#endif
-
-#if defined(Q_OS_DARWIN) && defined(Q_CC_CLANG)
-#   pragma clang diagnostic push
-#   pragma clang diagnostic ignored "-Wshift-negative-value"
-#endif
-
-#include <jasper/jasper.h>
-#include <jasper/jas_version.h>
-
-// Restore warnings
-#if !defined(Q_OS_DARWIN) && defined(Q_CC_GNU)
-#   pragma GCC diagnostic pop
-#endif
-
-#if defined(Q_OS_DARWIN) && defined(Q_CC_CLANG)
-#   pragma clang diagnostic pop
-#endif
-
-#ifndef Q_CC_MSVC
-}
-#endif
+#include "dimgjpeg2000loader_p.h"
 
 namespace DigikamJPEG2000DImgPlugin
 {
@@ -328,7 +281,7 @@ bool DImgJPEG2000Loader::save(const QString& filePath, DImgLoaderObserver* const
     // use sprintf for locale-aware string
 
     char rateBuffer[16];
-    sprintf(rateBuffer, "rate=%.2g", (quality / 100.0));
+    snprintf(rateBuffer, sizeof(rateBuffer), "rate=%.2g", (quality / 100.0));
 
     qCDebug(DIGIKAM_DIMG_LOG_JP2K) << "JPEG2000 quality: " << quality;
     qCDebug(DIGIKAM_DIMG_LOG_JP2K) << "JPEG2000 "          << rateBuffer;
