@@ -6,14 +6,13 @@
  * Date        : 2019-09-22
  * Description : JPEG-2000 DImg plugin.
  *
- * SPDX-FileCopyrightText: 2020-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2020-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DIMG_JPEG_2000_PLUGIN_H
-#define DIGIKAM_DIMG_JPEG_2000_PLUGIN_H
+#pragma once
 
 // Qt includes
 
@@ -67,9 +66,7 @@ public:
 
 private:
 
-    bool m_initJasper;
+    bool m_initJasper = false;
 };
 
 } // namespace DigikamJPEG2000DImgPlugin
-
-#endif // DIGIKAM_DIMG_JPEG_2000_PLUGIN_H
