@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DIMG_IMAGEMAGICK_LOADER_H
-#define DIGIKAM_DIMG_IMAGEMAGICK_LOADER_H
+#pragma once
 
 // Local includes
 
@@ -31,7 +30,7 @@ class DImgImageMagickLoader : public DImgLoader
 public:
 
     explicit DImgImageMagickLoader(DImg* const image);
-    ~DImgImageMagickLoader()                                               override;
+    ~DImgImageMagickLoader()                                               override = default;
 
     bool load(const QString& filePath, DImgLoaderObserver* const observer) override;
     bool save(const QString& filePath, DImgLoaderObserver* const observer) override;
@@ -42,10 +41,8 @@ public:
 
 private:
 
-    bool m_sixteenBit;
-    bool m_hasAlpha;
+    bool m_sixteenBit   = false;
+    bool m_hasAlpha     = false;
 };
 
 } // namespace DigikamImageMagickDImgPlugin
-
-#endif // DIGIKAM_DIMG_IMAGEMAGICK_LOADER_H
