@@ -50,7 +50,7 @@ using namespace MagickCore;
 #   pragma clang diagnostic pop
 #endif
 
-#if defined(Q_CC_GNU)
+#if !defined(Q_OS_DARWIN) && defined(Q_CC_GNU)
 #   pragma GCC diagnostic pop
 #endif
 
@@ -214,7 +214,7 @@ QString DImgImageMagickPlugin::typeMimes() const
 
     QString ret;
 
-    Q_FOREACH (const QString& str, formats)
+    for (const QString& str : std::as_const(formats))
     {
         if (!ret.contains(str))
         {
