@@ -30,6 +30,7 @@
 
 // Local includes
 
+#include "digikam_globals.h"
 #include "dnuminput.h"
 
 namespace Digikam
@@ -40,29 +41,24 @@ class Q_DECL_HIDDEN DImgPGFExportSettings::Private
 
 public:
 
-    explicit Private()
-      : PGFGrid            (nullptr),
-        labelPGFcompression(nullptr),
-        PGFLossLess        (nullptr),
-        PGFcompression     (nullptr)
-    {
-    }
+    Private() = default;
 
-    QGridLayout*  PGFGrid;
+public:
 
-    QLabel*       labelPGFcompression;
+    QGridLayout*  PGFGrid               = nullptr;
 
-    QCheckBox*    PGFLossLess;
+    QLabel*       labelPGFcompression   = nullptr;
 
-    DIntNumInput* PGFcompression;
+    QCheckBox*    PGFLossLess           = nullptr;
+
+    DIntNumInput* PGFcompression        = nullptr;
 };
 
 DImgPGFExportSettings::DImgPGFExportSettings(QWidget* const parent)
     : DImgLoaderSettings(parent),
       d                 (new Private)
 {
-    const int spacing = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
-                             QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
+    const int spacing = layoutSpacing();
 
     d->PGFGrid        = new QGridLayout(this);
     d->PGFLossLess    = new QCheckBox(i18n("Lossless PGF files"), this);
