@@ -19,12 +19,15 @@
 
 extern "C"
 {
+
 #ifndef Q_CC_MSVC
 #   include <unistd.h>
 #endif
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+
 }
 
 // C++ includes
@@ -38,8 +41,6 @@ extern "C"
 #include <QFile>
 #include <QVariant>
 #include <QByteArray>
-#include <QTextStream>
-#include <QDataStream>
 #include <qplatformdefs.h>
 
 // Windows includes
@@ -59,6 +60,7 @@ extern "C"
 #if defined(Q_CC_CLANG)
 #   pragma clang diagnostic push
 #   pragma clang diagnostic ignored "-Wkeyword-macro"
+#   pragma clang diagnostic ignored "-Wreorder-ctor"
 #endif
 
 #include "PGFimage.h"
@@ -83,14 +85,7 @@ namespace Digikam
 {
 
 DImgPGFLoader::DImgPGFLoader(DImg* const image)
-    : DImgLoader  (image),
-      m_sixteenBit(false),
-      m_hasAlpha  (false),
-      m_observer  (nullptr)
-{
-}
-
-DImgPGFLoader::~DImgPGFLoader()
+    : DImgLoader(image)
 {
 }
 
