@@ -6,14 +6,13 @@
  * Date        : 2019-09-22
  * Description : PGF DImg plugin.
  *
- * SPDX-FileCopyrightText: 2020-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2020-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DIMG_PGF_PLUGIN_H
-#define DIGIKAM_DIMG_PGF_PLUGIN_H
+#pragma once
 
 // Qt includes
 
@@ -42,7 +41,7 @@ class DImgPGFPlugin : public DPluginDImg
 public:
 
     explicit DImgPGFPlugin(QObject* const parent = nullptr);
-    ~DImgPGFPlugin()                                                                              override;
+    ~DImgPGFPlugin()                                                                              override = default;
 
     QString name()                                                                          const override;
     QString iid()                                                                           const override;
@@ -67,5 +66,3 @@ public:
 };
 
 } // namespace DigikamPGFDImgPlugin
-
-#endif // DIGIKAM_DIMG_PGF_PLUGIN_H
