@@ -6,14 +6,13 @@
  * Date        : 2005-11-01
  * Description : a PNG image loader for DImg framework.
  *
- * SPDX-FileCopyrightText: 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DIMG_PNG_LOADER_H
-#define DIGIKAM_DIMG_PNG_LOADER_H
+#pragma once
 
 // C++ includes
 
@@ -34,7 +33,7 @@ class DImgPNGLoader : public DImgLoader
 public:
 
     explicit DImgPNGLoader(DImg* const image);
-    ~DImgPNGLoader()                                                       override;
+    ~DImgPNGLoader()                                                       override = default;
 
     bool load(const QString& filePath, DImgLoaderObserver* const observer) override;
     bool save(const QString& filePath, DImgLoaderObserver* const observer) override;
@@ -45,10 +44,8 @@ public:
 
 private:
 
-    bool m_sixteenBit;
-    bool m_hasAlpha;
+    bool m_sixteenBit   = false;
+    bool m_hasAlpha     = false;
 };
 
 } // namespace DigikamPNGDImgPlugin
-
-#endif // DIGIKAM_DIMG_PNG_LOADER_H
