@@ -6,7 +6,7 @@
  * Date        : 2005-11-01
  * Description : a PNG image loader for DImg framework - load operations.
  *
- * SPDX-FileCopyrightText: 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -111,6 +111,7 @@ bool DImgPNGLoader::load(const QString& filePath, DImgLoaderObserver* const obse
     {
         qCWarning(DIGIKAM_DIMG_LOG_PNG) << "Cannot open image file.";
         loadingFailed();
+
         return false;
     }
 
@@ -127,10 +128,12 @@ bool DImgPNGLoader::load(const QString& filePath, DImgLoaderObserver* const obse
     if ((membersRead != PNG_BYTES_TO_CHECK) || !png_check_sig(buf, PNG_BYTES_TO_CHECK))
 
 #endif
+
     {
         qCWarning(DIGIKAM_DIMG_LOG_PNG) << "Not a PNG image file.";
         fclose(f);
         loadingFailed();
+
         return false;
     }
 
@@ -146,6 +149,7 @@ bool DImgPNGLoader::load(const QString& filePath, DImgLoaderObserver* const obse
         qCWarning(DIGIKAM_DIMG_LOG_PNG) << "Invalid PNG image file structure.";
         fclose(f);
         loadingFailed();
+
         return false;
     }
 
@@ -157,6 +161,7 @@ bool DImgPNGLoader::load(const QString& filePath, DImgLoaderObserver* const obse
         png_destroy_read_struct(&png_ptr, nullptr, nullptr);
         fclose(f);
         loadingFailed();
+
         return false;
     }
 
@@ -165,18 +170,13 @@ bool DImgPNGLoader::load(const QString& filePath, DImgLoaderObserver* const obse
     // will jump here
 
     // setjmp-save cleanup
+
     class Q_DECL_HIDDEN CleanupData
     {
 
     public:
 
-        CleanupData()
-          : data (nullptr),
-            lines(nullptr),
-            file (nullptr),
-            cmod (0)
-        {
-        }
+        CleanupData() = default;
 
         ~CleanupData()
         {
@@ -231,12 +231,12 @@ bool DImgPNGLoader::load(const QString& filePath, DImgLoaderObserver* const obse
 
     public:
 
-        uchar*  data;
-        uchar** lines;
-        FILE*   file;
+        uchar*  data    = nullptr;
+        uchar** lines   = { nullptr };
+        FILE*   file    = nullptr;
 
         QSize  size;
-        int    cmod;
+        int    cmod     = 0;
     };
 
     CleanupData* const cleanupData = new CleanupData;
@@ -251,15 +251,19 @@ bool DImgPNGLoader::load(const QString& filePath, DImgLoaderObserver* const obse
     if (setjmp(png_ptr->jmpbuf))
 
 #endif
+
     {
         png_destroy_read_struct(&png_ptr, &info_ptr, (png_infopp) nullptr);
 
-        if (!cleanupData->data ||
-            !cleanupData->size.isValid())
+        if (
+            !cleanupData->data ||
+            !cleanupData->size.isValid()
+           )
         {
             qCWarning(DIGIKAM_DIMG_LOG_PNG) << "Internal libPNG error during reading file. Process aborted!";
             delete cleanupData;
             loadingFailed();
+
             return false;
         }
 
@@ -285,6 +289,7 @@ bool DImgPNGLoader::load(const QString& filePath, DImgLoaderObserver* const obse
 
         cleanupData->takeData();
         delete cleanupData;
+
         return true;
     }
 
@@ -335,6 +340,7 @@ bool DImgPNGLoader::load(const QString& filePath, DImgLoaderObserver* const obse
         {
             m_hasAlpha = false;
             colorModel = DImg::RGB;
+
             break;
         }
 
@@ -342,6 +348,7 @@ bool DImgPNGLoader::load(const QString& filePath, DImgLoaderObserver* const obse
         {
             m_hasAlpha = true;
             colorModel = DImg::RGB;
+
             break;
         }
 
@@ -349,6 +356,7 @@ bool DImgPNGLoader::load(const QString& filePath, DImgLoaderObserver* const obse
         {
             m_hasAlpha = false;
             colorModel = DImg::GRAYSCALE;
+
             break;
         }
 
@@ -356,6 +364,7 @@ bool DImgPNGLoader::load(const QString& filePath, DImgLoaderObserver* const obse
         {
             m_hasAlpha = true;
             colorModel = DImg::GRAYSCALE;
+
             break;
         }
 
@@ -363,6 +372,7 @@ bool DImgPNGLoader::load(const QString& filePath, DImgLoaderObserver* const obse
         {
             m_hasAlpha = false;
             colorModel = DImg::INDEXED;
+
             break;
         }
     }
@@ -385,43 +395,41 @@ bool DImgPNGLoader::load(const QString& filePath, DImgLoaderObserver* const obse
 
             switch (color_type)
             {
-                case PNG_COLOR_TYPE_RGB :           // RGB
+                case PNG_COLOR_TYPE_RGB:           // RGB
                 {
                     qCDebug(DIGIKAM_DIMG_LOG_PNG) << "PNG in PNG_COLOR_TYPE_RGB";
-
                     png_set_add_alpha(png_ptr, 0xFFFF, PNG_FILLER_AFTER);
+
                     break;
                 }
 
-                case PNG_COLOR_TYPE_RGB_ALPHA :     // RGBA
+                case PNG_COLOR_TYPE_RGB_ALPHA:     // RGBA
                 {
                     qCDebug(DIGIKAM_DIMG_LOG_PNG) << "PNG in PNG_COLOR_TYPE_RGB_ALPHA";
+
                     break;
                 }
 
-                case PNG_COLOR_TYPE_GRAY :          // Grayscale
+                case PNG_COLOR_TYPE_GRAY:          // Grayscale
                 {
                     qCDebug(DIGIKAM_DIMG_LOG_PNG) << "PNG in PNG_COLOR_TYPE_GRAY";
-
                     png_set_gray_to_rgb(png_ptr);
                     png_set_add_alpha(png_ptr, 0xFFFF, PNG_FILLER_AFTER);
 
                     break;
                 }
 
-                case PNG_COLOR_TYPE_GRAY_ALPHA :    // Grayscale + Alpha
+                case PNG_COLOR_TYPE_GRAY_ALPHA:    // Grayscale + Alpha
                 {
                     qCDebug(DIGIKAM_DIMG_LOG_PNG) << "PNG in PNG_COLOR_TYPE_GRAY_ALPHA";
-
                     png_set_gray_to_rgb(png_ptr);
 
                     break;
                 }
 
-                case PNG_COLOR_TYPE_PALETTE :       // Indexed
+                case PNG_COLOR_TYPE_PALETTE:       // Indexed
                 {
                     qCDebug(DIGIKAM_DIMG_LOG_PNG) << "PNG in PNG_COLOR_TYPE_PALETTE";
-
                     png_set_palette_to_rgb(png_ptr);
                     png_set_add_alpha(png_ptr, 0xFFFF, PNG_FILLER_AFTER);
 
@@ -431,9 +439,9 @@ bool DImgPNGLoader::load(const QString& filePath, DImgLoaderObserver* const obse
                 default:
                 {
                     qCWarning(DIGIKAM_DIMG_LOG_PNG) << "PNG color type unknown.";
-
                     delete cleanupData;
                     loadingFailed();
+
                     return false;
                 }
             }
@@ -441,28 +449,26 @@ bool DImgPNGLoader::load(const QString& filePath, DImgLoaderObserver* const obse
         else
         {
             qCDebug(DIGIKAM_DIMG_LOG_PNG) << "PNG in >=8 bits/color/pixel.";
-
             png_set_packing(png_ptr);
 
             switch (color_type)
             {
-                case PNG_COLOR_TYPE_RGB :           // RGB
+                case PNG_COLOR_TYPE_RGB:           // RGB
                 {
                     qCDebug(DIGIKAM_DIMG_LOG_PNG) << "PNG in PNG_COLOR_TYPE_RGB";
-
                     png_set_add_alpha(png_ptr, 0xFF, PNG_FILLER_AFTER);
 
                     break;
                 }
 
-                case PNG_COLOR_TYPE_RGB_ALPHA :     // RGBA
+                case PNG_COLOR_TYPE_RGB_ALPHA:     // RGBA
                 {
                     qCDebug(DIGIKAM_DIMG_LOG_PNG) << "PNG in PNG_COLOR_TYPE_RGB_ALPHA";
 
                     break;
                 }
 
-                case PNG_COLOR_TYPE_GRAY :          // Grayscale
+                case PNG_COLOR_TYPE_GRAY:          // Grayscale
                 {
                     qCDebug(DIGIKAM_DIMG_LOG_PNG) << "PNG in PNG_COLOR_TYPE_GRAY";
 
@@ -482,18 +488,17 @@ bool DImgPNGLoader::load(const QString& filePath, DImgLoaderObserver* const obse
                     break;
                 }
 
-                case PNG_COLOR_TYPE_GRAY_ALPHA :    // Grayscale + alpha
+                case PNG_COLOR_TYPE_GRAY_ALPHA:    // Grayscale + alpha
                 {
                     qCDebug(DIGIKAM_DIMG_LOG_PNG) << "PNG in PNG_COLOR_TYPE_GRAY_ALPHA";
-
                     png_set_gray_to_rgb(png_ptr);
+
                     break;
                 }
 
-                case PNG_COLOR_TYPE_PALETTE :       // Indexed
+                case PNG_COLOR_TYPE_PALETTE:       // Indexed
                 {
                     qCDebug(DIGIKAM_DIMG_LOG_PNG) << "PNG in PNG_COLOR_TYPE_PALETTE";
-
                     png_set_packing(png_ptr);
                     png_set_palette_to_rgb(png_ptr);
                     png_set_add_alpha(png_ptr, 0xFF, PNG_FILLER_AFTER);
@@ -504,9 +509,9 @@ bool DImgPNGLoader::load(const QString& filePath, DImgLoaderObserver* const obse
                 default:
                 {
                     qCWarning(DIGIKAM_DIMG_LOG_PNG) << "PNG color type unknown." << color_type;
-
                     delete cleanupData;
                     loadingFailed();
+
                     return false;
                 }
             }
@@ -540,6 +545,7 @@ bool DImgPNGLoader::load(const QString& filePath, DImgLoaderObserver* const obse
 
         // Call before png_read_update_info and png_start_read_image()
         // for non-interlaced images number_passes will be 1
+
         int number_passes = png_set_interlace_handling(png_ptr);
 
         png_read_update_info(png_ptr, info_ptr);
@@ -567,6 +573,7 @@ bool DImgPNGLoader::load(const QString& filePath, DImgLoaderObserver* const obse
             png_destroy_read_struct(&png_ptr, &info_ptr, (png_infopp) nullptr);
             delete cleanupData;
             loadingFailed();
+
             return false;
         }
 
@@ -593,7 +600,7 @@ bool DImgPNGLoader::load(const QString& filePath, DImgLoaderObserver* const obse
 
             for (int y = 0 ; y < height ; ++y)
             {
-                if (observer && y == checkPoint)
+                if (observer && (y == checkPoint))
                 {
                     checkPoint += granularity(observer, height, 0.7F);
 
@@ -602,10 +609,12 @@ bool DImgPNGLoader::load(const QString& filePath, DImgLoaderObserver* const obse
                         png_destroy_read_struct(&png_ptr, &info_ptr, (png_infopp) nullptr);
                         delete cleanupData;
                         loadingFailed();
+
                         return false;
                     }
 
                     // use 10% - 80% for progress while reading rows
+
                     observer->progressInfo(0.1F + (0.7F * (((float)y) / ((float)height))));
                 }
 
@@ -702,9 +711,9 @@ bool DImgPNGLoader::load(const QString& filePath, DImgLoaderObserver* const obse
         {
             // Check if we have a Raw profile embedded using ImageMagick technique.
 
-            if (memcmp(text_ptr[i].key, "Raw profile type exif", 21) != 0 ||
-                memcmp(text_ptr[i].key, "Raw profile type APP1", 21) != 0 ||
-                memcmp(text_ptr[i].key, "Raw profile type iptc", 21) != 0)
+            if ((memcmp(text_ptr[i].key, "Raw profile type exif", 21) != 0) ||
+                (memcmp(text_ptr[i].key, "Raw profile type APP1", 21) != 0) ||
+                (memcmp(text_ptr[i].key, "Raw profile type iptc", 21) != 0))
             {
                 imageSetEmbbededText(QLatin1String(text_ptr[i].key), QLatin1String(text_ptr[i].text));
 
