@@ -6,7 +6,7 @@
  * Date        : 2019-09-22
  * Description : PNG DImg plugin.
  *
- * SPDX-FileCopyrightText: 2020-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2020-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -38,10 +38,6 @@ DImgPNGPlugin::DImgPNGPlugin(QObject* const parent)
 {
 }
 
-DImgPNGPlugin::~DImgPNGPlugin()
-{
-}
-
 QString DImgPNGPlugin::name() const
 {
     return i18nc("@title", "PNG loader");
@@ -93,7 +89,7 @@ QList<DPluginAuthor> DImgPNGPlugin::authors() const
     return QList<DPluginAuthor>()
             << DPluginAuthor(QString::fromUtf8("Gilles Caulier"),
                              QString::fromUtf8("caulier dot gilles at gmail dot com"),
-                             QString::fromUtf8("(C) 2005-2022"))
+                             QString::fromUtf8("(C) 2005-2024"))
             ;
 }
 
@@ -157,7 +153,7 @@ int DImgPNGPlugin::canRead(const QFileInfo& fileInfo, bool magic) const
         return 0;
     }
 
-    uchar pngID[8] = { 0x89, 0x50, 0x4E, 0x47, 0x0D, 0x0A, 0x1A, 0x0A };
+    const uchar pngID[8] = { 0x89, 0x50, 0x4E, 0x47, 0x0D, 0x0A, 0x1A, 0x0A };
 
     if (memcmp(header.data(), &pngID, 8) == 0)
     {
@@ -169,7 +165,7 @@ int DImgPNGPlugin::canRead(const QFileInfo& fileInfo, bool magic) const
 
 int DImgPNGPlugin::canWrite(const QString& format) const
 {
-    return typeMimes().contains(format.toUpper()) ? 10 : 0;
+    return (typeMimes().contains(format.toUpper()) ? 10 : 0);
 }
 
 DImgLoader* DImgPNGPlugin::loader(DImg* const image, const DRawDecoding&) const
@@ -188,3 +184,5 @@ DImgLoaderSettings* DImgPNGPlugin::exportWidget(const QString& format) const
 }
 
 } // namespace DigikamPNGDImgPlugin
+
+#include "moc_dimgpngplugin.cpp"
