@@ -6,7 +6,7 @@
  * Date        : 2022-04-04
  * Description : WEBP image export settings widget.
  *
- * SPDX-FileCopyrightText: 2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2022-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -30,6 +30,7 @@
 
 // Local includes
 
+#include "digikam_globals.h"
 #include "dnuminput.h"
 
 namespace Digikam
@@ -40,29 +41,22 @@ class Q_DECL_HIDDEN DImgWEBPExportSettings::Private
 
 public:
 
-    explicit Private()
-      : WEBPGrid            (nullptr),
-        labelWEBPcompression(nullptr),
-        WEBPLossLess        (nullptr),
-        WEBPcompression     (nullptr)
-    {
-    }
+    Private() = default;
 
-    QGridLayout*  WEBPGrid;
+    QGridLayout*  WEBPGrid              = nullptr;
 
-    QLabel*       labelWEBPcompression;
+    QLabel*       labelWEBPcompression  = nullptr;
 
-    QCheckBox*    WEBPLossLess;
+    QCheckBox*    WEBPLossLess          = nullptr;
 
-    DIntNumInput* WEBPcompression;
+    DIntNumInput* WEBPcompression       = nullptr;
 };
 
 DImgWEBPExportSettings::DImgWEBPExportSettings(QWidget* const parent)
     : DImgLoaderSettings(parent),
       d                 (new Private)
 {
-    const int spacing = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
-                             QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
+    const int spacing = layoutSpacing();
 
     d->WEBPGrid     = new QGridLayout(this);
     d->WEBPLossLess = new QCheckBox(i18n("Lossless WEBP files"), this);
