@@ -6,14 +6,13 @@
  * Date        : 2007-08-02
  * Description : TIFF image export settings widget.
  *
- * SPDX-FileCopyrightText: 2007-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DIMG_TIFF_EXPORT_SETTINGS_H
-#define DIGIKAM_DIMG_TIFF_EXPORT_SETTINGS_H
+#pragma once
 
 // Local includes
 
@@ -41,9 +40,7 @@ public:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_DIMG_TIFF_EXPORT_SETTINGS_H
