@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ADJUSTCURVESTOOL_PLUGIN_H
-#define DIGIKAM_ADJUSTCURVESTOOL_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class AdjustCurvesToolPlugin : public DPluginEditor
 public:
 
     explicit AdjustCurvesToolPlugin(QObject* const parent = nullptr);
-    ~AdjustCurvesToolPlugin()            override;
+    ~AdjustCurvesToolPlugin()            override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -55,5 +54,3 @@ private Q_SLOTS:
 };
 
 } // namespace DigikamEditorAdjustCurvesToolPlugin
-
-#endif // DIGIKAM_ADJUSTCURVESTOOL_PLUGIN_H
