@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ADJUSTLEVELSTOOL_PLUGIN_H
-#define DIGIKAM_ADJUSTLEVELSTOOL_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class AdjustLevelsToolPlugin : public DPluginEditor
 public:
 
     explicit AdjustLevelsToolPlugin(QObject* const parent = nullptr);
-    ~AdjustLevelsToolPlugin()            override;
+    ~AdjustLevelsToolPlugin()            override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -55,5 +54,3 @@ private Q_SLOTS:
 };
 
 } // namespace DigikamEditorAdjustLevelsToolPlugin
-
-#endif // DIGIKAM_ADJUSTLEVELSTOOL_PLUGIN_H
