@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_AUTO_CORRECTION_TOOL_H
-#define DIGIKAM_EDITOR_AUTO_CORRECTION_TOOL_H
+#pragma once
 
 // Qt includes
 
@@ -57,9 +56,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorAutoCorrectionToolPlugin
-
-#endif // DIGIKAM_EDITOR_AUTO_CORRECTION_TOOL_H
