@@ -8,14 +8,13 @@
  *               Contrast, and Gamma of picture.
  *
  * SPDX-FileCopyrightText: 2004      by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_BCG_TOOL_H
-#define DIGIKAM_EDITOR_BCG_TOOL_H
+#pragma once
 
 // Local includes
 
@@ -51,9 +50,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorBCGToolPlugin
-
-#endif // DIGIKAM_EDITOR_BCG_TOOL_H
