@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BCGTOOL_PLUGIN_H
-#define DIGIKAM_BCGTOOL_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class BCGToolPlugin : public DPluginEditor
 public:
 
     explicit BCGToolPlugin(QObject* const parent = nullptr);
-    ~BCGToolPlugin()                     override;
+    ~BCGToolPlugin()                     override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -55,5 +54,3 @@ private Q_SLOTS:
 };
 
 } // namespace DigikamEditorBCGToolPlugin
-
-#endif // DIGIKAM_BCGTOOL_PLUGIN_H
