@@ -7,14 +7,13 @@
  * Description : Black and White conversion tool.
  *
  * SPDX-FileCopyrightText: 2004-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_BW_SEPIA_TOOL_H
-#define DIGIKAM_EDITOR_BW_SEPIA_TOOL_H
+#pragma once
 
 // Local includes
 
@@ -54,9 +53,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorBWSepiaToolPlugin
-
-#endif // DIGIKAM_EDITOR_BW_SEPIA_TOOL_H
