@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_CHANNELMIXERTOOL_PLUGIN_H
-#define DIGIKAM_CHANNELMIXERTOOL_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class ChannelMixerToolPlugin : public DPluginEditor
 public:
 
     explicit ChannelMixerToolPlugin(QObject* const parent = nullptr);
-    ~ChannelMixerToolPlugin()            override;
+    ~ChannelMixerToolPlugin()            override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -55,5 +54,3 @@ private Q_SLOTS:
 };
 
 } // namespace DigikamEditorChannelMixerToolPlugin
-
-#endif // DIGIKAM_CHANNELMIXERTOOL_PLUGIN_H
