@@ -6,7 +6,7 @@
  * Date        : 2004-07-11
  * Description : digiKam image editor Color Balance tool.
  *
- * SPDX-FileCopyrightText: 2004-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -43,26 +43,17 @@ class Q_DECL_HIDDEN CBTool::Private
 {
 public:
 
-    explicit Private()
-      : cbSettings   (nullptr),
-        previewWidget(nullptr),
-        gboxSettings (nullptr)
-    {
-    }
+    Private() = default;
 
-    static const QString configGroupName;
-    static const QString configHistogramChannelEntry;
-    static const QString configHistogramScaleEntry;
+    const QString configGroupName               = QLatin1String("colorbalance Tool");
+    const QString configHistogramChannelEntry   = QLatin1String("Histogram Channel");
+    const QString configHistogramScaleEntry     = QLatin1String("Histogram Scale");
 
-    CBSettings*          cbSettings;
-    ImageRegionWidget*   previewWidget;
-    EditorToolSettings*  gboxSettings;
+    CBSettings*          cbSettings             = nullptr;
+    ImageRegionWidget*   previewWidget          = nullptr;
+    EditorToolSettings*  gboxSettings           = nullptr;
 };
 
-const QString CBTool::Private::configGroupName(QLatin1String("colorbalance Tool"));
-const QString CBTool::Private::configHistogramChannelEntry(QLatin1String("Histogram Channel"));
-const QString CBTool::Private::configHistogramScaleEntry(QLatin1String("Histogram Scale"));
-
 // --------------------------------------------------------
 
 CBTool::CBTool(QObject* const parent)
@@ -162,3 +153,5 @@ void CBTool::setFinalImage()
 }
 
 } // namespace DigikamEditorColorBalanceToolPlugin
+
+#include "moc_cbtool.cpp"
