@@ -6,14 +6,13 @@
  * Date        : 2004-07-11
  * Description : digiKam image editor Color Balance tool.
  *
- * SPDX-FileCopyrightText: 2004-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_CB_TOOL_H
-#define DIGIKAM_EDITOR_CB_TOOL_H
+#pragma once
 
 #include <QObject>
 
@@ -51,9 +50,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorColorBalanceToolPlugin
-
-#endif // DIGIKAM_EDITOR_CB_TOOL_H
