@@ -6,7 +6,7 @@
  * Date        : 2018-07-30
  * Description : image editor plugin to convert 16 bits color depth to 8.
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -36,10 +36,6 @@ Convert16To8ToolPlugin::Convert16To8ToolPlugin(QObject* const parent)
 {
 }
 
-Convert16To8ToolPlugin::~Convert16To8ToolPlugin()
-{
-}
-
 QString Convert16To8ToolPlugin::name() const
 {
     return i18nc("@title", "Convert to 8 bits");
@@ -85,7 +81,7 @@ QList<DPluginAuthor> Convert16To8ToolPlugin::authors() const
     return QList<DPluginAuthor>()
             << DPluginAuthor(QString::fromUtf8("Gilles Caulier"),
                              QString::fromUtf8("caulier dot gilles at gmail dot com"),
-                             QString::fromUtf8("(C) 2005-2021"))
+                             QString::fromUtf8("(C) 2005-2024"))
             ;
 }
 
@@ -134,3 +130,5 @@ void Convert16To8ToolPlugin::slotConvert16To8()
 }
 
 } // namespace DigikamEditorConvert16To8ToolPlugin
+
+#include "moc_convert16to8toolplugin.cpp"
