@@ -6,14 +6,13 @@
  * Date        : 2018-07-30
  * Description : image editor plugin to convert 16 bits color depth to 8.
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_CONVERT16TO8TOOL_PLUGIN_H
-#define DIGIKAM_CONVERT16TO8TOOL_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class Convert16To8ToolPlugin : public DPluginEditor
 public:
 
     explicit Convert16To8ToolPlugin(QObject* const parent = nullptr);
-    ~Convert16To8ToolPlugin()            override;
+    ~Convert16To8ToolPlugin()            override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -55,5 +54,3 @@ private Q_SLOTS:
 };
 
 } // namespace DigikamEditorConvert16To8ToolPlugin
-
-#endif // DIGIKAM_CONVERT16TO8TOOL_PLUGIN_H
