@@ -6,14 +6,13 @@
  * Date        : 2018-07-30
  * Description : image editor plugin to convert 8 bits color depth to 16.
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_CONVERT8TO16TOOL_PLUGIN_H
-#define DIGIKAM_CONVERT8TO16TOOL_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class Convert8To16ToolPlugin : public DPluginEditor
 public:
 
     explicit Convert8To16ToolPlugin(QObject* const parent = nullptr);
-    ~Convert8To16ToolPlugin()            override;
+    ~Convert8To16ToolPlugin()            override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -55,5 +54,3 @@ private Q_SLOTS:
 };
 
 } // namespace DigikamEditorConvert8To16ToolPlugin
-
-#endif // DIGIKAM_CONVERT8TO16TOOL_PLUGIN_H
