@@ -8,7 +8,7 @@
  *               image white balance
  *
  * SPDX-FileCopyrightText: 2008-2009 by Guillaume Castagnino <casta at xwing dot info>
- * SPDX-FileCopyrightText: 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -48,28 +48,19 @@ class Q_DECL_HIDDEN WhiteBalanceTool::Private
 {
 public:
 
-    explicit Private()
-      : settingsView (nullptr),
-        previewWidget(nullptr),
-        gboxSettings (nullptr)
-    {
-    }
+    Private() = default;
 
-    static const QString configGroupName;
-    static const QString configHistogramChannelEntry;
-    static const QString configHistogramScaleEntry;
+    const QString configGroupName              = QLatin1String("whitebalance Tool");
+    const QString configHistogramChannelEntry  = QLatin1String("Histogram Channel");
+    const QString configHistogramScaleEntry    = QLatin1String("Histogram Scale");
 
-    WBSettings*          settingsView;
+    WBSettings*          settingsView          = nullptr;
 
-    ImageRegionWidget*   previewWidget;
+    ImageRegionWidget*   previewWidget         = nullptr;
 
-    EditorToolSettings*  gboxSettings;
+    EditorToolSettings*  gboxSettings          = nullptr;
 };
 
-const QString WhiteBalanceTool::Private::configGroupName(QLatin1String("whitebalance Tool"));
-const QString WhiteBalanceTool::Private::configHistogramChannelEntry(QLatin1String("Histogram Channel"));
-const QString WhiteBalanceTool::Private::configHistogramScaleEntry(QLatin1String("Histogram Scale"));
-
 // --------------------------------------------------------
 
 WhiteBalanceTool::WhiteBalanceTool(QObject* const parent)
@@ -255,3 +246,5 @@ void WhiteBalanceTool::slotSaveAsSettings()
 }
 
 } // namespace DigikamEditorWhiteBalanceToolPlugin
+
+#include "moc_whitebalancetool.cpp"
