@@ -7,7 +7,7 @@
  * Description : a digiKam image tool to add a border
  *               around an image.
  *
- * SPDX-FileCopyrightText: 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -43,19 +43,13 @@ class Q_DECL_HIDDEN BorderTool::Private
 {
 public:
 
-    explicit Private()
-      : configGroupName(QLatin1String("border Tool")),
-        gboxSettings   (nullptr),
-        previewWidget  (nullptr),
-        settingsView   (nullptr)
-    {
-    }
+    Private() = default;
 
-    const QString       configGroupName;
+    const QString       configGroupName = QLatin1String("border Tool");
 
-    EditorToolSettings* gboxSettings;
-    ImageGuideWidget*   previewWidget;
-    BorderSettings*     settingsView;
+    EditorToolSettings* gboxSettings    = nullptr;
+    ImageGuideWidget*   previewWidget   = nullptr;
+    BorderSettings*     settingsView    = nullptr;
 };
 
 BorderTool::BorderTool(QObject* const parent)
@@ -163,3 +157,5 @@ void BorderTool::setFinalImage()
 }
 
 } // namespace DigikamEditorBorderToolPlugin
+
+#include "moc_bordertool.cpp"
