@@ -7,15 +7,14 @@
  * Description : a digiKam image tool to add a border
  *               around an image.
  *
- * SPDX-FileCopyrightText: 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_BORDER_TOOL_H
-#define DIGIKAM_EDITOR_BORDER_TOOL_H
+#pragma once
 
 // Qt includes
 
@@ -55,9 +54,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorBorderToolPlugin
-
-#endif // DIGIKAM_EDITOR_BORDER_TOOL_H
