@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BORDERTOOL_PLUGIN_H
-#define DIGIKAM_BORDERTOOL_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class BorderToolPlugin : public DPluginEditor
 public:
 
     explicit BorderToolPlugin(QObject* const parent = nullptr);
-    ~BorderToolPlugin()                  override;
+    ~BorderToolPlugin()                  override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -55,5 +54,3 @@ private Q_SLOTS:
 };
 
 } // namespace DigikamEditorBorderToolPlugin
-
-#endif // DIGIKAM_BORDERTOOL_PLUGIN_H
