@@ -6,15 +6,14 @@
  * Date        : 2005-02-14
  * Description : a tool to insert a text over an image.
  *
- * SPDX-FileCopyrightText: 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_INSERT_TEXT_TOOL_H
-#define DIGIKAM_EDITOR_INSERT_TEXT_TOOL_H
+#pragma once
 
 // Local includes
 
@@ -57,9 +56,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorInsertTextToolPlugin
-
-#endif // DIGIKAM_EDITOR_INSERT_TEXT_TOOL_H
