@@ -6,7 +6,7 @@
  * Date        : 2005-03-10
  * Description : a tool to apply texture over an image
  *
- * SPDX-FileCopyrightText: 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -44,19 +44,13 @@ class Q_DECL_HIDDEN TextureTool::Private
 {
 public:
 
-    explicit Private()
-      : configGroupName(QLatin1String("texture Tool")),
-        settingsView   (nullptr),
-        previewWidget  (nullptr),
-        gboxSettings   (nullptr)
-    {
-    }
+    Private() = default;
 
-    const QString       configGroupName;
+    const QString       configGroupName = QLatin1String("texture Tool");
 
-    TextureSettings*    settingsView;
-    ImageRegionWidget*  previewWidget;
-    EditorToolSettings* gboxSettings;
+    TextureSettings*    settingsView    = nullptr;
+    ImageRegionWidget*  previewWidget   = nullptr;
+    EditorToolSettings* gboxSettings    = nullptr;
 };
 
 // --------------------------------------------------------
@@ -139,3 +133,5 @@ void TextureTool::setFinalImage()
 }
 
 } // namespace DigikamEditorTextureToolPlugin
+
+#include "moc_texturetool.cpp"
