@@ -6,15 +6,14 @@
  * Date        : 2005-03-10
  * Description : a tool to apply texture over an image
  *
- * SPDX-FileCopyrightText: 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_TEXTURE_TOOL_H
-#define DIGIKAM_EDITOR_TEXTURE_TOOL_H
+#pragma once
 
 // Qt includes
 
@@ -54,9 +53,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorTextureToolPlugin
-
-#endif // DIGIKAM_EDITOR_TEXTURE_TOOL_H
