@@ -6,7 +6,7 @@
  * Date        : 2018-07-30
  * Description : image editor plugin to add texture
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -35,10 +35,6 @@ TextureToolPlugin::TextureToolPlugin(QObject* const parent)
 {
 }
 
-TextureToolPlugin::~TextureToolPlugin()
-{
-}
-
 QString TextureToolPlugin::name() const
 {
     return i18nc("@title", "Texture");
@@ -87,7 +83,7 @@ QList<DPluginAuthor> TextureToolPlugin::authors() const
                              QString::fromUtf8("(C) 2006-2010"))
             << DPluginAuthor(QString::fromUtf8("Gilles Caulier"),
                              QString::fromUtf8("caulier dot gilles at gmail dot com"),
-                             QString::fromUtf8("(C) 2005-2021"))
+                             QString::fromUtf8("(C) 2005-2024"))
             ;
 }
 
@@ -118,3 +114,5 @@ void TextureToolPlugin::slotTexture()
 }
 
 } // namespace DigikamEditorTextureToolPlugin
+
+#include "moc_texturetoolplugin.cpp"
