@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_BLUR_TOOL_H
-#define DIGIKAM_EDITOR_BLUR_TOOL_H
+#pragma once
 
 // Local includes
 
@@ -50,9 +49,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorBlurToolPlugin
-
-#endif // DIGIKAM_EDITOR_BLUR_TOOL_H
