@@ -14,8 +14,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_HOT_PIXELS_TOOL_H
-#define DIGIKAM_EDITOR_HOT_PIXELS_TOOL_H
+#pragma once
 
 // Qt includes
 
@@ -62,9 +61,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorHotPixelsToolPlugin
-
-#endif // DIGIKAM_EDITOR_HOT_PIXELS_TOOL_H
