@@ -4,7 +4,7 @@
  * Description : a tool to fix automatically camera lens aberrations
  *
  * SPDX-FileCopyrightText: 2008      by Adrian Schroeter <adrian at suse dot de>
- * SPDX-FileCopyrightText: 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -37,7 +37,6 @@
 #include "editortoolsettings.h"
 #include "imageiface.h"
 #include "imageguidewidget.h"
-#include "lensfuniface.h"
 #include "lensfunfilter.h"
 #include "lensfunsettings.h"
 #include "lensfuncameraselector.h"
@@ -50,30 +49,20 @@ class Q_DECL_HIDDEN LensAutoFixTool::Private
 {
 public:
 
-    explicit Private()
-      : configGroupName (QLatin1String("Lens Auto-Correction Tool")),
-        configShowGrid  (QLatin1String("Show Grid")),
-        maskPreviewLabel(nullptr),
-        showGrid        (nullptr),
-        settingsView    (nullptr),
-        cameraSelector  (nullptr),
-        previewWidget   (nullptr),
-        gboxSettings    (nullptr)
-    {
-    }
+    Private() = default;
 
-    const QString          configGroupName;
-    const QString          configShowGrid;
+    const QString          configGroupName  = QLatin1String("Lens Auto-Correction Tool");
+    const QString          configShowGrid   = QLatin1String("Show Grid");
 
-    QLabel*                maskPreviewLabel;
+    QLabel*                maskPreviewLabel = nullptr;
 
-    QCheckBox*             showGrid;
+    QCheckBox*             showGrid         = nullptr;
 
-    LensFunSettings*       settingsView;
-    LensFunCameraSelector* cameraSelector;
+    LensFunSettings*       settingsView     = nullptr;
+    LensFunCameraSelector* cameraSelector   = nullptr;
 
-    ImageGuideWidget*      previewWidget;
-    EditorToolSettings*    gboxSettings;
+    ImageGuideWidget*      previewWidget    = nullptr;
+    EditorToolSettings*    gboxSettings     = nullptr;
 };
 
 LensAutoFixTool::LensAutoFixTool(QObject* const parent)
@@ -98,8 +87,8 @@ LensAutoFixTool::LensAutoFixTool(QObject* const parent)
 
     // -------------------------------------------------------------
 
-    d->cameraSelector      = new LensFunCameraSelector(d->gboxSettings->plainPage());
-    DImg* const img        = d->previewWidget->imageIface()->original();
+    d->cameraSelector       = new LensFunCameraSelector(d->gboxSettings->plainPage());
+    DImg* const img         = d->previewWidget->imageIface()->original();
     d->cameraSelector->setMetadata(img->getMetadata());
     DLineWidget* const line = new DLineWidget(Qt::Horizontal, d->gboxSettings->plainPage());
 
@@ -140,10 +129,11 @@ LensAutoFixTool::~LensAutoFixTool()
 
 void LensAutoFixTool::slotLensChanged()
 {
-    d->settingsView->setEnabledCCA(d->cameraSelector->iface()->supportsCCA());
-    d->settingsView->setEnabledVig(d->cameraSelector->iface()->supportsVig());
-    d->settingsView->setEnabledDist(d->cameraSelector->iface()->supportsDistortion());
-    d->settingsView->setEnabledGeom(d->cameraSelector->iface()->supportsDistortion());
+    d->settingsView->setEnabledCCA(d->cameraSelector->supportsCCA());
+    d->settingsView->setEnabledVig(d->cameraSelector->supportsVig());
+    d->settingsView->setEnabledDist(d->cameraSelector->supportsDistortion());
+    d->settingsView->setEnabledGeom(d->cameraSelector->supportsGeometry());
+
     slotTimer();
 }
 
@@ -182,6 +172,7 @@ void LensAutoFixTool::slotResetSettings()
 void LensAutoFixTool::preparePreview()
 {
     // Settings information must be get before to disable settings view.
+
     LensFunContainer settings = d->cameraSelector->settings();
     d->settingsView->assignFilterSettings(settings);
     ImageIface* const iface   = d->previewWidget->imageIface();
@@ -205,10 +196,16 @@ void LensAutoFixTool::preparePreview()
         p2.end();
         DImg grid(pix.toImage());
 
+        if (preview.sixteenBit())
+        {
+            grid.convertDepth(64);
+        }
+
         DColorComposer* const composer            = DColorComposer::getComposer(DColorComposer::PorterDuffNone);
         DColorComposer::MultiplicationFlags flags = DColorComposer::NoMultiplication;
 
         // Do alpha blending of template on dest image
+
         preview.bitBlendImage(composer, &grid, 0, 0, preview.width(), preview.height(), 0, 0, flags);
 
         delete composer;
@@ -220,6 +217,7 @@ void LensAutoFixTool::preparePreview()
 void LensAutoFixTool::prepareFinal()
 {
     // Settings information must be handle before to disable settings view.
+
     LensFunContainer settings = d->cameraSelector->settings();
     d->settingsView->assignFilterSettings(settings);
     ImageIface iface;
@@ -241,6 +239,7 @@ void LensAutoFixTool::setFinalImage()
 
     // Note: there are certain situations in the editor where these metadata changes may be undone.
     // Ignore for now, as they are not critical.
+
     LensFunFilter* const fltr = dynamic_cast<LensFunFilter*>(filter());
 
     if (fltr)
@@ -252,3 +251,5 @@ void LensAutoFixTool::setFinalImage()
 }
 
 } // namespace DigikamEditorLensAutoFixToolPlugin
+
+#include "moc_lensautofixtool.cpp"
