@@ -6,7 +6,7 @@
  * Date        : 2018-07-30
  * Description : image editor plugin to reduce lens distortions
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -35,10 +35,6 @@ LensDistortionToolPlugin::LensDistortionToolPlugin(QObject* const parent)
 {
 }
 
-LensDistortionToolPlugin::~LensDistortionToolPlugin()
-{
-}
-
 QString LensDistortionToolPlugin::name() const
 {
     return i18nc("@title", "Lens Distortion");
@@ -87,7 +83,7 @@ QList<DPluginAuthor> LensDistortionToolPlugin::authors() const
                              QString::fromUtf8("(C) 2006-2010"))
             << DPluginAuthor(QString::fromUtf8("Gilles Caulier"),
                              QString::fromUtf8("caulier dot gilles at gmail dot com"),
-                             QString::fromUtf8("(C) 2004-2021"))
+                             QString::fromUtf8("(C) 2004-2024"))
             ;
 }
 
@@ -118,3 +114,5 @@ void LensDistortionToolPlugin::slotLensDistortion()
 }
 
 } // namespace DigikamEditorLensDistortionToolPlugin
+
+#include "moc_lensdistortiontoolplugin.cpp"
