@@ -7,14 +7,13 @@
  * Description : a tool to enhance image with local contrasts (as human eye does).
  *
  * SPDX-FileCopyrightText: 2009      by Julien Pontabry <julien dot pontabry at gmail dot com>
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_LOCAL_CONTRAST_TOOL_H
-#define DIGIKAM_EDITOR_LOCAL_CONTRAST_TOOL_H
+#pragma once
 
 // Local includes
 
@@ -52,9 +51,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorLocalContrastToolPlugin
-
-#endif // DIGIKAM_EDITOR_LOCAL_CONTRAST_TOOL_H
