@@ -6,14 +6,13 @@
  * Date        : 2004-08-24
  * Description : a tool to reduce CCD noise.
  *
- * SPDX-FileCopyrightText: 2004-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_NOISE_REDUCTION_TOOL_H
-#define DIGIKAM_EDITOR_NOISE_REDUCTION_TOOL_H
+#pragma once
 
 // Local includes
 
@@ -53,9 +52,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorNoiseReductionToolPlugin
-
-#endif // DIGIKAM_EDITOR_NOISE_REDUCTION_TOOL_H
