@@ -7,14 +7,13 @@
  * Description : Red eyes correction tool for image editor
  *
  * SPDX-FileCopyrightText: 2004-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2004-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_RED_EYE_TOOL_H
-#define DIGIKAM_EDITOR_RED_EYE_TOOL_H
+#pragma once
 
 // Local includes
 
@@ -51,9 +50,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorRedEyeToolPlugin
-
-#endif // DIGIKAM_EDITOR_RED_EYE_TOOL_H
