@@ -6,7 +6,7 @@
  * Date        : 2018-07-30
  * Description : image editor plugin to restore an image
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -35,10 +35,6 @@ RedEyeToolPlugin::RedEyeToolPlugin(QObject* const parent)
 {
 }
 
-RedEyeToolPlugin::~RedEyeToolPlugin()
-{
-}
-
 QString RedEyeToolPlugin::name() const
 {
     return i18nc("@title", "Red Eye");
@@ -92,7 +88,7 @@ QList<DPluginAuthor> RedEyeToolPlugin::authors() const
 
             << DPluginAuthor(QString::fromUtf8("Gilles Caulier"),
                              QString::fromUtf8("caulier dot gilles at gmail dot com"),
-                             QString::fromUtf8("(C) 2005-2021"))
+                             QString::fromUtf8("(C) 2005-2024"))
             ;
 }
 
@@ -125,3 +121,5 @@ void RedEyeToolPlugin::slotRedEye()
 }
 
 } // namespace DigikamEditorRedEyeToolPlugin
+
+#include "moc_redeyetoolplugin.cpp"
