@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_RESTORATION_TOOL_H
-#define DIGIKAM_EDITOR_RESTORATION_TOOL_H
+#pragma once
 
 // Local includes
 
@@ -53,9 +52,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorRestorationToolPlugin
-
-#endif // DIGIKAM_EDITOR_RESTORATION_TOOL_H
