@@ -6,7 +6,7 @@
  * Date        : 2018-07-30
  * Description : image editor plugin to restore an image
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -35,10 +35,6 @@ RestoreToolPlugin::RestoreToolPlugin(QObject* const parent)
 {
 }
 
-RestoreToolPlugin::~RestoreToolPlugin()
-{
-}
-
 QString RestoreToolPlugin::name() const
 {
     return i18nc("@title", "Restoration");
@@ -84,7 +80,7 @@ QList<DPluginAuthor> RestoreToolPlugin::authors() const
     return QList<DPluginAuthor>()
             << DPluginAuthor(QString::fromUtf8("Gilles Caulier"),
                              QString::fromUtf8("caulier dot gilles at gmail dot com"),
-                             QString::fromUtf8("(C) 2005-2021"))
+                             QString::fromUtf8("(C) 2005-2024"))
             ;
 }
 
@@ -115,3 +111,5 @@ void RestoreToolPlugin::slotRestore()
 }
 
 } // namespace DigikamEditorRestorationToolPlugin
+
+#include "moc_restorationtoolplugin.cpp"
