@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_SHARPEN_TOOL_H
-#define DIGIKAM_EDITOR_SHARPEN_TOOL_H
+#pragma once
 
 // Local includes
 
@@ -53,9 +52,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorSharpenToolPlugin
-
-#endif // DIGIKAM_EDITOR_SHARPEN_TOOL_H
