@@ -7,7 +7,7 @@
  * Description : image editor printing interface.
  *
  * SPDX-FileCopyrightText: 2009      by Angelo Naselli <anaselli at linux dot it>
- * SPDX-FileCopyrightText: 2009-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -25,19 +25,16 @@ namespace DigikamEditorPrintToolPlugin
 
 class Q_DECL_HIDDEN PrintConfigHelper
 {
-    public:
+public:
 
-        PrintConfigHelper()
-            : q(nullptr)
-        {
-        }
+    PrintConfigHelper() = default;
 
-        ~PrintConfigHelper()
-        {
-            delete q;
-        }
+    ~PrintConfigHelper()
+    {
+        delete q;
+    }
 
-        PrintConfig* q;
+    PrintConfig* q = nullptr;
 };
 
 Q_GLOBAL_STATIC(PrintConfigHelper, s_globalPrintConfig)
@@ -155,3 +152,5 @@ PrintConfig::~PrintConfig()
 }
 
 } // namespace DigikamEditorPrintToolPlugin
+
+#include "moc_printconfig.cpp"
