@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_PRINT_CONFIG_H
-#define DIGIKAM_PRINT_CONFIG_H
+#pragma once
 
 // Qt includes
 
@@ -168,19 +167,17 @@ private:
 
 private:
 
-    int    mPrintPosition;
-    int    mPrintScaleMode;
-    bool   mPrintEnlargeSmallerImages;
-    double mPrintWidth;
-    double mPrintHeight;
-    int    mPrintUnit;
-    bool   mPrintKeepRatio;
-    bool   mPrintColorManaged;
-    bool   mPrintAutoRotate;
+    int    mPrintPosition               = Qt::AlignHCenter | Qt::AlignVCenter;
+    int    mPrintScaleMode              = PrintOptionsPage::ScaleToPage;
+    bool   mPrintEnlargeSmallerImages   = false;
+    double mPrintWidth                  = 15.0;
+    double mPrintHeight                 = 10.0;
+    int    mPrintUnit                   = PrintOptionsPage::Centimeters;
+    bool   mPrintKeepRatio              = true;
+    bool   mPrintColorManaged           = false;
+    bool   mPrintAutoRotate             = false;
 
     friend class PrintConfigHelper;
 };
 
 } // namespace DigikamEditorPrintToolPlugin
-
-#endif // DIGIKAM_PRINT_CONFIG_H
