@@ -7,14 +7,13 @@
  * Description : image editor printing interface.
  *
  * SPDX-FileCopyrightText: 2009      by Angelo Naselli <anaselli at linux dot it>
- * SPDX-FileCopyrightText: 2009-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_PRINT_HELPER_H
-#define DIGIKAM_PRINT_HELPER_H
+#pragma once
 
 // Local includes
 
@@ -46,9 +45,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorPrintToolPlugin
-
-#endif // DIGIKAM_PRINT_HELPER_H
