@@ -7,7 +7,7 @@
  * Description : image editor printing interface.
  *
  * SPDX-FileCopyrightText: 2009      by Angelo Naselli <anaselli at linux dot it>
- * SPDX-FileCopyrightText: 2009-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -63,24 +63,17 @@ class Q_DECL_HIDDEN PrintOptionsPage::Private : public Ui_PrintOptionsPage
 {
 public:
 
-    explicit Private()
-      : parent              (nullptr),
-        configDialogManager (nullptr),
-        colorManaged        (nullptr),
-        cmPreferences       (nullptr),
-        cmEnabled           (false)
-    {
-    }
+    Private() = default;
 
-    QWidget*        parent;
+    QWidget*        parent              = nullptr;
     QSize           imageSize;
     QButtonGroup    scaleGroup;
     QButtonGroup    positionGroup;
-    DConfigDlgMngr* configDialogManager;
+    DConfigDlgMngr* configDialogManager = nullptr;
     IccProfile      outputProfile;
-    QCheckBox*      colorManaged;
-    QPushButton*    cmPreferences;
-    bool            cmEnabled;
+    QCheckBox*      colorManaged        = nullptr;
+    QPushButton*    cmPreferences       = nullptr;
+    bool            cmEnabled           = false;
 
 public:
 
@@ -355,3 +348,5 @@ void PrintOptionsPage::slotSetupDlg()
 }
 
 } // namespace DigiKam
+
+#include "moc_printoptionspage.cpp"
