@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_PRINT_OPTIONS_PAGE_H
-#define DIGIKAM_PRINT_OPTIONS_PAGE_H
+#pragma once
 
 // Qt includes
 
@@ -81,9 +80,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorPrintToolPlugin
-
-#endif // DIGIKAM_PRINT_OPTIONS_PAGE_H
