@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_PRINT_PLUGIN_H
-#define DIGIKAM_PRINT_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class PrintToolPlugin : public DPluginEditor
 public:
 
     explicit PrintToolPlugin(QObject* const parent = nullptr);
-    ~PrintToolPlugin()                   override;
+    ~PrintToolPlugin()                   override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -55,5 +54,3 @@ private Q_SLOTS:
 };
 
 } // namespace DigikamEditorPrintToolPlugin
-
-#endif // DIGIKAM_PRINT_PLUGIN_H
