@@ -6,15 +6,14 @@
  * Date        : 2005-02-09
  * Description : a tool to apply Blur FX to images
  *
- * SPDX-FileCopyrightText: 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_BLUR_FX_TOOL_H
-#define DIGIKAM_EDITOR_BLUR_FX_TOOL_H
+#pragma once
 
 // Local includes
 
@@ -53,9 +52,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorBlurFxToolPlugin
-
-#endif // DIGIKAM_EDITOR_BLUR_FX_TOOL_H
