@@ -6,14 +6,13 @@
  * Date        : 2018-07-30
  * Description : image editor plugin to apply blur effects.
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BLURFXTOOL_PLUGIN_H
-#define DIGIKAM_BLURFXTOOL_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class BlurFXToolPlugin : public DPluginEditor
 public:
 
     explicit BlurFXToolPlugin(QObject* const parent = nullptr);
-    ~BlurFXToolPlugin()                  override;
+    ~BlurFXToolPlugin()                  override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -55,5 +54,3 @@ private Q_SLOTS:
 };
 
 } // namespace DigikamEditorBlurFxToolPlugin
-
-#endif // DIGIKAM_BLURFXTOOL_PLUGIN_H
