@@ -7,7 +7,7 @@
  * Description : a digikam image editor tool to
  *               simulate charcoal drawing.
  *
- * SPDX-FileCopyrightText: 2004-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -43,29 +43,19 @@ class Q_DECL_HIDDEN CharcoalTool::Private
 {
 public:
 
-    explicit Private()
-      : pencilInput  (nullptr),
-        smoothInput  (nullptr),
-        previewWidget(nullptr),
-        gboxSettings (nullptr)
-    {
-    }
+    Private() = default;
 
-    static const QString configGroupName;
-    static const QString configPencilAdjustmentEntry;
-    static const QString configSmoothAdjustmentEntry;
+    const QString configGroupName               = QLatin1String("charcoal Tool");
+    const QString configPencilAdjustmentEntry   = QLatin1String("PencilAdjustment");
+    const QString configSmoothAdjustmentEntry   = QLatin1String("SmoothAdjustment");
 
-    DIntNumInput*        pencilInput;
-    DIntNumInput*        smoothInput;
+    DIntNumInput*        pencilInput            = nullptr;
+    DIntNumInput*        smoothInput            = nullptr;
 
-    ImageRegionWidget*   previewWidget;
-    EditorToolSettings*  gboxSettings;
+    ImageRegionWidget*   previewWidget          = nullptr;
+    EditorToolSettings*  gboxSettings           = nullptr;
 };
 
-const QString CharcoalTool::Private::configGroupName(QLatin1String("charcoal Tool"));
-const QString CharcoalTool::Private::configPencilAdjustmentEntry(QLatin1String("PencilAdjustment"));
-const QString CharcoalTool::Private::configSmoothAdjustmentEntry(QLatin1String("SmoothAdjustment"));
-
 // --------------------------------------------------------
 
 CharcoalTool::CharcoalTool(QObject* const parent)
@@ -190,3 +180,5 @@ void CharcoalTool::setFinalImage()
 }
 
 } // namespace DigikamEditorCharcoalToolPlugin
+
+#include "moc_charcoaltool.cpp"
