@@ -6,7 +6,7 @@
  * Date        : 2018-07-30
  * Description : image editor plugin to emulate charcoal drawing.
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -35,10 +35,6 @@ CharcoalToolPlugin::CharcoalToolPlugin(QObject* const parent)
 {
 }
 
-CharcoalToolPlugin::~CharcoalToolPlugin()
-{
-}
-
 QString CharcoalToolPlugin::name() const
 {
     return i18nc("@title", "Charcoal Drawing");
@@ -84,7 +80,7 @@ QList<DPluginAuthor> CharcoalToolPlugin::authors() const
     return QList<DPluginAuthor>()
             << DPluginAuthor(QString::fromUtf8("Gilles Caulier"),
                              QString::fromUtf8("caulier dot gilles at gmail dot com"),
-                             QString::fromUtf8("(C) 2004-2021"))
+                             QString::fromUtf8("(C) 2004-2024"))
             ;
 }
 
@@ -115,3 +111,5 @@ void CharcoalToolPlugin::slotCharcoal()
 }
 
 } // namespace DigikamEditorCharcoalToolPlugin
+
+#include "moc_charcoaltoolplugin.cpp"
