@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_CHARCOALTOOL_PLUGIN_H
-#define DIGIKAM_CHARCOALTOOL_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class CharcoalToolPlugin : public DPluginEditor
 public:
 
     explicit CharcoalToolPlugin(QObject* const parent = nullptr);
-    ~CharcoalToolPlugin()                override;
+    ~CharcoalToolPlugin()                override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -55,5 +54,3 @@ private Q_SLOTS:
 };
 
 } // namespace DigikamEditorCharcoalToolPlugin
-
-#endif // DIGIKAM_CHARCOALTOOL_PLUGIN_H
