@@ -6,7 +6,7 @@
  * Date        : 2005-02-11
  * Description : a tool to apply Distortion FX to an image.
  *
- * SPDX-FileCopyrightText: 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * Original Distortion algorithms copyrighted 2004-2005 by
@@ -16,8 +16,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_DISTORTION_FX_TOOL_H
-#define DIGIKAM_EDITOR_DISTORTION_FX_TOOL_H
+#pragma once
 
 // Local includes
 
@@ -56,9 +55,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorDistortionFxToolPlugin
-
-#endif // DIGIKAM_EDITOR_DISTORTION_FX_TOOL_H
