@@ -7,7 +7,7 @@
  * Description : a digiKam image editor tool to emboss
  *               an image.
  *
- * SPDX-FileCopyrightText: 2004-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -43,24 +43,16 @@ class Q_DECL_HIDDEN EmbossTool::Private
 {
 public:
 
-    explicit Private()
-      : depthInput   (nullptr),
-        previewWidget(nullptr),
-        gboxSettings (nullptr)
-    {
-    }
+    Private() = default;
 
-    static const QString configGroupName;
-    static const QString configDepthAdjustmentEntry;
+    const QString configGroupName               = QLatin1String("emboss Tool");
+    const QString configDepthAdjustmentEntry    = QLatin1String("DepthAdjustment");
 
-    DIntNumInput*        depthInput;
-    ImageRegionWidget*   previewWidget;
-    EditorToolSettings*  gboxSettings;
+    DIntNumInput*        depthInput             = nullptr;
+    ImageRegionWidget*   previewWidget          = nullptr;
+    EditorToolSettings*  gboxSettings           = nullptr;
 };
 
-const QString EmbossTool::Private::configGroupName(QLatin1String("emboss Tool"));
-const QString EmbossTool::Private::configDepthAdjustmentEntry(QLatin1String("DepthAdjustment"));
-
 // --------------------------------------------------------
 
 EmbossTool::EmbossTool(QObject* const parent)
@@ -168,3 +160,5 @@ void EmbossTool::setFinalImage()
 }
 
 } // namespace DigikamEditorEmbossToolPlugin
+
+#include "moc_embosstool.cpp"
