@@ -14,8 +14,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_EMBOSS_TOOL_H
-#define DIGIKAM_EDITOR_EMBOSS_TOOL_H
+#pragma once
 
 // Local includes
 
@@ -51,9 +50,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorEmbossToolPlugin
-
-#endif // DIGIKAM_EDITOR_EMBOSS_TOOL_H
