@@ -7,15 +7,14 @@
  * Description : a digiKam image editor tool for add film
  *               grain on an image.
  *
- * SPDX-FileCopyrightText: 2004-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_FILM_GRAIN_TOOL_H
-#define DIGIKAM_EDITOR_FILM_GRAIN_TOOL_H
+#pragma once
 
 // Local includes
 
@@ -52,9 +51,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorFilmGrainToolPlugin
-
-#endif // DIGIKAM_EDITOR_FILM_GRAIN_TOOL_H
