@@ -6,7 +6,7 @@
  * Date        : 2018-07-30
  * Description : image editor plugin to add film grain over an image.
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -35,10 +35,6 @@ FilmGrainToolPlugin::FilmGrainToolPlugin(QObject* const parent)
 {
 }
 
-FilmGrainToolPlugin::~FilmGrainToolPlugin()
-{
-}
-
 QString FilmGrainToolPlugin::name() const
 {
     return i18nc("@title", "Film Grain");
@@ -87,7 +83,7 @@ QList<DPluginAuthor> FilmGrainToolPlugin::authors() const
                              QString::fromUtf8("(C) 2006-2012"))
             << DPluginAuthor(QString::fromUtf8("Gilles Caulier"),
                              QString::fromUtf8("caulier dot gilles at gmail dot com"),
-                             QString::fromUtf8("(C) 2004-2021"))
+                             QString::fromUtf8("(C) 2004-2024"))
             ;
 }
 
@@ -118,3 +114,5 @@ void FilmGrainToolPlugin::slotFilmGrain()
 }
 
 } // namespace DigikamEditorFilmGrainToolPlugin
+
+#include "moc_filmgraintoolplugin.cpp"
