@@ -6,15 +6,14 @@
  * Date        : 2004-08-25
  * Description : a tool to simulate Oil Painting
  *
- * SPDX-FileCopyrightText: 2004-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_OIL_PAINT_TOOL_H
-#define DIGIKAM_EDITOR_OIL_PAINT_TOOL_H
+#pragma once
 
 // Local includes
 
@@ -50,9 +49,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorOilPaintToolPlugin
-
-#endif // DIGIKAM_EDITOR_OIL_PAINT_TOOL_H
