@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_RAIN_DROP_TOOL_H
-#define DIGIKAM_EDITOR_RAIN_DROP_TOOL_H
+#pragma once
 
 // Local includes
 
@@ -52,9 +51,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorRainDropToolPlugin
-
-#endif // DIGIKAM_EDITOR_RAIN_DROP_TOOL_H
