@@ -6,7 +6,7 @@
  * Date        : 2018-07-30
  * Description : image editor plugin to auto-crop an image.
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -35,10 +35,6 @@ AutoCropToolPlugin::AutoCropToolPlugin(QObject* const parent)
 {
 }
 
-AutoCropToolPlugin::~AutoCropToolPlugin()
-{
-}
-
 QString AutoCropToolPlugin::name() const
 {
     return i18nc("@title", "Auto-Crop");
@@ -88,7 +84,7 @@ QList<DPluginAuthor> AutoCropToolPlugin::authors() const
                              QString::fromUtf8("(C) 2013"))
             << DPluginAuthor(QString::fromUtf8("Gilles Caulier"),
                              QString::fromUtf8("caulier dot gilles at gmail dot com"),
-                             QString::fromUtf8("(C) 2013-2021"))
+                             QString::fromUtf8("(C) 2013-2024"))
             ;
 }
 
@@ -122,3 +118,5 @@ void AutoCropToolPlugin::slotAutoCrop()
 }
 
 } // namespace DigikamEditorAutoCropToolPlugin
+
+#include "moc_autocroptoolplugin.cpp"
