@@ -7,14 +7,13 @@
  * Description : Content aware resizing tool.
  *
  * SPDX-FileCopyrightText: 2009      by Julien Pontabry <julien dot pontabry at ulp dot u-strasbg dot fr>
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_CONTENT_AWARE_RESIZE_TOOL_H
-#define DIGIKAM_EDITOR_CONTENT_AWARE_RESIZE_TOOL_H
+#pragma once
 
 // Local includes
 
@@ -66,9 +65,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorContentAwareResizeToolPlugin
-
-#endif // DIGIKAM_EDITOR_CONTENT_AWARE_RESIZE_TOOL_H
