@@ -6,7 +6,7 @@
  * Date        : 2018-07-30
  * Description : image editor plugin to resize an image with content analysis
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -35,10 +35,6 @@ ContentAwareResizeToolPlugin::ContentAwareResizeToolPlugin(QObject* const parent
 {
 }
 
-ContentAwareResizeToolPlugin::~ContentAwareResizeToolPlugin()
-{
-}
-
 QString ContentAwareResizeToolPlugin::name() const
 {
     return i18nc("@title", "Liquid Rescale");
@@ -90,7 +86,7 @@ QList<DPluginAuthor> ContentAwareResizeToolPlugin::authors() const
                              QString::fromUtf8("(C) 2009-2010"))
             << DPluginAuthor(QString::fromUtf8("Gilles Caulier"),
                              QString::fromUtf8("caulier dot gilles at gmail dot com"),
-                             QString::fromUtf8("(C) 2009-2021"))
+                             QString::fromUtf8("(C) 2009-2024"))
             ;
 }
 
@@ -121,3 +117,5 @@ void ContentAwareResizeToolPlugin::slotContentAwareResize()
 }
 
 } // namespace DigikamEditorContentAwareResizeToolPlugin
+
+#include "moc_contentawareresizetoolplugin.cpp"
