@@ -14,8 +14,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_FREE_ROTATION_TOOL_H
-#define DIGIKAM_EDITOR_FREE_ROTATION_TOOL_H
+#pragma once
 
 // Local includes
 
@@ -71,9 +70,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorFreeRotationToolPlugin
-
-#endif // DIGIKAM_EDITOR_FREE_ROTATION_TOOL_H
