@@ -14,8 +14,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_PERSPECTIVE_MATRIX_H
-#define DIGIKAM_EDITOR_PERSPECTIVE_MATRIX_H
+#pragma once
 
 namespace DigikamEditorPerspectiveToolPlugin
 {
@@ -29,7 +28,7 @@ public:
      *
      * Initializes matrix to the identity matrix.
      */
-    explicit PerspectiveMatrix();
+    PerspectiveMatrix();
 
     /**
      * translate:
@@ -91,9 +90,7 @@ public:
      *
      * The 3x3 matrix data
      */
-    double coeff[3][3];
+    double coeff[3][3] = { { 0.0 } };
 };
 
 } // namespace DigikamEditorPerspectiveToolPlugin
-
-#endif // DIGIKAM_EDITOR_PERSPECTIVE_MATRIX_H
