@@ -4,9 +4,9 @@
  * https://www.digikam.org
  *
  * Date        : 2005-02-17
- * Description : a tool to change image perspective .
+ * Description : a tool to change image perspective.
  *
- * SPDX-FileCopyrightText: 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -48,46 +48,28 @@ class Q_DECL_HIDDEN PerspectiveTool::Private
 {
 public:
 
-    explicit Private()
-      : newWidthLabel           (nullptr),
-        newHeightLabel          (nullptr),
-        topLeftAngleLabel       (nullptr),
-        topRightAngleLabel      (nullptr),
-        bottomLeftAngleLabel    (nullptr),
-        bottomRightAngleLabel   (nullptr),
-        drawWhileMovingCheckBox (nullptr),
-        drawGridCheckBox        (nullptr),
-        inverseTransformation   (nullptr),
-        previewWidget           (nullptr),
-        gboxSettings            (nullptr)
-    {
-    }
+    Private() = default;
 
-    static const QString configGroupName;
-    static const QString configDrawWhileMovingEntry;
-    static const QString configDrawGridEntry;
-    static const QString configInverseTransformationEntry;
+    const QString configGroupName                   = QLatin1String("perspective Tool");
+    const QString configDrawWhileMovingEntry        = QLatin1String("Draw While Moving");
+    const QString configDrawGridEntry               = QLatin1String("Draw Grid");
+    const QString configInverseTransformationEntry  = QLatin1String("Inverse Transformation");
 
-    QLabel*              newWidthLabel;
-    QLabel*              newHeightLabel;
-    QLabel*              topLeftAngleLabel;
-    QLabel*              topRightAngleLabel;
-    QLabel*              bottomLeftAngleLabel;
-    QLabel*              bottomRightAngleLabel;
+    QLabel*              newWidthLabel              = nullptr;
+    QLabel*              newHeightLabel             = nullptr;
+    QLabel*              topLeftAngleLabel          = nullptr;
+    QLabel*              topRightAngleLabel         = nullptr;
+    QLabel*              bottomLeftAngleLabel       = nullptr;
+    QLabel*              bottomRightAngleLabel      = nullptr;
 
-    QCheckBox*           drawWhileMovingCheckBox;
-    QCheckBox*           drawGridCheckBox;
-    QCheckBox*           inverseTransformation;
+    QCheckBox*           drawWhileMovingCheckBox    = nullptr;
+    QCheckBox*           drawGridCheckBox           = nullptr;
+    QCheckBox*           inverseTransformation      = nullptr;
 
-    PerspectiveWidget*   previewWidget;
-    EditorToolSettings*  gboxSettings;
+    PerspectiveWidget*   previewWidget              = nullptr;
+    EditorToolSettings*  gboxSettings               = nullptr;
 };
 
-const QString PerspectiveTool::Private::configGroupName(QLatin1String("perspective Tool"));
-const QString PerspectiveTool::Private::configDrawWhileMovingEntry(QLatin1String("Draw While Moving"));
-const QString PerspectiveTool::Private::configDrawGridEntry(QLatin1String("Draw Grid"));
-const QString PerspectiveTool::Private::configInverseTransformationEntry(QLatin1String("Inverse Transformation"));
-
 // --------------------------------------------------------
 
 PerspectiveTool::PerspectiveTool(QObject* const parent)
@@ -273,3 +255,5 @@ void PerspectiveTool::setBackgroundColor(const QColor& bg)
 }
 
 } // namespace DigikamEditorPerspectiveToolPlugin
+
+#include "moc_perspectivetool.cpp"
