@@ -6,14 +6,13 @@
  * Date        : 2018-07-30
  * Description : image editor plugin to adjust perspective.
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_PERSPECTIVETOOL_PLUGIN_H
-#define DIGIKAM_PERSPECTIVETOOL_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class PerspectiveToolPlugin : public DPluginEditor
 public:
 
     explicit PerspectiveToolPlugin(QObject* const parent = nullptr);
-    ~PerspectiveToolPlugin()             override;
+    ~PerspectiveToolPlugin()             override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -55,5 +54,3 @@ private Q_SLOTS:
 };
 
 } // namespace DigikamEditorPerspectiveToolPlugin
-
-#endif // DIGIKAM_PERSPECTIVETOOL_PLUGIN_H
