@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_PERSPECTIVE_TRIANGLE_H
-#define DIGIKAM_EDITOR_PERSPECTIVE_TRIANGLE_H
+#pragma once
 
 // Qt includes
 
@@ -40,11 +39,9 @@ private:
 
 private:
 
-    float m_a;
-    float m_b;
-    float m_c;
+    float m_a = 0.0F;
+    float m_b = 0.0F;
+    float m_c = 0.0F;
 };
 
 } // namespace DigikamEditorPerspectiveToolPlugin
-
-#endif // DIGIKAM_EDITOR_PERSPECTIVE_TRIANGLE_H
