@@ -14,8 +14,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_RATIO_CROP_TOOL_H
-#define DIGIKAM_EDITOR_RATIO_CROP_TOOL_H
+#pragma once
 
 // Qt includes
 
@@ -80,9 +79,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorRatioCropToolPlugin
-
-#endif // DIGIKAM_EDITOR_RATIO_CROP_TOOL_H
