@@ -6,7 +6,7 @@
  * Date        : 2018-07-30
  * Description : image editor plugin to crop an image with ratio.
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -35,10 +35,6 @@ RatioCropToolPlugin::RatioCropToolPlugin(QObject* const parent)
 {
 }
 
-RatioCropToolPlugin::~RatioCropToolPlugin()
-{
-}
-
 QString RatioCropToolPlugin::name() const
 {
     return i18nc("@title", "Aspect Ratio Crop");
@@ -90,7 +86,7 @@ QList<DPluginAuthor> RatioCropToolPlugin::authors() const
                              QString::fromUtf8("(C) 2008"))
             << DPluginAuthor(QString::fromUtf8("Gilles Caulier"),
                              QString::fromUtf8("caulier dot gilles at gmail dot com"),
-                             QString::fromUtf8("(C) 2004-2021"))
+                             QString::fromUtf8("(C) 2004-2024"))
             ;
 }
 
@@ -121,3 +117,5 @@ void RatioCropToolPlugin::slotRatioCrop()
 }
 
 } // namespace DigikamEditorRatioCropToolPlugin
+
+#include "moc_ratiocroptoolplugin.cpp"
