@@ -6,14 +6,13 @@
  * Date        : 2018-07-30
  * Description : image editor plugin to crop an image with ratio.
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_RATIOCROPTOOL_PLUGIN_H
-#define DIGIKAM_RATIOCROPTOOL_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class RatioCropToolPlugin : public DPluginEditor
 public:
 
     explicit RatioCropToolPlugin(QObject* const parent = nullptr);
-    ~RatioCropToolPlugin()               override;
+    ~RatioCropToolPlugin()               override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -55,5 +54,3 @@ private Q_SLOTS:
 };
 
 } // namespace DigikamEditorRatioCropToolPlugin
-
-#endif // DIGIKAM_RATIOCROPTOOL_PLUGIN_H
