@@ -8,7 +8,7 @@
  *
  * SPDX-FileCopyrightText: 2007      by Jaromir Malenko <malenko at email.cz>
  * SPDX-FileCopyrightText: 2008      by Roberto Castagnola <roberto dot castagnola at gmail dot com>
- * SPDX-FileCopyrightText: 2004-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -40,7 +40,6 @@
 // Qt includes
 
 #include <QRegion>
-#include <QColor>
 #include <QPainter>
 #include <QBrush>
 #include <QPixmap>
@@ -74,69 +73,53 @@ public:
         ResizingBottomRight
     };
 
-    explicit Private()
-      : drawGoldenSection       (false),
-        drawGoldenSpiralSection (false),
-        drawGoldenSpiral        (false),
-        drawGoldenTriangle      (false),
-        flipHorGoldenGuide      (false),
-        flipVerGoldenGuide      (false),
-        moving                  (false),
-        autoOrientation         (false),
-        preciseCrop             (false),
-        isDrawingSelection      (false),
-        guideLinesType          (0),
-        guideSize               (1),
-        currentAspectRatioType  (0),
-        currentResizing         (ResizingNone),
-        currentOrientation      (0),
-        currentWidthRatioValue  (0),
-        currentHeightRatioValue (0),
-        pixmap                  (nullptr),
-        iface                   (nullptr)
-    {
-    }
+public:
+
+    Private() = default;
 
     // Golden guide types.
-    bool        drawGoldenSection;
-    bool        drawGoldenSpiralSection;
-    bool        drawGoldenSpiral;
-    bool        drawGoldenTriangle;
+
+    bool        drawGoldenSection       = false;
+    bool        drawGoldenSpiralSection = false;
+    bool        drawGoldenSpiral        = false;
+    bool        drawGoldenTriangle      = false;
 
     // Golden guide translations.
-    bool        flipHorGoldenGuide;
-    bool        flipVerGoldenGuide;
 
-    bool        moving;
-    bool        autoOrientation;
-    bool        preciseCrop;
+    bool        flipHorGoldenGuide      = false;
+    bool        flipVerGoldenGuide      = false;
 
-    bool        isDrawingSelection;
+    bool        moving                  = false;
+    bool        autoOrientation         = false;
+    bool        preciseCrop             = false;
 
-    int         guideLinesType;
-    int         guideSize;
+    bool        isDrawingSelection      = false;
 
-    int         currentAspectRatioType;
-    int         currentResizing;
-    int         currentOrientation;
+    int         guideLinesType          = 0;
+    int         guideSize               = 1;
 
-    float       currentWidthRatioValue;
-    float       currentHeightRatioValue;
+    int         currentAspectRatioType  = 0;
+    int         currentResizing         = ResizingNone;
+    int         currentOrientation      = 0;
+
+    float       currentWidthRatioValue  = 0.0;
+    float       currentHeightRatioValue = 0.0;
 
     QPoint      lastPos;
 
     QRect       rect;
-    QRect       image;                   // Real image dimension.
-    QRect       regionSelection;         // Real size image selection.
-    QRect       localRegionSelection;    // Local size selection.
+    QRect       image;                  // Real image dimension.
+    QRect       regionSelection;        // Real size image selection.
+    QRect       localRegionSelection;   // Local size selection.
 
     // Draggable local region selection corners.
+
     QRect       localTopLeftCorner;
     QRect       localBottomLeftCorner;
     QRect       localTopRightCorner;
     QRect       localBottomRightCorner;
 
-    QPixmap*    pixmap;
+    QPixmap*    pixmap                  = nullptr;
     QPixmap     grayOverLay;
     QPixmap     previewPixmap;
 
@@ -145,7 +128,7 @@ public:
 
     DImg        preview;
 
-    ImageIface* iface;
+    ImageIface* iface                   = nullptr;
 };
 
 RatioCropWidget::RatioCropWidget(int w, int h, QWidget* const parent)
@@ -642,10 +625,12 @@ void RatioCropWidget::reverseRatioValues()
 {
     // Reverse ratio values if needed
 
-    if (((d->currentWidthRatioValue > d->currentHeightRatioValue)  &&
+    if (
+        ((d->currentWidthRatioValue > d->currentHeightRatioValue)  &&
          (d->currentOrientation == Portrait))                      ||
          ((d->currentHeightRatioValue > d->currentWidthRatioValue) &&
-          (d->currentOrientation == Landscape)))
+          (d->currentOrientation == Landscape))
+       )
     {
         float tmp                  = d->currentWidthRatioValue;
         d->currentWidthRatioValue  = d->currentHeightRatioValue;
@@ -923,6 +908,15 @@ void RatioCropWidget::drawRulesOfThirds(QPainter& p, const int& xThird, const in
 
 }
 
+void RatioCropWidget::drawRulesOfCenter(QPainter& p, const int& xHalf, const int& yHalf)
+{
+    p.drawLine(d->localRegionSelection.left() + xHalf, d->localRegionSelection.top(),
+               d->localRegionSelection.left() + xHalf, d->localRegionSelection.bottom());
+
+    p.drawLine(d->localRegionSelection.left(),  d->localRegionSelection.top() + yHalf,
+               d->localRegionSelection.right(), d->localRegionSelection.top() + yHalf);
+}
+
 void RatioCropWidget::drawDiagonalMethod(QPainter& p, const int& w, const int& h)
 {
     p.setRenderHint(QPainter::Antialiasing);
@@ -1236,6 +1230,19 @@ void RatioCropWidget::updatePixmap()
 
             break;
         }
+
+        case CenterLines:
+        {
+            int xHalf = d->localRegionSelection.width()  / 2;
+            int yHalf = d->localRegionSelection.height() / 2;
+
+            p.setPen(QPen(Qt::white, d->guideSize, Qt::SolidLine));
+            drawRulesOfCenter(p, xHalf, yHalf);
+
+            p.setPen(QPen(d->guideColor, d->guideSize, Qt::DotLine));
+            drawRulesOfCenter(p, xHalf, yHalf);
+            break;
+        }
     }
 
     p.setClipping(false);
@@ -1696,3 +1703,5 @@ void RatioCropWidget::setIsDrawingSelection(bool draw)
 }
 
 } // namespace DigikamEditorRatioCropToolPlugin
+
+#include "moc_ratiocropwidget.cpp"
