@@ -14,8 +14,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_RATIO_CROP_WIDGET_H
-#define DIGIKAM_EDITOR_RATIO_CROP_WIDGET_H
+#pragma once
 
 // Qt includes
 
@@ -181,9 +180,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorRatioCropToolPlugin
-
-#endif // DIGIKAM_EDITOR_RATIO_CROP_WIDGET_H
