@@ -6,14 +6,13 @@
  * Date        : 2004-12-23
  * Description : a tool to shear an image
  *
- * SPDX-FileCopyrightText: 2004-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_SHEAR_TOOL_H
-#define DIGIKAM_EDITOR_SHEAR_TOOL_H
+#pragma once
 
 // Local includes
 
@@ -50,9 +49,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorShearToolPlugin
-
-#endif // DIGIKAM_EDITOR_SHEAR_TOOL_H
