@@ -6,7 +6,7 @@
  * Date        : 2018-07-30
  * Description : a plugin to acquire images with a digital scanner.
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -38,10 +38,6 @@ DigitalScannerPlugin::DigitalScannerPlugin(QObject* const parent)
 {
 }
 
-DigitalScannerPlugin::~DigitalScannerPlugin()
-{
-}
-
 void DigitalScannerPlugin::cleanUp()
 {
     if (m_saneWidget)
@@ -98,7 +94,7 @@ QList<DPluginAuthor> DigitalScannerPlugin::authors() const
                              QString::fromUtf8("(C) 2006-2007"))
             << DPluginAuthor(QString::fromUtf8("Gilles Caulier"),
                              QString::fromUtf8("caulier dot gilles at gmail dot com"),
-                             QString::fromUtf8("(C) 2003-2022"))
+                             QString::fromUtf8("(C) 2003-2024"))
             ;
 }
 
@@ -156,3 +152,5 @@ void DigitalScannerPlugin::slotDigitalScanner()
 }
 
 } // namespace DigikamGenericDScannerPlugin
+
+#include "moc_dscannerplugin.cpp"
