@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_SAVE_IMG_THREAD_H
-#define DIGIKAM_SAVE_IMG_THREAD_H
+#pragma once
 
 // Qt includes
 
@@ -72,9 +71,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamGenericDScannerPlugin
-
-#endif // DIGIKAM_SAVE_IMG_THREAD_H
