@@ -15,8 +15,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_GEO_LOCATION_EDIT_H
-#define DIGIKAM_GEO_LOCATION_EDIT_H
+#pragma once
 
 // Qt includes
 
@@ -49,7 +48,7 @@ class GeolocationEdit : public DPluginDialog
 public:
 
     explicit GeolocationEdit(QWidget* const parent, DInfoInterface* const iface);
-    ~GeolocationEdit() override;
+    ~GeolocationEdit()                  override;
 
     /**
      * Populate items in dialog list based on url. To be used in case of non database as with Showfoto.
@@ -102,9 +101,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamGenericGeolocationEditPlugin
-
-#endif // DIGIKAM_GEO_LOCATION_EDIT_H
