@@ -7,14 +7,13 @@
  * Description : GPS data file parser.
  *               (GPX format https://www.topografix.com/gpx.asp).
  *
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_GEO_DATA_PARSER_H
-#define DIGIKAM_GEO_DATA_PARSER_H
+#pragma once
 
 // Qt includes
 
@@ -34,8 +33,8 @@ class GeoDataParser
 
 public:
 
-    explicit GeoDataParser();
-    ~GeoDataParser() {};
+    GeoDataParser();
+    ~GeoDataParser() = default;
 
     bool loadGPXFile(const QUrl& url);
 
@@ -49,6 +48,7 @@ public:
 private:
 
     /// Methods used to perform interpolation.
+
     QDateTime findNextDate(const QDateTime& dateTime, int secs);
     QDateTime findPrevDate(const QDateTime& dateTime, int secs);
 
@@ -60,5 +60,3 @@ protected:
 };
 
 } // namespace DigikamGenericGeolocationEditPlugin
-
-#endif // DIGIKAM_GEO_DATA_PARSER_H
