@@ -8,14 +8,13 @@
  *               Put into an extra file for easier testing.
  *
  * SPDX-FileCopyrightText: 2010      by Michael G. Hansen <mike at mghansen dot de>
- * SPDX-FileCopyrightText: 2017-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_GEO_DATA_PARSER_TIME_H
-#define DIGIKAM_GEO_DATA_PARSER_TIME_H
+#pragma once
 
 // Qt includes
 
@@ -45,8 +44,10 @@ QDateTime GeoDataParserParseTime(QString timeString)
     const int timeZonePlusPosition  = timeString.lastIndexOf(QLatin1Char('+'));
     const int timeZoneMinusPosition = timeString.lastIndexOf(QLatin1Char('-'));
 
-    if ((timeZonePlusPosition  == timeZoneSignPosition) ||
-        (timeZoneMinusPosition == timeZoneSignPosition))
+    if (
+        (timeZonePlusPosition  == timeZoneSignPosition) ||
+        (timeZoneMinusPosition == timeZoneSignPosition)
+       )
     {
         const int timeZoneSign       = (timeZonePlusPosition == timeZoneSignPosition) ? +1 : -1;
 
@@ -77,5 +78,3 @@ QDateTime GeoDataParserParseTime(QString timeString)
 }
 
 } // namespace DigikamGenericGeolocationEditPlugin
-
-#endif // DIGIKAM_GEO_DATA_PARSER_TIME_H
