@@ -7,7 +7,7 @@
  * Description : a tool to export GPS data to KML file.
  *
  * SPDX-FileCopyrightText: 2006-2007 by Stephane Pontier <shadow dot walker at free dot fr>
- * SPDX-FileCopyrightText: 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -23,12 +23,7 @@ namespace DigikamGenericGeolocationEditPlugin
 {
 
 KMLGeoDataParser::KMLGeoDataParser()
-    : GeoDataParser(),
-      kmlDocument  (nullptr)
-{
-}
-
-KMLGeoDataParser::~KMLGeoDataParser()
+    : GeoDataParser()
 {
 }
 
