@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_KML_GPS_DATA_PARSER_H
-#define DIGIKAM_KML_GPS_DATA_PARSER_H
+#pragma once
 
 // Qt includes
 
@@ -35,8 +34,8 @@ class KMLGeoDataParser : public GeoDataParser
 
 public:
 
-    explicit KMLGeoDataParser();
-    ~KMLGeoDataParser();
+    KMLGeoDataParser();
+    ~KMLGeoDataParser() = default;
 
     /*! KMLGeoDataParser::KMLGeoDataParser::lineString()
      *  @return the string containing the time ordered point (lon,lat,alt)
@@ -68,8 +67,8 @@ private:
      */
     QDomElement addKmlElement(QDomElement& target, const QString& tag)
     {
-        QDomElement kmlElement = kmlDocument->createElement( tag );
-        target.appendChild( kmlElement );
+        QDomElement kmlElement = kmlDocument->createElement(tag);
+        target.appendChild(kmlElement);
 
         return kmlElement;
     }
@@ -83,10 +82,10 @@ private:
      */
     QDomElement addKmlTextElement(QDomElement& target, const QString& tag, const QString& text)
     {
-        QDomElement kmlElement  = kmlDocument->createElement( tag );
-        target.appendChild( kmlElement );
-        QDomText kmlTextElement = kmlDocument->createTextNode( text );
-        kmlElement.appendChild( kmlTextElement );
+        QDomElement kmlElement  = kmlDocument->createElement(tag);
+        target.appendChild(kmlElement);
+        QDomText kmlTextElement = kmlDocument->createTextNode(text);
+        kmlElement.appendChild(kmlTextElement);
 
         return kmlElement;
     }
@@ -99,5 +98,3 @@ private:
 };
 
 } // namespace DigikamGenericGeolocationEditPlugin
-
-#endif // DIGIKAM_KML_GPS_DATA_PARSER_H
