@@ -6,15 +6,14 @@
  * Date        : 2010-06-01
  * Description : A widget to search for places.
  *
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2010-2011 by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_SEARCH_RESULT_MODEL_H
-#define DIGIKAM_SEARCH_RESULT_MODEL_H
+#pragma once
 
 // Qt includes
 
@@ -23,7 +22,7 @@
 
 // local includes
 
-#include "searchbackend.h"
+#include "searchresultbackend.h"
 
 class QItemSelection;
 
@@ -42,7 +41,7 @@ public:
     {
     public:
 
-        SearchBackend::SearchResult result;
+        SearchResultBackend::SearchResult result;
     };
 
 public:
@@ -50,7 +49,7 @@ public:
     explicit SearchResultModel(QObject* const parent = nullptr);
     ~SearchResultModel()                                                  override;
 
-    void addResults(const SearchBackend::SearchResult::List& results);
+    void addResults(const SearchResultBackend::SearchResult::List& results);
     SearchResultItem resultItem(const QModelIndex& index)           const;
     bool getMarkerIcon(const QModelIndex& index,
                        QPoint* const offset,
@@ -85,9 +84,7 @@ public:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamGenericGeolocationEditPlugin
-
-#endif // DIGIKAM_SEARCH_RESULT_MODEL_H
