@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_SEARCH_RESULT_MODEL_HELPER_H
-#define DIGIKAM_SEARCH_RESULT_MODEL_HELPER_H
+#pragma once
 
 // Qt includes
 
@@ -43,17 +42,21 @@ public:
                                      QItemSelectionModel* const selectionModel,
                                      GPSItemModel* const imageModel,
                                      QObject* const parent = nullptr);
-    ~SearchResultModelHelper()                                                                                                     override;
+    ~SearchResultModelHelper()                                                                override;
 
     void setVisibility(const bool state);
 
-    QAbstractItemModel* model()                                                                                              const override;
-    QItemSelectionModel* selectionModel()                                                                                    const override;
-    bool itemCoordinates(const QModelIndex& index, GeoCoordinates* const coordinates)                                        const override;
-    bool itemIcon(const QModelIndex& index, QPoint* const offset, QSize* const size, QPixmap* const pixmap, QUrl* const url) const override;
-    PropertyFlags modelFlags()                                                                                               const override;
-    PropertyFlags itemFlags(const QModelIndex& index)                                                                        const override;
-    void snapItemsTo(const QModelIndex& targetIndex, const QList<QModelIndex>& snappedIndices)                                     override;
+    QAbstractItemModel* model()                                                         const override;
+    QItemSelectionModel* selectionModel()                                               const override;
+    bool itemCoordinates(const QModelIndex& index,
+                         GeoCoordinates* const coordinates)                             const override;
+    bool itemIcon(const QModelIndex& index, QPoint* const offset,
+                  QSize* const size, QPixmap* const pixmap,
+                  QUrl* const url)                                                      const override;
+    PropertyFlags modelFlags()                                                          const override;
+    PropertyFlags itemFlags(const QModelIndex& index)                                   const override;
+    void snapItemsTo(const QModelIndex& targetIndex,
+                     const QList<QModelIndex>& snappedIndices)                                override;
 
 Q_SIGNALS:
 
@@ -62,9 +65,7 @@ Q_SIGNALS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamGenericGeolocationEditPlugin
-
-#endif // DIGIKAM_SEARCH_RESULT_MODEL_HELPER_H
